@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
-
 """Top-level package for PrettyQt."""
 
 __author__ = """Philipp Temminghoff"""
 __email__ = "phil65@kodi.tv"
-__version__ = "0.122.1"
+__version__ = "0.161.0"
 
 
 def debug():
@@ -12,6 +10,9 @@ def debug():
     import inspect
 
     frame = inspect.currentframe()
+    if frame is None or frame.f_back is None:
+        del frame
+        raise RuntimeError()
     try:
         from prettyqt.objbrowser import objectbrowser
 
