@@ -1,11 +1,24 @@
-# -*- coding: utf-8 -*-
-
 import contextlib
-from typing import Optional, Tuple
+from typing import Optional
 
 from qtpy import QtCore
 
 from prettyqt import core
+from prettyqt.utils import bidict
+
+
+CHECK_INDEX_OPTIONS = bidict(
+    none=QtCore.QAbstractItemModel.CheckIndexOption.NoOption,
+    index_is_valid=QtCore.QAbstractItemModel.CheckIndexOption.IndexIsValid,
+    do_not_use_parent=QtCore.QAbstractItemModel.CheckIndexOption.DoNotUseParent,
+    parent_is_invalid=QtCore.QAbstractItemModel.CheckIndexOption.ParentIsInvalid,
+)
+
+LAYOUT_CHANGE_HINT = bidict(
+    none=QtCore.QAbstractItemModel.NoLayoutChangeHint,
+    vertical_sort=QtCore.QAbstractItemModel.VerticalSortHint,
+    horizontal_sort=QtCore.QAbstractItemModel.HorizontalSortHint,
+)
 
 
 QtCore.QAbstractItemModel.__bases__ = (core.Object,)
@@ -13,20 +26,32 @@ QtCore.QAbstractItemModel.__bases__ = (core.Object,)
 
 class AbstractItemModel(QtCore.QAbstractItemModel):
     def __repr__(self):
-        return f"{self.__class__.__name__}: {self.rowCount()} rows"
+        return f"{type(self).__name__}: {self.rowCount()} rows"
 
     def __len__(self) -> int:
         """Return amount of rows."""
         return self.rowCount()
 
-    def __getitem__(self, index: Tuple[int, int]):
-        return self.index(*index)
+    # causes issues with PySide2
+    # def __getitem__(self, index: Tuple[int, int]) -> QtCore.QModelIndex:
+    #     return self.index(*index)
 
-    def rows(self) -> int:
-        return self.rowCount()
-
-    def columns(self) -> int:
-        return self.columnCount()
+    def check_index(
+        self,
+        index: QtCore.QModelIndex,
+        index_is_valid: bool = False,
+        do_not_use_parent: bool = False,
+        parent_is_invalid: bool = False,
+    ) -> bool:
+        flag = QtCore.QAbstractItemModel.CheckIndexOption.NoOption
+        if index_is_valid:
+            flag |= CHECK_INDEX_OPTIONS["index_is_valid"]  # type: ignore
+        if do_not_use_parent:
+            flag |= CHECK_INDEX_OPTIONS["do_not_use_parent"]  # type: ignore
+        if parent_is_invalid:
+            flag |= CHECK_INDEX_OPTIONS["parent_is_invalid"]  # type: ignore
+        check_flag = QtCore.QAbstractItemModel.CheckIndexOptions(flag)  # type: ignore
+        return self.checkIndex(index, check_flag)
 
     @contextlib.contextmanager
     def change_layout(self):
@@ -121,3 +146,11 @@ class AbstractItemModel(QtCore.QAbstractItemModel):
         self.beginInsertColumns(parent, first, last)
         yield None
         self.endInsertColumns()
+
+    def force_reset(self):
+        self.beginResetModel()
+        self.endResetModel()
+
+    def force_layoutchange(self):
+        self.layoutAboutToBeChanged.emit()
+        self.layoutChanged.emit()
