@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtCore
 
 
 class ByteArray(QtCore.QByteArray):
     def __reduce__(self):
-        return (self.__class__, (bytes(self),))
+        return type(self), (bytes(self),)
