@@ -1,27 +1,30 @@
-# -*- coding: utf-8 -*-
+from typing import Literal, Union
 
 from qtpy import QtCore
 
 from prettyqt import core
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt.utils import InvalidParamError, bidict
 
 
 FLOAT_PRECISION = bidict(
-    single=QtCore.QDataStream.SinglePrecision, double=QtCore.QDataStream.DoublePrecision,
+    single=QtCore.QDataStream.SinglePrecision,
+    double=QtCore.QDataStream.DoublePrecision,
 )
 
+FloatPrecisionStr = Literal["single", "double"]
+
 BYTE_ORDER = bidict(
     big_endian=QtCore.QDataStream.BigEndian,
     little_endian=QtCore.QDataStream.LittleEndian,
 )
 
+ByteOrderStr = Literal["big_endian", "little_endian"]
+
 
 class DataStream(QtCore.QDataStream):
-    def set_byte_order(self, order: str):
+    def set_byte_order(self, order: ByteOrderStr):
         """Set byte order.
 
-        valid values are: "big_endian", "little endian"
-
         Args:
             order: byte order to use
 
@@ -32,21 +35,17 @@ class DataStream(QtCore.QDataStream):
             raise InvalidParamError(order, BYTE_ORDER)
         self.setByteOrder(BYTE_ORDER[order])
 
-    def get_byte_order(self) -> bool:
+    def get_byte_order(self) -> ByteOrderStr:
         """Return byte order.
 
-        possible values are "big_endian", "little_endian"
-
         Returns:
             byte order
         """
-        return BYTE_ORDER.inv[self.byteOrder()]
+        return BYTE_ORDER.inverse[self.byteOrder()]
 
-    def set_float_precision(self, precision: str):
+    def set_float_precision(self, precision: FloatPrecisionStr):
         """Set floating point precision.
 
-        valid values are: "single", "double"
-
         Args:
             precision: floating point precision
 
@@ -57,15 +56,13 @@ class DataStream(QtCore.QDataStream):
             raise InvalidParamError(precision, FLOAT_PRECISION)
         self.setFloatingPointPrecision(FLOAT_PRECISION[precision])
 
-    def get_float_precision(self) -> bool:
+    def get_float_precision(self) -> FloatPrecisionStr:
         """Return floating point precision.
 
-        possible values are "single", "double"
-
         Returns:
             floating point precision
         """
-        return FLOAT_PRECISION.inv[self.floatingPointPrecision()]
+        return FLOAT_PRECISION.inverse[self.floatingPointPrecision()]
 
     @classmethod
     def create_bytearray(cls, data) -> QtCore.QByteArray:
@@ -75,7 +72,9 @@ class DataStream(QtCore.QDataStream):
         return ba
 
     @classmethod
-    def write_bytearray(cls, ba: QtCore.QByteArray, write_to):
+    def write_bytearray(cls, ba: Union[QtCore.QByteArray, bytes], write_to):
+        if not isinstance(ba, QtCore.QByteArray):
+            ba = QtCore.QByteArray(ba)
         stream = cls(ba, core.IODevice.ReadOnly)
         stream >> write_to
 
