@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtCore
 
 
 class Event(QtCore.QEvent):
     def __repr__(self):
-        return f"Event({self.type()})"
+        return f"{type(self).__name__}({self.type()})"
