@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-
-from typing import Union
+from typing import Any, Dict, Iterator, List, Union
 
 import orjson as json
 from qtpy import QtCore
@@ -8,6 +6,9 @@ from qtpy import QtCore
 from prettyqt import core
 
 
+JSONType = Union[str, int, float, bool, None, Dict[str, Any], List[Any]]
+
+
 QtCore.QMimeData.__bases__ = (core.Object,)
 OPTS = json.OPT_NAIVE_UTC | json.OPT_SERIALIZE_NUMPY
 
@@ -16,8 +17,8 @@ class MimeData(QtCore.QMimeData):
     def __len__(self):
         return len(self.formats())
 
-    def __getitem__(self, index: str):
-        return self.data(index)
+    def __getitem__(self, index: str) -> str:
+        return self.get_data(index)
 
     def __setitem__(self, index: str, value: Union[QtCore.QByteArray, bytes, str]):
         if isinstance(value, str):
@@ -35,18 +36,18 @@ class MimeData(QtCore.QMimeData):
     def set_data(self, mime_type: str, data: str):
         self.setData(mime_type, QtCore.QByteArray(data.encode()))
 
-    def set_json_data(self, mime_type: str, data):
+    def set_json_data(self, mime_type: str, data: JSONType):
         self.setData(mime_type, QtCore.QByteArray(json.dumps(data, option=OPTS)))
 
     def get_data(self, mime_type: str) -> str:
         return bytes(self.data(mime_type)).decode()
 
-    def get_json_data(self, mime_type: str):
+    def get_json_data(self, mime_type: str) -> JSONType:
         data = self.data(mime_type)
         return json.loads(bytes(data))
 
-    def keys(self):
+    def keys(self) -> List[str]:
         return self.formats()
 
-    def values(self):
-        return (self.data(key) for key in self.formats())
+    def values(self) -> Iterator[Any]:
+        return (self.get_data(key) for key in self.formats())
