@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtCore
 
 
 class ModelIndex(QtCore.QModelIndex):
-    def __getitem__(self, flag):
+    def __getitem__(self, flag: int):
         return self.data(flag)
