@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-
-from typing import Callable, Iterator, Optional, Union, Dict, Tuple
+from typing import Callable, Dict, Iterator, Literal, Optional, Tuple, Union
 
 from qtpy import QtCore
 
@@ -19,13 +17,15 @@ FLAGS = bidict(
     unicode=QtCore.QRegularExpression.UseUnicodePropertiesOption,
 )
 
-MATCH_TYPES = bidict(
+MATCH_TYPE = bidict(
     normal=QtCore.QRegularExpression.NormalMatch,
     prefer_complete=QtCore.QRegularExpression.PartialPreferCompleteMatch,
     prefer_first=QtCore.QRegularExpression.PartialPreferFirstMatch,
     no_match=QtCore.QRegularExpression.NoMatch,
 )
 
+MatchTypeStr = Literal["normal", "prefer_complete", "prefer_first", "no_match"]
+
 MATCH_OPTIONS = bidict(
     none=QtCore.QRegularExpression.NoMatchOption,
     anchored=QtCore.QRegularExpression.AnchoredMatchOption,
@@ -36,20 +36,20 @@ class RegularExpression(QtCore.QRegularExpression):
     def __init__(
         self,
         pattern: Union[str, QtCore.QRegularExpression] = "",
-        flags: int = FLAGS["none"],
+        flags: QtCore.QRegularExpression.PatternOption = FLAGS["none"],
     ):
         if isinstance(pattern, QtCore.QRegularExpression):
             super().__init__(pattern)
         else:
             if isinstance(flags, int):
-                flags = core.RegularExpression.PatternOptions(flags)
-            super().__init__(pattern, flags)
+                flags = core.RegularExpression.PatternOptions(flags)  # type: ignore
+            super().__init__(pattern, flags)  # type: ignore
 
     def __repr__(self):
-        return f"RegularExpression({self.pattern()!r})"
+        return f"{type(self).__name__}({self.pattern()!r})"
 
     def __reduce__(self):
-        return (self.__class__, (self.pattern(), int(self.flags)))
+        return type(self), (self.pattern(), int(self.flags))
 
     def globalMatch(self, *args, **kwargs) -> core.RegularExpressionMatchIterator:
         it = super().globalMatch(*args, **kwargs)
@@ -59,26 +59,28 @@ class RegularExpression(QtCore.QRegularExpression):
         self,
         text: str,
         offset: int = 0,
-        match_type: str = "normal",
+        match_type: MatchTypeStr = "normal",
         anchored: bool = False,
     ):
         options = MATCH_OPTIONS["anchored"] if anchored else MATCH_OPTIONS["none"]
-        return self.globalMatch(text, offset, MATCH_TYPES[match_type], options)
+        return self.globalMatch(text, offset, MATCH_TYPE[match_type], options)
 
-    def match(
+    def match(  # type: ignore
         self,
         text: str,
         offset: int = 0,
-        match_type: str = "normal",
+        match_type: Union[MatchTypeStr, QtCore.QRegularExpression.MatchType] = "normal",
         anchored: bool = False,
     ) -> core.RegularExpressionMatch:
         if isinstance(match_type, str):
-            match_type = MATCH_TYPES[match_type]
+            typ = MATCH_TYPE[match_type]
+        else:
+            typ = match_type
         if isinstance(anchored, bool):
             options = MATCH_OPTIONS["anchored"] if anchored else MATCH_OPTIONS["none"]
         else:
             options = anchored
-        match = super().match(text, offset, match_type, options)
+        match = super().match(text, offset, typ, options)
         return core.RegularExpressionMatch(match)
 
     def fullmatch(
@@ -102,7 +104,7 @@ class RegularExpression(QtCore.QRegularExpression):
             yield match
 
     def findall(self, string: str, pos: int = 0, endpos: Optional[int] = None) -> list:
-        matches = [m for m in self.globalMatch(string[:endpos], offset=pos)]
+        matches = list(self.globalMatch(string[:endpos], offset=pos))
         return [m.groups() if len(m.groups()) > 1 else m.group(0) for m in matches]
 
     def subn(
