@@ -1,21 +1,23 @@
-# -*- coding: utf-8 -*-
-
 import contextlib
-import pathlib
-from typing import List, Mapping, Optional, Union, Dict, Any
 import logging
+import pathlib
+from typing import Any, Dict, Iterator, List, Literal, Mapping, Optional, Tuple, Union
 
 from qtpy import QtCore
 
 from prettyqt import core
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt.utils import InvalidParamError, bidict
+
 
 logger = logging.getLogger(__name__)
 
-FORMATS = bidict(native=QtCore.QSettings.NativeFormat, ini=QtCore.QSettings.IniFormat)
+FORMAT = bidict(native=QtCore.QSettings.NativeFormat, ini=QtCore.QSettings.IniFormat)
 
-SCOPES = bidict(user=QtCore.QSettings.UserScope, system=QtCore.QSettings.SystemScope)
+FormatStr = Literal["user", "system"]
 
+SCOPE = bidict(user=QtCore.QSettings.UserScope, system=QtCore.QSettings.SystemScope)
+
+ScopeStr = Literal["user", "system"]
 
 QtCore.QSettings.__bases__ = (core.Object,)
 
@@ -26,7 +28,7 @@ class Settings(QtCore.QSettings):
         self.settings_id = settings_id
 
     def __repr__(self):
-        return f"Settings: {self.as_dict()}"
+        return f"{type(self).__name__}: {self.as_dict()}"
 
     def __contains__(self, key: str) -> bool:
         return self.contains(key)
@@ -51,8 +53,8 @@ class Settings(QtCore.QSettings):
             raise KeyError(key)
         return self.remove(key)
 
-    def __iter__(self):
-        return iter(self.allKeys())
+    def __iter__(self) -> Iterator[Tuple[str, Any]]:
+        return iter(self.items())
 
     def __len__(self) -> int:
         return len(self.allKeys())
@@ -64,7 +66,7 @@ class Settings(QtCore.QSettings):
             settings.set_value(k, v)
         return settings
 
-    def as_dict(self):
+    def as_dict(self) -> Dict[str, Any]:
         return {k: v for k, v in self.items()}
 
     def set_value(self, key: str, value):
@@ -87,44 +89,38 @@ class Settings(QtCore.QSettings):
         return val["value"]
 
     @classmethod
-    def set_default_format(cls, fmt: str):
+    def set_default_format(cls, fmt: FormatStr):
         """Set the default format.
 
-        possible values are "native", "ini"
-
         Args:
             fmt: the default format to use
 
         Raises:
             InvalidParamError: invalid format
         """
-        if fmt not in FORMATS:
-            raise InvalidParamError(fmt, FORMATS)
-        cls.setDefaultFormat(FORMATS[fmt])
+        if fmt not in FORMAT:
+            raise InvalidParamError(fmt, FORMAT)
+        cls.setDefaultFormat(FORMAT[fmt])
 
     @classmethod
-    def get_default_format(cls) -> str:
+    def get_default_format(cls) -> FormatStr:
         """Return default settings format.
 
-        possible values are "native", "ini"
-
         Returns:
             default settings format
         """
-        return FORMATS.inv[cls.defaultFormat()]
+        return FORMAT.inverse[cls.defaultFormat()]
 
-    def get_scope(self) -> str:
+    def get_scope(self) -> ScopeStr:
         """Return scope.
 
-        possible values are "user", "system"
-
         Returns:
             scope
         """
-        return SCOPES.inv[self.scope()]
+        return SCOPE.inverse[self.scope()]
 
     @classmethod
-    def set_path(cls, fmt: str, scope: str, path: Union[str, pathlib.Path]):
+    def set_path(cls, fmt: FormatStr, scope: ScopeStr, path: Union[str, pathlib.Path]):
         """Set the path to the settings file.
 
         Args:
@@ -134,14 +130,14 @@ class Settings(QtCore.QSettings):
         Raises:
             InvalidParamError: invalid format or scope
         """
-        if fmt not in FORMATS:
-            raise InvalidParamError(fmt, FORMATS)
-        if scope not in SCOPES:
-            raise InvalidParamError(scope, SCOPES)
-        cls.setPath(FORMATS[fmt], SCOPES[scope], str(path))
+        if fmt not in FORMAT:
+            raise InvalidParamError(fmt, FORMAT)
+        if scope not in SCOPE:
+            raise InvalidParamError(scope, SCOPE)
+        cls.setPath(FORMAT[fmt], SCOPE[scope], str(path))
 
     @contextlib.contextmanager
-    def group(self, prefix: str):
+    def edit_group(self, prefix: str):
         """Context manager for setting groups.
 
         Args:
@@ -176,10 +172,10 @@ class Settings(QtCore.QSettings):
 
     # Dictionary interface
 
-    def get(self, key: str, default=None):
+    def get(self, key: str, default: Any = None) -> Any:
         return self.get_value(key, default)
 
-    def setdefault(self, key: str, default=None):
+    def setdefault(self, key: str, default: Any = None) -> Any:
         if not self.contains(key):
             self.set_value(key, default)
             return default
@@ -188,7 +184,7 @@ class Settings(QtCore.QSettings):
     def keys(self) -> List[str]:
         return self.allKeys()
 
-    def values(self):
+    def values(self) -> Iterator[Any]:
         return (self.get_value(key) for key in self.allKeys())
 
     def items(self):
@@ -199,7 +195,7 @@ class Settings(QtCore.QSettings):
             return self.get_value(key)
         raise KeyError(key)
 
-    def popitem(self) -> tuple:
+    def popitem(self) -> Tuple[str, Any]:
         key = self.keys()[0]
         return (key, self.get_value(key))
 
@@ -208,17 +204,21 @@ class Settings(QtCore.QSettings):
             self.set_value(k, v)
 
 
-def register_extensions(*exts, app_name=None, app_path=None):
+def register_extensions(
+    *exts: str,
+    app_name: Optional[str] = None,
+    app_path: Union[None, str, pathlib.Path] = None,
+):
     logger.debug(f"assigning extensions {exts} to {app_name}")
     s = Settings("HKEY_CURRENT_USER\\SOFTWARE\\Classes", Settings.NativeFormat)
     if app_path is None:
-        app_path = core.Dir.toNativeSeparators(core.CoreApplication.applicationFilePath())
+        app_path = str(core.CoreApplication.get_application_file_path())
     if app_name is None:
         app_name = core.CoreApplication.applicationName()
     for ext in exts:
         s.setValue(f"{ext}/DefaultIcon/.", app_path)  # perhaps ,0 after app_path
         s.setValue(f"{ext}/.", app_name)
-    s.setValue(f"{app_name}/shell/open/command/.", app_path + " %1")
+    s.setValue(f"{app_name}/shell/open/command/.", f"{app_path} %1")
 
 
 if __name__ == "__main__":
