@@ -1,14 +1,19 @@
-# -*- coding: utf-8 -*-
 """Module containing custom delegate classes."""
 
 from .buttondelegate import ButtonDelegate
 from .radiodelegate import RadioDelegate
+from .progressbardelegate import ProgressBarDelegate
 from .icondelegate import IconDelegate
+from .stardelegate import StarDelegate
+from .renderlinkdelegate import RenderLinkDelegate
 from .nofocusdelegate import NoFocusDelegate
 
 __all__ = [
     "ButtonDelegate",
     "RadioDelegate",
+    "ProgressBarDelegate",
     "IconDelegate",
+    "StarDelegate",
+    "RenderLinkDelegate",
     "NoFocusDelegate",
 ]
