@@ -1,9 +1,7 @@
-# -*- coding: utf-8 -*-
+from qtpy import QtCore, QtGui, QtWidgets
 
 from prettyqt import widgets
 
-from qtpy import QtGui, QtWidgets, QtCore
-
 
 # Remove dotted border on cell focus.  https://stackoverflow.com/a/55252650/3620725
 class NoFocusDelegate(widgets.StyledItemDelegate):
