@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 from typing import Optional
 
-from qtpy import QtWidgets
+from qtpy import QtCore
 
 from prettyqt import constants, core, widgets
 
@@ -12,7 +10,7 @@ class RegexMatchesModel(core.AbstractTableModel):
     HEADER = ["Start", "End", "Value", "Groups"]
 
     def __init__(
-        self, matches: Optional[list] = None, parent: Optional[QtWidgets.QWidget] = None
+        self, matches: Optional[list] = None, parent: Optional[QtCore.QObject] = None
     ):
         super().__init__(parent=parent)
         self.matches = matches if matches else list()
@@ -20,10 +18,12 @@ class RegexMatchesModel(core.AbstractTableModel):
     def columnCount(self, parent=None):
         return len(self.HEADER)
 
-    def headerData(self, offset: int, orientation, role):
+    def headerData(  # type: ignore
+        self, section: int, orientation: QtCore.Qt.Orientation, role: int
+    ) -> Optional[str]:
         if role == constants.DISPLAY_ROLE:
             if orientation == constants.HORIZONTAL:
-                return self.HEADER[offset]
+                return self.HEADER[section]
 
     def data(self, index, role):
         if not index.isValid():
@@ -66,4 +66,4 @@ if __name__ == "__main__":
     view.resize(500, 300)
     print(view.model())
     print(view.model().rowCount())
-    app.exec_()
+    app.main_loop()
