@@ -1,20 +1,19 @@
-# -*- coding: utf-8 -*-
+from typing import Callable, Dict
 
-from typing import Dict
-
-from prettyqt import constants
 from qtpy import QtCore
 
+from prettyqt import constants
 
-class SelectionMixin(object):
 
-    CHECKSTATE: Dict = {}  # column: identifier
+class SelectionMixin:
+
+    CHECKSTATE: Dict[int, Callable] = {}  # column: identifier
     dataChanged: QtCore.Signal
     DATA_ROLE: int
 
     def __init__(self):
         super().__init__()
-        self.selected = dict()
+        self.selected = {}
 
     def setData(self, index: QtCore.QModelIndex, value, role):
         if not index.isValid():
