@@ -1,13 +1,20 @@
-# -*- coding: utf-8 -*-
+from typing import Tuple
+
+from qtpy import QtGui
 
 from prettyqt import gui
 
 
 class NotEmptyValidator(gui.Validator):
-    def validate(self, text: str, pos: int = 0) -> tuple:
+    def __eq__(self, other: object):
+        return isinstance(other, NotEmptyValidator)
+
+    def validate(  # type: ignore
+        self, text: str, pos: int = 0
+    ) -> Tuple[QtGui.QValidator.State, str, int]:
         if text == "":
             return (self.Intermediate, text, pos)
-        return (self.Acceptable, text, pos)
+        return self.Acceptable, text, pos
 
 
 if __name__ == "__main__":
@@ -18,4 +25,4 @@ if __name__ == "__main__":
     widget = widgets.LineEdit("This is a test")
     widget.setValidator(val)
     widget.show()
-    app.exec_()
+    app.main_loop()
