@@ -1,15 +1,16 @@
-# -*- coding: utf-8 -*-
 """Module containing custom widget classes."""
 
+from prettyqt import core
+
 from .image import Image
 from .listinput import ListInput
 from .booldicttoolbutton import BoolDictToolButton
 from .optionalwidget import OptionalWidget
 from .collapsibleframe import CollapsibleFrame
+from .expandableline import ExpandableLine
 from .singlelinetextedit import SingleLineTextEdit
 from .regexinput import RegexInput
 from .mappedcheckbox import MappedCheckBox
-from .promptlineedit import PromptLineEdit
 from .logtextedit import LogTextEdit
 from .flagselectionwidget import FlagSelectionWidget
 from .stringornumberwidget import StringOrNumberWidget
@@ -28,8 +29,13 @@ from .imageviewer import ImageViewer
 from .popupinfo import PopupInfo
 from .selectionwidget import SelectionWidget
 from .codeeditor import CodeEditor
+from .roundprogressbar import RoundProgressBar
+
+# from .stareditor import StarEditor, StarRating
 from .timeline import Timeline, VideoSample
-from .regexeditor.editor import RegexEditorWidget
+
+if core.VersionNumber.get_qt_version() < (6, 0, 0):
+    from .player import Player
 
 # Deprecated: should be imported from custom_delegates instead
 from prettyqt.custom_delegates.buttondelegate import ButtonDelegate
@@ -41,10 +47,10 @@ __all__ = [
     "BoolDictToolButton",
     "OptionalWidget",
     "CollapsibleFrame",
+    "ExpandableLine",
     "SingleLineTextEdit",
     "RegexInput",
     "MappedCheckBox",
-    "PromptLineEdit",
     "LogTextEdit",
     "FlagSelectionWidget",
     "StringOrNumberWidget",
@@ -58,6 +64,7 @@ __all__ = [
     "SpanSlider",
     "LabeledSlider",
     "WaitingSpinner",
+    "RoundProgressBar",
     "PopupInfo",
     "ButtonDelegate",
     "RadioDelegate",
@@ -65,7 +72,10 @@ __all__ = [
     "ImageViewer",
     "MarkdownWindow",
     "CodeEditor",
+    "Player",
     "Timeline",
+    # "StarEditor",
+    # "StarRating",
     "VideoSample",
     "RegexEditorWidget",
 ]
