@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from typing import Optional
 
 from qtpy import QtCore, QtWidgets
@@ -7,18 +5,6 @@ from qtpy import QtCore, QtWidgets
 from prettyqt import core, gui, widgets
 
 
-class LineNumberArea(widgets.Widget):
-    def __init__(self, editor):
-        super().__init__(editor)
-        self.editor = editor
-
-    def sizeHint(self):
-        return core.Size(self.editor.line_area_width(), 0)
-
-    def paintEvent(self, event):
-        self.editor.line_area_paintevent(event)
-
-
 class CodeEditor(widgets.PlainTextEdit):
     def __init__(
         self, language: str = "python", parent: Optional[QtWidgets.QWidget] = None
@@ -45,13 +31,12 @@ class CodeEditor(widgets.PlainTextEdit):
 
     def line_area_width(self) -> int:
         digits = len(str(self.blockCount()))
-        space = 3 + self.fontMetrics().boundingRect("9").width() * digits
-        return space
+        return 3 + self.fontMetrics().boundingRect("9").width() * digits
 
     def update_line_area_width(self, _):
         self.setViewportMargins(self.line_area_width(), 0, 0, 0)
 
-    def update_line_area(self, rect, dy):
+    def update_line_area(self, rect: QtCore.QRect, dy: int):
         if dy:
             self.line_area.scroll(0, dy)
         else:
@@ -61,28 +46,42 @@ class CodeEditor(widgets.PlainTextEdit):
             self.update_line_area_width(0)
 
     def line_area_paintevent(self, event):
-        painter = gui.Painter(self.line_area)
-        painter.fill_rect(event.rect(), "lightgray")
+        with gui.Painter(self.line_area) as painter:
+            painter.fill_rect(event.rect(), "lightgray")
 
-        block = self.firstVisibleBlock()
-        block_number = block.blockNumber()
-        top = self.blockBoundingGeometry(block).translated(self.contentOffset()).top()
-        bottom = top + self.blockBoundingRect(block).height()
-        width = self.line_area.width()
-        height = self.fontMetrics().height()
-        painter.set_color("black")
-        while block.isValid() and (top <= event.rect().bottom()):
-            if block.isVisible() and (bottom >= event.rect().top()):
-                number = str(block_number + 1)
-                painter.drawText(0, top, width, height, QtCore.Qt.AlignRight, number)
-            block = block.next()
-            top = bottom
+            block = self.firstVisibleBlock()
+            block_number = block.blockNumber()
+            top = self.blockBoundingGeometry(block).translated(self.contentOffset()).top()
             bottom = top + self.blockBoundingRect(block).height()
-            block_number += 1
+            width = self.line_area.width()
+            height = self.fontMetrics().height()
+            painter.set_color("black")
+            while block.isValid() and (top <= event.rect().bottom()):
+                if block.isVisible() and (bottom >= event.rect().top()):
+                    number = str(block_number + 1)
+                    painter.drawText(
+                        0, int(top), width, height, QtCore.Qt.AlignRight, number
+                    )
+                block = block.next()
+                top = bottom
+                bottom = top + self.blockBoundingRect(block).height()
+                block_number += 1
+
+
+class LineNumberArea(widgets.Widget):
+    def __init__(self, editor: CodeEditor):
+        super().__init__(editor)
+        self.editor = editor
+
+    def sizeHint(self) -> core.Size:
+        return core.Size(self.editor.line_area_width(), 0)
+
+    def paintEvent(self, event):
+        self.editor.line_area_paintevent(event)
 
 
 if __name__ == "__main__":
     app = widgets.app()
     dlg = CodeEditor()
     dlg.show()
-    app.exec_()
+    app.main_loop()
