@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
-
 from typing import Optional
 
 from qtpy import QtWidgets
 
-from prettyqt import core, gui, widgets
+from prettyqt import core, gui, iconprovider, widgets
 from prettyqt.utils import colors
 
 
@@ -12,7 +10,9 @@ class ColorChooserButton(widgets.Widget):
 
     value_changed = core.Signal(gui.Color)
 
-    def __init__(self, color=None, parent: Optional[QtWidgets.QWidget] = None):
+    def __init__(
+        self, color: colors.ColorType = None, parent: Optional[QtWidgets.QWidget] = None
+    ):
         super().__init__(parent)
         layout = widgets.BoxLayout("horizontal", self)
         layout.set_margin(0)
@@ -25,44 +25,47 @@ class ColorChooserButton(widgets.Widget):
         self.button.setDefaultAction(action)
         layout += self.button
         if color is not None:
-            self.set_color(color)
+            self.set_current_color(color)
 
     def __repr__(self):
-        return f"ColorChooserButton({self.current_color})"
+        return f"{type(self).__name__}({self._current_color})"
 
     def serialize_fields(self):
-        return dict(color=self.current_color, enabled=self.isEnabled())
+        return dict(current_color=self._current_color, enabled=self.isEnabled())
 
     def __setstate__(self, state):
-        self.__init__()
-        if state["color"]:
-            self.set_color(state["color"])
+        if state["current_color"]:
+            self.set_current_color(state["current_color"])
         self.setEnabled(state.get("enabled", True))
 
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
     @core.Slot()
     def choose_color(self):
         dlg = widgets.ColorDialog()
-        if self.current_color:
-            dlg.setCurrentColor(self.current_color)
+        if self._current_color:
+            dlg.setCurrentColor(self._current_color)
 
         if dlg.exec_():
-            self.set_color(dlg.current_color())
-            self.value_changed.emit(dlg.current_color())
+            new_color = dlg.current_color()
+            self.set_current_color(new_color)
+            self.value_changed.emit(new_color)
 
-    def set_color(self, color: colors.ColorType):
-        self.current_color = colors.get_color(color)
-        self.lineedit.set_text(self.current_color.name().upper())
-        icon = gui.Icon.for_color(self.current_color)
+    def set_current_color(self, color: colors.ColorType):
+        self._current_color = colors.get_color(color)
+        self.lineedit.set_text(self._current_color.name().upper())
+        icon = iconprovider.for_color(self._current_color)
         self.button.set_icon(icon)
 
     def is_valid(self) -> bool:
         return self.lineedit.is_valid()
 
-    def get_value(self):
-        return self.current_color
+    def get_value(self) -> gui.Color:
+        return self._current_color
 
-    def set_value(self, value):
-        self.set_color(value)
+    def set_value(self, value: colors.ColorType):
+        self.set_current_color(value)
 
 
 if __name__ == "__main__":
@@ -70,4 +73,4 @@ if __name__ == "__main__":
     btn = ColorChooserButton(gui.Color("green"))
     btn.show()
     btn.value_changed.connect(print)
-    app.exec_()
+    app.main_loop()
