@@ -1,7 +1,5 @@
-# -*- coding: utf-8 -*-
-
 import pathlib
-from typing import Optional, Union, List, Dict
+from typing import Dict, List, Optional, Union
 
 from qtpy import QtWidgets
 
@@ -15,8 +13,8 @@ class FileChooserButton(widgets.Widget):
     def __init__(
         self,
         extensions: Optional[Dict[str, List[str]]] = None,
-        mode: str = "save",
-        file_mode: str = "existing_files",
+        mode: widgets.filedialog.AcceptModeStr = "save",
+        file_mode: widgets.filedialog.FileModeStr = "existing_files",
         root: Union[None, str, pathlib.Path] = None,
         parent: Optional[QtWidgets.QWidget] = None,
     ):
@@ -34,8 +32,8 @@ class FileChooserButton(widgets.Widget):
         super().__init__(parent)
         self.path: Optional[pathlib.Path] = None
         self.extensions = extensions
-        self.mode = mode
-        self.file_mode = file_mode
+        self.mode: widgets.filedialog.AcceptModeStr = mode
+        self.file_mode: widgets.filedialog.FileModeStr = file_mode
         self.root = root
         layout = widgets.BoxLayout("horizontal", self)
         layout.set_margin(0)
@@ -57,10 +55,12 @@ class FileChooserButton(widgets.Widget):
         return dict(path=self.path, extensions=self.extensions, enabled=self.isEnabled())
 
     def __setstate__(self, state):
-        self.__init__(state["extensions"])
         self.set_path(state["path"])
         self.set_enabled(state.get("enabled", True))
 
+    def __reduce__(self):
+        return type(self), (self.extensions,), self.__getstate__()
+
     @core.Slot()
     def open_file(self):
         dialog = widgets.FileDialog(
@@ -73,7 +73,7 @@ class FileChooserButton(widgets.Widget):
         if self.extensions:
             dialog.set_extension_filter(self.extensions)
         if not dialog.choose():
-            return None
+            return
         self.set_path(dialog.selected_file())
         self.value_changed.emit(self.path)
 
@@ -96,4 +96,4 @@ if __name__ == "__main__":
     btn = FileChooserButton()
     btn.show()
     btn.value_changed.connect(print)
-    app.exec_()
+    app.main_loop()
