@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
-
 from typing import Optional
 
 from qtpy import QtWidgets
 
-from prettyqt import gui, widgets
+from prettyqt import iconprovider, widgets
 
 
 class IconLabel(widgets.Widget):
@@ -12,7 +10,7 @@ class IconLabel(widgets.Widget):
         self,
         text: Optional[str] = None,
         tooltip: str = "",
-        icon: gui.icon.IconType = "mdi.help-circle-outline",
+        icon: iconprovider.IconType = "mdi.help-circle-outline",
         parent: Optional[QtWidgets.QWidget] = None,
     ):
         super().__init__(parent=parent)
@@ -21,7 +19,7 @@ class IconLabel(widgets.Widget):
         self.label.setMargin(10)
         self.label.set_size_policy(horizontal="minimum")
         self.tooltip = tooltip
-        icon = gui.icon.get_icon(icon)
+        icon = iconprovider.get_icon(icon)
         self.icon = widgets.Label()
         self.icon.setToolTip(tooltip)
         self.icon.set_size_policy(horizontal="minimum")
@@ -32,15 +30,15 @@ class IconLabel(widgets.Widget):
         self.box.setSpacing(0)
         self.box.addStretch()
 
-    def __getattr__(self, value):
+    def __getattr__(self, value: str):
         return self.label.__getattribute__(value)
 
     def __repr__(self):
-        return f"IconLabel({self.text()!r})"
+        return f"{type(self).__name__}({self.text()!r})"
 
 
 if __name__ == "__main__":
     app = widgets.app()
     widget = IconLabel("test", tooltip="testus")
     widget.show()
-    app.exec_()
+    app.main_loop()
