@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
+from __future__ import annotations
 
 import pathlib
-from typing import Union, Optional
+from typing import Optional, Union
 
-from qtpy import QtCore, QtWidgets
+from qtpy import QtWidgets
 
 from prettyqt import gui, widgets
 
@@ -19,25 +19,7 @@ class Image(widgets.Label):
             self.set_image(path)
 
     def __repr__(self):
-        return f"Image({self.text()!r})"
-
-    def __bool__(self):
-        return not self.isNull()
-
-    def serialize_fields(self):
-        return dict(
-            text=self.text(),
-            scaled_contents=self.hasScaledContents(),
-            margin=self.margin(),
-            alignment=int(self.alignment()),
-        )
-
-    def __setstate__(self, state):
-        self.__init__()
-        self.setText(state.get("text", ""))
-        self.setMargin(state.get("margin", 0))
-        self.setAlignment(QtCore.Qt.Alignment(state.get("alignment")))
-        self.setScaledContents(state["scaled_contents"])
+        return f"{type(self).__name__}()"
 
     def set_image(self, path: Union[pathlib.Path, str], width: int = 300):
         self.setScaledContents(True)
@@ -49,7 +31,9 @@ class Image(widgets.Label):
         )
 
     @classmethod
-    def from_path(cls, path: Union[pathlib.Path, str], parent=None) -> "Image":
+    def from_path(
+        cls, path: Union[pathlib.Path, str], parent: Optional[QtWidgets.QWidget] = None
+    ) -> Image:
         pixmap = gui.Pixmap.from_file(path)
         label = cls(parent=parent)
         label.setPixmap(pixmap)
@@ -61,4 +45,5 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = Image("https://act-crm-addon.de/wp-content/uploads/2018/12/test.png")
     widget.show()
-    app.exec_()
+    bool(widget)
+    app.main_loop()
