@@ -1,7 +1,5 @@
-# -*- coding: utf-8 -*-
-
-from typing import Optional, Union
 import pathlib
+from typing import Optional, Union
 
 from qtpy import QtWidgets
 
@@ -27,4 +25,4 @@ class ImageViewer(widgets.Widget):
 if __name__ == "__main__":
     app = widgets.app()
     ex = ImageViewer()
-    app.exec_()
+    app.main_loop()
