@@ -1,7 +1,7 @@
-# -*- coding: utf-8 -*-
+from typing import List, Optional, Type, Union
 
-from typing import List, Union, Optional, Type
 from qtpy import QtWidgets
+
 from prettyqt import custom_validators, widgets
 from prettyqt.utils import helpers
 
@@ -37,5 +37,5 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = ListInput()
     widget.show()
-    app.exec_()
+    app.main_loop()
     print(widget.get_value())
