@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from typing import Optional
 
 from qtpy import QtWidgets
@@ -20,7 +18,7 @@ class OptionalWidget(widgets.GroupBox):
         self.widget = widget
         self.toggled.connect(self.widget.setEnabled)
 
-    def __getattr__(self, value):
+    def __getattr__(self, value: str):
         return self.widget.__getattribute__(value)
 
     @property
@@ -42,5 +40,5 @@ if __name__ == "__main__":
     img = widgets.RadioButton("test")
     widget = OptionalWidget(img, "Test")
     widget.show()
-    app.exec_()
+    app.main_loop()
     print(widget.enabled)
