@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from typing import Optional
 
 from qtpy import QtCore, QtWidgets
@@ -30,14 +28,14 @@ class PopupInfo(widgets.Dialog):
         layout += self.label
         # signals.signals.popup_info.connect(self.popup)
 
-    def show(self, *args, **kwargs):
+    def show(self):
         self.hide()
         screen_geo = gui.GuiApplication.primaryScreen().geometry()
         size = self.label.sizeHint()
-        x = (screen_geo.width() - size.width()) / 2
-        y = (screen_geo.height() - size.height()) / 2
+        x = (screen_geo.width() - size.width()) // 2
+        y = (screen_geo.height() - size.height()) // 2
         self.move(x, y - 200)
-        super().show(*args, **kwargs)
+        super().show()
         self.timer.start(2500)
 
     def show_popup(self, text: str):
@@ -49,4 +47,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = PopupInfo()
     widget.show_popup("test")
-    app.exec_()
+    app.main_loop()
