@@ -1,6 +1,6 @@
 """Module containing classes related to the RegEx editor."""
 
-from .editor import RegexEditorWidget
+from .regexeditorwidget import RegexEditorWidget
 
 
 __all__ = ["RegexEditorWidget"]
