@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-
-from typing import Optional
+from typing import Optional, Pattern, Union
 
 from qtpy import QtWidgets
 import regex as re
@@ -8,9 +6,18 @@ import regex as re
 from prettyqt import core, custom_validators, custom_widgets, widgets
 
 
+MAP = dict(
+    multiline=re.MULTILINE,
+    ignorecase=re.IGNORECASE,
+    ascii=re.ASCII,
+    dotall=re.DOTALL,
+    verbose=re.VERBOSE,
+)
+
+
 class RegexInput(widgets.Widget):
 
-    value_changed = core.Signal()
+    value_changed = core.Signal(object)
 
     def __init__(
         self,
@@ -32,33 +39,23 @@ class RegexInput(widgets.Widget):
             self.box[0, 2] = self.tb_flags
         if show_error:
             self.box[1, 0:2] = self.label_error
-        self.tb_flags.triggered.connect(self._on_value_change)
-        self.lineedit.textChanged.connect(self._on_value_change)
         val = custom_validators.RegexPatternValidator()
+        val.error_occured.connect(self.label_error.set_text)
+        val.pattern_updated.connect(self.value_changed)
+        self.tb_flags.value_changed.connect(self._on_value_change)
         self.lineedit.set_validator(val)
-        dct = {
-            "multiline": "MultiLine",
-            "ignorecase": "Ignore case",
-            "ascii": "ASCII-only matching",
-            "dotall": "Dot matches newline",
-            "verbose": "Ignore whitespace",
-        }
-        self._mapping = {
-            "ignorecase": re.IGNORECASE,
-            "multiline": re.MULTILINE,
-            "ascii": re.ASCII,
-            "dotall": re.DOTALL,
-            "verbose": re.VERBOSE,
-        }
+        dct = dict(
+            multiline="MultiLine",
+            ignorecase="Ignore case",
+            ascii="ASCII-only matching",
+            dotall="Dot matches newline",
+            verbose="Ignore whitespace",
+        )
         self.tb_flags.set_dict(dct)
 
-    def _on_value_change(self) -> None:
-        self.value_changed.emit()
-        if self.lineedit.is_valid():
-            self.label_error.set_text("")
-        elif self.lineedit.validator is not None:
-            message = self.lineedit.validator.error_message
-            self.label_error.set_text(message)
+    def _on_value_change(self):
+        val = self.get_value()
+        self.value_changed.emit(val)
 
     @property
     def pattern(self) -> str:
@@ -71,28 +68,28 @@ class RegexInput(widgets.Widget):
     @property
     def compile_flags(self) -> int:
         ret_val = 0
-        for identifier, flag in self._mapping.items():
+        for identifier, flag in MAP.items():
             if self.tb_flags[identifier]:
                 ret_val |= flag
         return ret_val
 
     @compile_flags.setter
     def compile_flags(self, value: int):
-        for identifier, flag in self._mapping.items():
+        for identifier, flag in MAP.items():
             self.tb_flags[identifier] = bool(value & flag)
 
-    def set_value(self, value):
+    def set_value(self, value: Optional[Union[str, Pattern]]):
         if value is None:
             self.pattern = ""
             self.flags = 0
-        if isinstance(value, str):
+        elif isinstance(value, str):
             self.pattern = value
             self.flags = 0
         else:
             self.pattern = value.pattern
             self.compile_flags = value.flags
 
-    def get_value(self):
+    def get_value(self) -> Pattern:
         return re.compile(self.pattern, self.compile_flags)
 
     def is_valid(self) -> bool:
@@ -101,6 +98,7 @@ class RegexInput(widgets.Widget):
 
 if __name__ == "__main__":
     app = widgets.app()
-    widget = RegexInput(show_flags=False, show_error=False)
+    widget = RegexInput(show_flags=True, show_error=True)
     widget.show()
-    app.exec_()
+    widget.value_changed.connect(print)
+    app.main_loop()
