@@ -1,11 +1,21 @@
-# -*- coding: utf-8 -*-
-
-from typing import Optional, Mapping, Iterable, Union, Dict, Any
+from typing import (
+    Any,
+    Dict,
+    Iterable,
+    Iterator,
+    Literal,
+    Mapping,
+    Optional,
+    Tuple,
+    Union,
+)
 
 from qtpy import QtWidgets
 
-from prettyqt import core, gui, widgets
-from prettyqt.utils import autoslot
+from prettyqt import constants, core, iconprovider, widgets
+
+
+TypeStr = Literal["string", "int", "float"]
 
 
 class SelectionWidget(widgets.GroupBox):
@@ -14,17 +24,17 @@ class SelectionWidget(widgets.GroupBox):
     def __init__(
         self,
         label: str = "",
-        layout: str = "horizontal",
+        layout: constants.OrientationStr = "horizontal",
         parent: Optional[QtWidgets.QWidget] = None,
     ):
         super().__init__(title=label, parent=parent)
         self.box = widgets.BoxLayout(layout)
         self.widget_custom: Optional[widgets.Widget] = None
         self.rb_other = widgets.RadioButton()
-        self.buttons: Dict[widgets.RadioButton, Any] = dict()
+        self.buttons: Dict[widgets.RadioButton, Any] = {}
         self.set_layout(self.box)
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[Tuple[widgets.RadioButton, Any]]:
         return iter(self.buttons.items())
 
     def add_items(self, items: Union[Iterable, Mapping]):
@@ -44,7 +54,8 @@ class SelectionWidget(widgets.GroupBox):
                 rb.setChecked(True)
                 break
 
-    def add(self, title: str, data=None):
+    def add(self, title: str, data=None, icon: iconprovider.IconType = None):
+        # TODO: make use of icon kwarg
         rb = widgets.RadioButton(title)
         rb.toggled.connect(self.update_choice)
         self.buttons[rb] = data
@@ -56,7 +67,7 @@ class SelectionWidget(widgets.GroupBox):
     def add_tooltip_icon(self, text: str):
         label = widgets.Label(text)
         label.setToolTip(text)
-        icon = gui.icon.get_icon("mdi.help-circle-outline")
+        icon = iconprovider.get_icon("mdi.help-circle-outline")
         pixmap = icon.pixmap(20, 20)
         label.setPixmap(pixmap)
         self.box += label
@@ -64,7 +75,7 @@ class SelectionWidget(widgets.GroupBox):
     def add_custom(
         self,
         label: str = "Other",
-        typ: str = "string",
+        typ: TypeStr = "string",
         default: Union[None, float, str] = None,
         regex: Optional[str] = None,
     ):
@@ -92,18 +103,18 @@ class SelectionWidget(widgets.GroupBox):
         layout += self.widget_custom
         self.box += layout
 
-    def current_choice(self):
+    def current_choice(self) -> Any:
         for k, v in self.buttons.items():
             if k.isChecked():
                 return v
         if self.rb_other.isChecked() and self.widget_custom is not None:
             return self.widget_custom.get_value()
-        return
+        return None
 
-    @autoslot.AutoSlot
+    @core.Slot(bool)
     def update_choice(self, checked: bool):
         if not checked:
-            return None
+            return
         choice = self.current_choice()
         if choice is not None:
             self.value_changed.emit(choice)
@@ -122,5 +133,5 @@ if __name__ == "__main__":
     widget.add_items(items)
     widget.add_custom(label="custom", typ="float")
     widget.show()
-    app.exec_()
+    app.main_loop()
     print(widget.get_value())
