@@ -1,23 +1,8 @@
-# -*- coding: utf-8 -*-
+from typing import Callable, Dict, Optional, Union
 
-from typing import Callable, Optional, Union, Dict
+from qtpy import QtCore, QtWidgets
 
-from qtpy import QtWidgets, QtCore, QtGui
-
-from prettyqt import gui, widgets
-
-
-def create_dot_pixmap(color="red", size=16):
-    col = gui.Color(color)
-    px = gui.Pixmap(size, size)
-    px.fill(QtCore.Qt.transparent)
-    px_size = px.rect().adjusted(1, 1, -1, -1)
-    with gui.Painter(px) as painter:
-        painter.setRenderHint(QtGui.QPainter.Antialiasing)
-        painter.setBrush(col)
-        painter.setPen(gui.Pen(gui.Color(15, 15, 15), 1.25))
-        painter.drawEllipse(px_size)
-    return px
+from prettyqt import gui, iconprovider, widgets
 
 
 class SidebarWidget(widgets.MainWindow):
@@ -31,8 +16,8 @@ class SidebarWidget(widgets.MainWindow):
         main_layout: Union[str, QtWidgets.QLayout] = "vertical",
     ):
         super().__init__(parent=parent)
-        self.button_map: Dict[QtWidgets.QWidget, QtWidgets.QToolButton] = dict()
-        self.icon_map: Dict[QtWidgets.QWidget, gui.Icon] = dict()
+        self.button_map: Dict[QtWidgets.QWidget, QtWidgets.QToolButton] = {}
+        self.icon_map: Dict[QtWidgets.QWidget, gui.Icon] = {}
         self.sidebar = widgets.ToolBar()
         self.sidebar.set_id("SidebarWidget")
         self.sidebar.set_title("Sidebar")
@@ -46,8 +31,7 @@ class SidebarWidget(widgets.MainWindow):
             self.settings_btn = self.sidebar.add_menu_button(
                 "", icon="mdi.wrench", menu=self.settings_menu
             )
-            self.settings_btn.setFixedWidth(self.BUTTON_WIDTH)
-            self.settings_btn.setFixedHeight(self.SETTINGS_BUTTON_HEIGHT)
+            self.settings_btn.setFixedSize(self.BUTTON_WIDTH, self.SETTINGS_BUTTON_HEIGHT)
             self.settings_btn.set_style("icon")
             self.sidebar.orientationChanged.connect(self._on_orientation_change)
             self.sidebar.add_separator()
@@ -64,17 +48,15 @@ class SidebarWidget(widgets.MainWindow):
 
     def _on_orientation_change(self, orientation: QtCore.Qt.Orientation):
         if orientation == QtCore.Qt.Horizontal:
-            self.settings_btn.setFixedWidth(34)
-            self.settings_btn.setFixedHeight(34)
+            self.settings_btn.setFixedSize(34, 34)
         else:
-            self.settings_btn.setFixedWidth(self.BUTTON_WIDTH)
-            self.settings_btn.setFixedHeight(self.SETTINGS_BUTTON_HEIGHT)
+            self.settings_btn.setFixedSize(self.BUTTON_WIDTH, self.SETTINGS_BUTTON_HEIGHT)
 
     def add_tab(
         self,
         item: QtWidgets.QWidget,
         title: str,
-        icon: gui.icon.IconType = None,
+        icon: iconprovider.IconType = None,
         show: bool = False,
         shortcut: Optional[str] = None,
         area: str = "top",
@@ -90,36 +72,40 @@ class SidebarWidget(widgets.MainWindow):
         # self.sidebar.add_separator()
         if area == "top":
             act = widgets.Action(
-                text=title, icon=icon, shortcut=shortcut, parent=self.sidebar
+                text=title,
+                icon=icon,
+                shortcut=shortcut,
+                parent=self.sidebar,
+                checkable=True,
+                callback=lambda: self.set_tab(item),
             )
-            act.setCheckable(True)
-            act.triggered.connect(lambda: self.set_tab(item))
             self.sidebar.insertAction(self.spacer_action, act)
         else:
             act = self.sidebar.add_action(
-                title, icon, lambda: self.set_tab(item), checkable=True
+                label=title,
+                icon=icon,
+                callback=lambda: self.set_tab(item),
+                checkable=True,
             )
         button = self.sidebar.widgetForAction(act)
         button.setFixedWidth(self.BUTTON_WIDTH)
         if len(self.area.box) == 1:
             button.setChecked(True)
         self.button_map[item] = button
-        self.icon_map[item] = gui.icon.get_icon(icon)
+        self.icon_map[item] = iconprovider.get_icon(icon)
         if show:
             self.area.box.setCurrentWidget(item)
 
     def set_marker(self, item: Union[str, int, widgets.Widget], color="red"):
         widget = self._get_widget(item)
         if widget == self._get_current_widget():
-            return None
+            return
         template = self.icon_map[widget]
         px = template.pixmap(100, 100)
-        painter = gui.Painter(px)
-        dot = create_dot_pixmap(color)
-        painter.drawPixmap(QtCore.QPoint(0, 0), dot)
-        painter.end()
-        icon = gui.Icon()
-        icon.addPixmap(px)
+        with gui.Painter(px) as painter:
+            dot = gui.Pixmap.create_dot(color)
+            painter.drawPixmap(0, 0, dot)
+        icon = gui.Icon(px)
         self.button_map[widget].set_icon(icon)
 
     def _get_widget(self, item: Union[str, int, widgets.Widget]):
@@ -135,6 +121,7 @@ class SidebarWidget(widgets.MainWindow):
         for k, v in self.button_map.items():
             if v.isChecked():
                 return k
+        raise RuntimeError("no page activated.")
 
     def set_tab(self, item: Union[str, int, widgets.Widget]):
         widget = self._get_widget(item)
@@ -155,7 +142,7 @@ class SidebarWidget(widgets.MainWindow):
     def add_action(
         self,
         title: str,
-        icon: gui.icon.IconType = None,
+        icon: iconprovider.IconType = None,
         callback: Callable = None,
         checkable: bool = False,
         shortcut: Optional[str] = None,
@@ -165,10 +152,13 @@ class SidebarWidget(widgets.MainWindow):
         #                                      icon=icon,
         #                                      callback=callback,
         #                                      checkable=checkable)
-        act = widgets.Action(text=title, icon=icon, shortcut=shortcut)
-        act.setCheckable(checkable)
-        if callback:
-            act.triggered.connect(callback)
+        act = widgets.Action(
+            text=title,
+            icon=icon,
+            shortcut=shortcut,
+            checkable=checkable,
+            callback=callback,
+        )
         if area == "top":
             self.sidebar.insertAction(self.spacer_action, act)
         if area == "bottom":
@@ -189,4 +179,4 @@ if __name__ == "__main__":
     ex.add_tab(page_3, "Help", "mdi.help-circle-outline")
     ex.set_marker(page_3)
     ex.show()
-    app.exec_()
+    app.main_loop()
