@@ -1,19 +1,17 @@
-# -*- coding: utf-8 -*-
-
 from typing import Optional
 
 from qtpy import QtWidgets
 
-from prettyqt import gui, widgets
+from prettyqt import widgets
 
 
 class SingleLineTextEdit(widgets.PlainTextEdit):
     def __init__(self, parent: Optional[QtWidgets.QWidget] = None):
         super().__init__(parent=parent)
         self.textChanged.connect(self._on_text_changed)
-        font_metrics = gui.FontMetrics(self.font())
+        font_metrics = self.get_font_metrics()
         self.row_height = font_metrics.lineSpacing()
-        self.setFixedHeight(self.row_height * 1.5)
+        self.setFixedHeight(int(self.row_height * 1.5))
         self.set_size_policy(vertical="fixed")
         self.set_line_wrap_mode("none")
         self.set_scrollbar_policy("always_off")
@@ -32,4 +30,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = SingleLineTextEdit()
     widget.show()
-    app.exec_()
+    app.main_loop()
