@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # The MIT License (MIT)
 
 # Copyright (c) 2011-2014 Marvin Killing
@@ -22,7 +20,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from typing import Tuple, Optional
+from typing import Literal, Optional, Tuple
 
 from qtpy import QtCore, QtWidgets
 
@@ -35,14 +33,25 @@ HANDLE_STYLE = widgets.Style.SC_SliderHandle
 GROOVE_STYLE = widgets.Style.SC_SliderGroove
 
 
-def clamp(v: float, lower: float, upper: float):
+MOVEMENT_MODE = ["no_crossing", "no_overlap", "free"]
+
+MovementModeStr = Literal["no_crossing", "no_overlap", "free"]
+
+HandleStr = Literal["upper", "lower"]
+
+ActionStr = Literal[
+    "single_step_add", "single_step_sub", "to_minimum", "to_maximum", "move", "none"
+]
+
+
+def clamp(v: float, lower: float, upper: float) -> float:
     return min(upper, max(lower, v))
 
 
 class SpanSlider(widgets.Slider):
-    value_changed = core.Signal(int, int)
-    lower_pos_changed = core.Signal(int)
-    upper_pos_changed = core.Signal(int)
+    value_changed = core.Signal(float, float)
+    lower_pos_changed = core.Signal(float)
+    upper_pos_changed = core.Signal(float)
     slider_pressed = core.Signal(object)
 
     def __init__(self, parent: Optional[QtWidgets.QWidget] = None):
@@ -50,36 +59,37 @@ class SpanSlider(widgets.Slider):
         self.rangeChanged.connect(self.update_range)
         self.sliderReleased.connect(self._move_pressed_handle)
 
-        self.lower = 0
-        self.upper = 0
-        self.lower_pos = 0
-        self.upper_pos = 0
+        self.lower_val = 0.0
+        self.upper_val = 0.0
+        self.lower_pos = 0.0
+        self.upper_pos = 0.0
         self.offset = 0
-        self.position = 0
+        self.position = 0.0
         self.last_pressed: Optional[str] = None
         self.upper_pressed = widgets.Style.SC_None
         self.lower_pressed = widgets.Style.SC_None
-        self.movement = "free"
-        self.main_control = "lower"
-        self.first_movement = False
-        self.block_tracking = False
-        self.gradient_left = self.palette().color(gui.Palette.Dark).lighter(110)
-        self.gradient_right = self.palette().color(gui.Palette.Dark).lighter(110)
+        self.movement: MovementModeStr = "no_crossing"
+        self._main_control: Literal["lower", "upper"] = "lower"
+        self._first_movement = False
+        self._block_tracking = False
+        dark_color = self.palette().color(gui.Palette.Dark)
+        self.gradient_left = dark_color.lighter(110)
+        self.gradient_right = dark_color.lighter(110)
 
     def mousePressEvent(self, event):
         if self.minimum() == self.maximum() or event.buttons() ^ event.button():
             event.ignore()
             return
 
-        self.upper_pressed = self.handle_mouse_press(
-            event.pos(), self.upper_pressed, self.upper, "upper"
+        self.upper_pressed = self._handle_mouse_press(
+            event.pos(), self.upper_pressed, self.upper_val, "upper"
         )
         if self.upper_pressed != HANDLE_STYLE:
-            self.lower_pressed = self.handle_mouse_press(
-                event.pos(), self.lower_pressed, self.lower, "lower"
+            self.lower_pressed = self._handle_mouse_press(
+                event.pos(), self.lower_pressed, self.lower_val, "lower"
             )
 
-        self.first_movement = True
+        self._first_movement = True
         event.accept()
 
     def mouseMoveEvent(self, event):
@@ -90,31 +100,32 @@ class SpanSlider(widgets.Slider):
         opt = widgets.StyleOptionSlider()
         self.initStyleOption(opt)
         m = self.style().pixelMetric(widgets.Style.PM_MaximumDragDistance, opt, self)
-        new_pos = self._pixel_pos_to_value(self.pick(event.pos()) - self.offset)
+        pixel_pos = self.pick(event.pos()) - self.offset
+        new_pos = float(self._pixel_pos_to_value(pixel_pos))
         if m >= 0:
             r = self.rect().adjusted(-m, -m, m, m)
             if not r.contains(event.pos()):
                 new_pos = self.position
 
         # pick the preferred handle on the first movement
-        if self.first_movement:
-            if self.lower == self.upper:
+        if self._first_movement:
+            if self.lower_val == self.upper_val:
                 if new_pos < self.lower_value:
                     self._swap_controls()
-                    self.first_movement = False
+                    self._first_movement = False
             else:
-                self.first_movement = False
+                self._first_movement = False
 
         if self.lower_pressed == HANDLE_STYLE:
             if self.movement == "no_crossing":
-                new_pos = min(new_pos, self.upper)
+                new_pos = min(new_pos, self.upper_val)
             elif self.movement == "no_overlap":
-                new_pos = min(new_pos, self.upper - 1)
+                new_pos = min(new_pos, self.upper_val - 1)
 
-            if self.movement == "free" and new_pos > self.upper:
+            if self.movement == "free" and new_pos > self.upper_val:
                 self._swap_controls()
                 self.set_upper_pos(new_pos)
-            else:
+            else:  # movement "none"
                 self.set_lower_pos(new_pos)
         elif self.upper_pressed == HANDLE_STYLE:
             if self.movement == "no_crossing":
@@ -122,10 +133,10 @@ class SpanSlider(widgets.Slider):
             elif self.movement == "no_overlap":
                 new_pos = max(new_pos, self.lower_value + 1)
 
-            if self.movement == "free" and new_pos < self.lower:
+            if self.movement == "free" and new_pos < self.lower_val:
                 self._swap_controls()
                 self.set_lower_pos(new_pos)
-            else:
+            else:  # movement "none"
                 self.set_upper_pos(new_pos)
         event.accept()
 
@@ -142,13 +153,13 @@ class SpanSlider(widgets.Slider):
         opt = widgets.StyleOptionSlider()
         self.initStyleOption(opt)
         opt.subControls = widgets.Style.SC_SliderTickmarks
-        painter.drawComplexControl(SLIDER_STYLE, opt)
+        painter.draw_complex_control("slider", opt)
 
         # groove
         opt.sliderPosition = 20
         opt.sliderValue = 0
         opt.subControls = GROOVE_STYLE
-        painter.drawComplexControl(SLIDER_STYLE, opt)
+        painter.draw_complex_control("slider", opt)
 
         # handle rects
         opt.sliderPosition = self.lower_pos
@@ -162,9 +173,10 @@ class SpanSlider(widgets.Slider):
         minv = min(lrv, urv)
         maxv = max(lrv, urv)
         c = self.style().subControlRect(SLIDER_STYLE, opt, GROOVE_STYLE, self).center()
-        rect = core.Rect(core.Point(c.x() - 2, minv), core.Point(c.x() + 1, maxv))
         if self.is_horizontal():
             rect = core.Rect(core.Point(minv, c.y() - 2), core.Point(maxv, c.y() + 1))
+        else:
+            rect = core.Rect(core.Point(c.x() - 2, minv), core.Point(c.x() + 1, maxv))
         self._draw_span(painter, rect)
 
         # handles
@@ -175,120 +187,118 @@ class SpanSlider(widgets.Slider):
             self.draw_handle(painter, "lower")
             self.draw_handle(painter, "upper")
 
-    @core.Property(int)
-    def lower_value(self) -> int:
-        return min(self.lower, self.upper)
+    @core.Property(float)
+    def lower_value(self) -> float:
+        return min(self.lower_val, self.upper_val)
 
-    def set_lower_value(self, lower: int):
-        self.set_span(lower, self.upper)
+    def set_lower_value(self, lower: float):
+        self.set_span(lower, self.upper_val)
 
-    @core.Property(int)
-    def upper_value(self):
-        return max(self.lower, self.upper)
+    @core.Property(float)
+    def upper_value(self) -> float:
+        return max(self.lower_val, self.upper_val)
 
-    def set_upper_value(self, upper: int):
-        self.set_span(self.lower, upper)
+    def set_upper_value(self, upper: float):
+        self.set_span(self.lower_val, upper)
 
     def on_value_change(self):
-        self.value_changed.emit(self.lower, self.upper)
+        self.value_changed.emit(self.lower_val, self.upper_val)
 
-    def get_value(self) -> Tuple[int, int]:
-        return (self.lower, self.upper)
+    def get_value(self) -> Tuple[float, float]:
+        return (self.lower_val, self.upper_val)
 
-    def set_value(self, value: Tuple[int, int]):
+    def set_value(self, value: Tuple[float, float]):
         self.set_lower_value(value[0])
         self.set_upper_value(value[1])
 
-    def get_movement_mode(self) -> str:
+    def get_movement_mode(self) -> MovementModeStr:
         return self.movement
 
-    def set_movement_mode(self, mode: str):
+    def set_movement_mode(self, mode: MovementModeStr):
         """Set movement mode.
 
-        Valid values: "no_crossing", "no_overlap", "free"
-
         Args:
-            modality: modality for the main window
+            mode: movement mode for the main window
 
         Raises:
-            ValueError: modality type does not exist
+            ValueError: movement mode type does not exist
         """
-        if mode not in ["no_crossing", "no_overlap", "free"]:
+        if mode not in MOVEMENT_MODE:
             raise ValueError("Invalid movement mode")
         self.movement = mode
 
-    def set_span(self, lower: int, upper: int):
+    def set_span(self, lower: float, upper: float):
         low = clamp(min(lower, upper), self.minimum(), self.maximum())
         upp = clamp(max(lower, upper), self.minimum(), self.maximum())
         changed = False
-        if low != self.lower:
-            self.lower = low
+        if low != self.lower_val:
+            self.lower_val = low
             self.lower_pos = low
             changed = True
-        if upp != self.upper:
-            self.upper = upp
+        if upp != self.upper_val:
+            self.upper_val = upp
             self.upper_pos = upp
             changed = True
         if changed:
             self.on_value_change()
             self.update()
 
-    def set_lower_pos(self, lower: int):
+    def set_lower_pos(self, lower: float):
         if self.lower_pos == lower:
-            return None
+            return
         self.lower_pos = lower
         if not self.hasTracking():
             self.update()
         if self.isSliderDown():
             self.lower_pos_changed.emit(lower)
-        if self.hasTracking() and not self.block_tracking:
-            main = self.main_control == "lower"
+        if self.hasTracking() and not self._block_tracking:
+            main = self._main_control == "lower"
             self.trigger_action("move", main)
 
-    def set_upper_pos(self, upper: int):
+    def set_upper_pos(self, upper: float):
         if self.upper_pos == upper:
-            return None
+            return
         self.upper_pos = upper
         if not self.hasTracking():
             self.update()
         if self.isSliderDown():
             self.upper_pos_changed.emit(upper)
-        if self.hasTracking() and not self.block_tracking:
-            main = self.main_control == "upper"
+        if self.hasTracking() and not self._block_tracking:
+            main = self._main_control == "upper"
             self.trigger_action("move", main)
 
     def set_left_color(self, color: colors.ColorType):
-        self.gradient_left = color
+        self.gradient_left = colors.get_color(color)
         self.update()
 
     def set_right_color(self, color: colors.ColorType):
-        self.gradient_right = color
+        self.gradient_right = colors.get_color(color)
         self.update()
 
     def _move_pressed_handle(self):
         if self.last_pressed == "lower":
-            if self.lower_pos != self.lower:
-                main = self.main_control == "lower"
+            if self.lower_pos != self.lower_val:
+                main = self._main_control == "lower"
                 self.trigger_action("move", main)
         elif self.last_pressed == "upper":
-            if self.upper_pos != self.upper:
-                main = self.main_control == "upper"
+            if self.upper_pos != self.upper_val:
+                main = self._main_control == "upper"
                 self.trigger_action("move", main)
 
     def pick(self, p: QtCore.QPoint) -> int:
         return p.x() if self.is_horizontal() else p.y()
 
-    def trigger_action(self, action: str, main: bool):
-        value = 0
+    def trigger_action(self, action: ActionStr, main: bool):
+        value = 0.0
         no = False
         up = False
         my_min = self.minimum()
         my_max = self.maximum()
-        self.block_tracking = True
-        main_control = main and self.main_control == "upper"
-        alt_control = not main and self.main_control == "lower"
+        self._block_tracking = True
+        main_control = main and self._main_control == "upper"
+        alt_control = not main and self._main_control == "lower"
         is_upper_handle = main_control or alt_control
-        val = self.upper if is_upper_handle else self.lower
+        val = self.upper_val if is_upper_handle else self.lower_val
         if action == "single_step_add":
             up = is_upper_handle
             value = clamp(val + self.singleStep(), my_min, my_max)
@@ -296,11 +306,11 @@ class SpanSlider(widgets.Slider):
             up = is_upper_handle
             value = clamp(val - self.singleStep(), my_min, my_max)
         elif action == "to_minimum":
+            up = is_upper_handle
             value = my_min
-            up = is_upper_handle
         elif action == "to_maximum":
-            value = my_max
             up = is_upper_handle
+            value = my_max
         elif action == "move":
             up = is_upper_handle
             no = True
@@ -309,40 +319,40 @@ class SpanSlider(widgets.Slider):
 
         if not no and not up:
             if self.movement == "no_crossing":
-                value = min(value, self.upper)
+                value = min(value, self.upper_val)
             elif self.movement == "no_overlap":
-                value = min(value, self.upper - 1)
+                value = min(value, self.upper_val - 1)
 
-            if self.movement == "free" and value > self.upper:
+            if self.movement == "free" and value > self.upper_val:
                 self._swap_controls()
                 self.set_upper_pos(value)
             else:
                 self.set_lower_pos(value)
         elif not no:
             if self.movement == "no_crossing":
-                value = max(value, self.lower)
+                value = max(value, self.lower_val)
             elif self.movement == "no_overlap":
-                value = max(value, self.lower + 1)
+                value = max(value, self.lower_val + 1)
 
-            if self.movement == "free" and value < self.lower:
+            if self.movement == "free" and value < self.lower_val:
                 self._swap_controls()
                 self.set_lower_pos(value)
             else:
                 self.set_upper_pos(value)
 
-        self.block_tracking = False
+        self._block_tracking = False
         self.set_lower_value(self.lower_pos)
         self.set_upper_value(self.upper_pos)
 
     def _swap_controls(self):
-        self.lower, self.upper = self.upper, self.lower
+        self.lower_val, self.upper_val = self.upper_val, self.lower_val
         self.lower_pressed, self.upper_pressed = self.upper_pressed, self.lower_pressed
         self.last_pressed = "upper" if self.last_pressed == "lower" else "lower"
-        self.main_control = "upper" if self.main_control == "lower" else "lower"
+        self._main_control = "upper" if self._main_control == "lower" else "lower"
 
     def update_range(self, min_, max_):
         # set_span() takes care of keeping span in range
-        self.set_span(self.lower, self.upper)
+        self.set_span(self.lower_val, self.upper_val)
 
     def _setup_painter(
         self,
@@ -364,18 +374,11 @@ class SpanSlider(widgets.Slider):
 
     def _draw_span(self, painter: widgets.StylePainter, rect: core.Rect):
         opt = widgets.StyleOptionSlider()
-        super().initStyleOption(opt)
-
-        # area
+        self.initStyleOption(opt)
+        painter.set_pen(color=self.gradient_left, width=0)
         groove = self.style().subControlRect(SLIDER_STYLE, opt, GROOVE_STYLE, self)
         if opt.is_horizontal():
             groove.adjust(0, 0, -1, 0)
-        else:
-            groove.adjust(0, 0, 0, -1)
-
-        # pen & brush
-        painter.set_pen(color=self.gradient_left, width=0)
-        if opt.is_horizontal():
             self._setup_painter(
                 painter,
                 opt.get_orientation(),
@@ -385,6 +388,7 @@ class SpanSlider(widgets.Slider):
                 groove.bottom(),
             )
         else:
+            groove.adjust(0, 0, 0, -1)
             self._setup_painter(
                 painter,
                 opt.get_orientation(),
@@ -401,9 +405,8 @@ class SpanSlider(widgets.Slider):
         gradient[1] = self.gradient_right
         painter.fillRect(intersected, gradient)
 
-    def draw_handle(self, painter: widgets.StylePainter, handle: str):
-        opt = widgets.StyleOptionSlider()
-        self._init_style_option(opt, handle)
+    def draw_handle(self, painter: widgets.StylePainter, handle: HandleStr):
+        opt = self.get_style_option(handle)
         opt.subControls = HANDLE_STYLE
         pressed = self.upper_pressed
         if handle == "lower":
@@ -412,20 +415,23 @@ class SpanSlider(widgets.Slider):
         if pressed == HANDLE_STYLE:
             opt.activeSubControls = pressed
             opt.state |= widgets.Style.State_Sunken
-        painter.drawComplexControl(SLIDER_STYLE, opt)
+        painter.draw_complex_control("slider", opt)
 
-    def _init_style_option(self, option, handle: str):
+    def get_style_option(self, handle: HandleStr) -> widgets.StyleOptionSlider:
+        option = widgets.StyleOptionSlider()
         self.initStyleOption(option)
-
-        option.sliderPosition = self.upper_pos
-        option.sliderValue = self.upper
         if handle == "lower":
             option.sliderPosition = self.lower_pos
-            option.sliderValue = self.lower
+            option.sliderValue = self.lower_val
+        else:
+            option.sliderPosition = self.upper_pos
+            option.sliderValue = self.upper_val
+        return option
 
-    def handle_mouse_press(self, pos: QtCore.QPoint, control, value, handle: str):
-        opt = widgets.StyleOptionSlider()
-        self._init_style_option(opt, handle)
+    def _handle_mouse_press(
+        self, pos: QtCore.QPoint, control, value: float, handle: HandleStr
+    ):
+        opt = self.get_style_option(handle)
         old_control = control
         control = self.style().hitTestComplexControl(SLIDER_STYLE, opt, pos, self)
         sr = self.style().subControlRect(SLIDER_STYLE, opt, HANDLE_STYLE, self)
@@ -439,7 +445,7 @@ class SpanSlider(widgets.Slider):
             self.update(sr)
         return control
 
-    def _pixel_pos_to_value(self, pos: int):
+    def _pixel_pos_to_value(self, pos: int) -> int:
         opt = widgets.StyleOptionSlider()
         self.initStyleOption(opt)
         gr = self.style().subControlRect(SLIDER_STYLE, opt, GROOVE_STYLE, self)
@@ -447,17 +453,17 @@ class SpanSlider(widgets.Slider):
         if self.is_horizontal():
             len_slider = sr.width()
             slider_min = gr.x()
-            slider_max = gr.right() - len_slider + 1
+            slider_end = gr.right()
         else:
             len_slider = sr.height()
             slider_min = gr.y()
-            slider_max = gr.bottom() - len_slider + 1
+            slider_end = gr.bottom()
 
         return widgets.Style.sliderValueFromPosition(
             self.minimum(),
             self.maximum(),
             pos - slider_min,
-            slider_max - slider_min,
+            slider_end - len_slider + 1 - slider_min,
             opt.upsideDown,
         )
 
@@ -493,4 +499,4 @@ if __name__ == "__main__":
     # slider.set_left_color(color)
     # slider.set_right_color(color)
     slider.show()
-    app.exec_()
+    app.main_loop()
