@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-
-from typing import Union, Optional
+from typing import Optional, Union
 
 from qtpy import QtWidgets
 
@@ -61,5 +59,5 @@ if __name__ == "__main__":
     widget = StringOrNumberWidget("Test")
     widget.value_changed.connect(print)
     widget.show()
-    app.exec_()
+    app.main_loop()
     print(widget.enabled)
