@@ -1,17 +1,35 @@
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
+from typing import Union
 
 from qtpy import QtGui
 
 
 class Color(QtGui.QColor):
+    def __init__(self, *args, **kwargs):
+        # PySide2 workaround
+        if len(args) == 1:
+            if isinstance(args[0], QtGui.QColor):
+                super().__init__(args[0].name())
+            elif isinstance(args[0], str):
+                super().__init__()
+                self.set_color(args[0])
+            else:
+                super().__init__(*args, **kwargs)
+        else:
+            super().__init__(*args, **kwargs)
+
     def __repr__(self):
-        return f"Color({self.red()}, {self.green()}, {self.blue()}, {self.alpha()})"
+        return (
+            f"{type(self).__name__}({self.red()}, {self.green()}, "
+            f"{self.blue()}, {self.alpha()})"
+        )
 
     def __str__(self):
         return self.name()
 
     def __reduce__(self):
-        return (self.__class__, (self.red(), self.green(), self.blue(), self.alpha()))
+        return type(self), (self.red(), self.green(), self.blue(), self.alpha())
 
     def serialize_fields(self):
         return dict(color=self.toString())
@@ -19,17 +37,16 @@ class Color(QtGui.QColor):
     def serialize(self):
         return self.serialize_fields()
 
-    def set_color(self, color):
+    def set_color(self, color: Union[str, tuple]):
         if isinstance(color, str):
             self.setNamedColor(color)
         else:
             self.setRgb(*color)
 
     @classmethod
-    def from_text(cls, text):
+    def from_text(cls, text: str) -> Color:
         """Create a QColor from specified string."""
         color = cls()
-        text = str(text)
         if text.startswith("#") and len(text) == 7:
             correct = "#0123456789abcdef"
             for char in text:
@@ -41,7 +58,7 @@ class Color(QtGui.QColor):
         return color
 
     @classmethod
-    def from_cmyk(cls, *args, **kwargs):
+    def from_cmyk(cls, *args, **kwargs) -> Color:
         return cls(cls.fromCmykF(*args, **kwargs))
 
     def as_qt(self) -> QtGui.QColor:
