@@ -1,9 +1,7 @@
-# -*- coding: utf-8 -*-
-
-from typing import Union
 import pathlib
+from typing import Union
 
-from qtpy import QtGui, QtCore
+from qtpy import QtCore, QtGui
 
 from prettyqt import core
 
@@ -11,4 +9,4 @@ from prettyqt import core
 class DesktopServices(QtGui.QDesktopServices):
     @classmethod
     def open_url(cls, location: Union[str, pathlib.Path, QtCore.QUrl]) -> bool:
-        return cls.openUrl(core.Url(location))
+        return cls.openUrl(core.Url.from_user_input(str(location)))
