@@ -1,21 +1,13 @@
-# -*- coding: utf-8 -*-
-
-from typing import Union
 import contextlib
+from typing import Iterator, List, Literal, Union
 
 from qtpy import QtCore, QtGui
 
-from prettyqt import core, gui
-from prettyqt.utils import bidict, colors, InvalidParamError
+from prettyqt import constants, core, gui
+from prettyqt.utils import InvalidParamError, bidict, colors
 
 
-PEN_STYLES = gui.pen.PEN_STYLES  # type: ignore
-
-JOIN_STYLES = gui.pen.JOIN_STYLES  # type: ignore
-
-CAP_STYLES = gui.pen.CAP_STYLES  # type: ignore
-
-COMP_MODES = bidict(
+COMPOSITION_MODE = bidict(
     source_over=QtGui.QPainter.CompositionMode_SourceOver,
     destination_over=QtGui.QPainter.CompositionMode_DestinationOver,
     clear=QtGui.QPainter.CompositionMode_Clear,
@@ -29,31 +21,33 @@ COMP_MODES = bidict(
     destination_atop=QtGui.QPainter.CompositionMode_DestinationAtop,
 )
 
-PATTERNS = bidict(
-    solid=QtCore.Qt.SolidPattern,
-    none=QtCore.Qt.NoBrush,
-    cross=QtCore.Qt.CrossPattern,
-    linear_gradient=QtCore.Qt.LinearGradientPattern,
-    radial_gradient=QtCore.Qt.RadialGradientPattern,
-)
-
-CLIP_OPERATIONS = bidict(
-    none=QtCore.Qt.NoClip,
-    replace=QtCore.Qt.ReplaceClip,
-    intersect=QtCore.Qt.IntersectClip,
-)
+CompositionModeStr = Literal[
+    "source_over",
+    "destination_over",
+    "clear",
+    "source",
+    "destination",
+    "source_in",
+    "destination_in",
+    "source_out",
+    "destination_out",
+    "source_atop",
+    "destination_atop",
+]
 
 RENDER_HINTS = bidict(
     antialiasing=QtGui.QPainter.Antialiasing,
     text_antialiasing=QtGui.QPainter.TextAntialiasing,
     smooth_pixmap_transform=QtGui.QPainter.SmoothPixmapTransform,
-    high_quality_antialiasing=QtGui.QPainter.HighQualityAntialiasing,
-    noncosmetic_default_pen=QtGui.QPainter.NonCosmeticDefaultPen,
-    qt4_compatible_painting=QtGui.QPainter.Qt4CompatiblePainting,
     lossless_image_rendering=QtGui.QPainter.LosslessImageRendering,
 )
 
-FILL_RULES = bidict(odd_even=QtCore.Qt.OddEvenFill, winding=QtCore.Qt.WindingFill)
+RenderHintStr = Literal[
+    "antialiasing",
+    "text_antialiasing",
+    "smooth_pixmap_transform",
+    "lossless_image_rendering",
+]
 
 
 class Painter(QtGui.QPainter):
@@ -69,6 +63,24 @@ class Painter(QtGui.QPainter):
         yield self
         self.end()
 
+    @contextlib.contextmanager
+    def backup_state(self):
+        self.save()
+        yield self
+        self.restore()
+
+    @contextlib.contextmanager
+    def native_mode(self):
+        self.beginNativePainting()
+        yield self
+        self.endNativePainting()
+
+    @contextlib.contextmanager
+    def edit_pen(self) -> Iterator[gui.Pen]:
+        pen = gui.Pen(self.pen())
+        yield pen
+        self.setPen(pen)
+
     def draw_image(
         self,
         target: Union[QtCore.QPoint, QtCore.QPointF, QtCore.QRect, QtCore.QRectF],
@@ -77,19 +89,28 @@ class Painter(QtGui.QPainter):
         self.set_composition_mode("source_atop")
         self.drawImage(target, frame_buffer)
 
-    def draw_polygon(self, *args, fill_rule: str = "odd_even"):
-        if fill_rule not in FILL_RULES:
-            raise InvalidParamError(fill_rule, FILL_RULES)
-        self.drawPolygon(*args, fillRule=FILL_RULES[fill_rule])
+    def draw_polygon(
+        self,
+        points: Union[
+            QtGui.QPolygon, QtGui.QPolygonF, List[QtCore.QPoint], List[QtCore.QPointF]
+        ],
+        fill_rule: constants.FillRuleStr = "odd_even",
+    ):
+        if fill_rule not in constants.FILL_RULE:
+            raise InvalidParamError(fill_rule, constants.FILL_RULE)
+        self.drawPolygon(points, fillRule=constants.FILL_RULE[fill_rule])  # type: ignore
 
     def use_antialiasing(self):
         self.setRenderHint(self.Antialiasing, True)
 
     def fill_rect(
-        self, rect: Union[QtCore.QRectF, QtCore.QRect], color, pattern: str = "solid"
+        self,
+        rect: Union[QtCore.QRectF, QtCore.QRect],
+        color,
+        pattern: constants.PatternStr = "solid",
     ):
-        if pattern not in PATTERNS:
-            raise InvalidParamError(pattern, PATTERNS)
+        if pattern not in constants.PATTERN:
+            raise InvalidParamError(pattern, constants.PATTERN)
         if isinstance(rect, tuple):
             rect = core.Rect(*rect)
         if isinstance(color, str):
@@ -97,16 +118,16 @@ class Painter(QtGui.QPainter):
                 raise ValueError("Invalid value for color.")
             color = gui.Color(color)
         if pattern != "solid":
-            color = gui.Brush(color, PATTERNS[pattern])
+            color = gui.Brush(color, constants.PATTERN[pattern])
         self.fillRect(rect, color)
 
     def set_pen(
         self,
-        style: str = "solid",
-        width: int = 1,
+        style: constants.PenStyleStr = "solid",
+        width: float = 1.0,
         color: colors.ColorType = "black",
-        join_style: str = "bevel",
-        cap_style: str = "square",
+        join_style: constants.JoinStyleStr = "bevel",
+        cap_style: constants.CapStyleStr = "square",
     ):
         """Set pen to use.
 
@@ -121,11 +142,11 @@ class Painter(QtGui.QPainter):
         pen.set_style(style)
         pen.set_cap_style(cap_style)
         pen.set_join_style(join_style)
-        pen.setWidth(width)
+        pen.setWidthF(width)
         pen.set_color(color)
         self.setPen(pen)
 
-    def get_pen(self) -> str:
+    def get_pen(self) -> gui.Pen:
         """Return current pen.
 
         Returns:
@@ -146,39 +167,40 @@ class Painter(QtGui.QPainter):
         mode = QtCore.Qt.TransparentMode if transparent else QtCore.Qt.OpaqueMode
         self.setBackgroundMode(mode)
 
-    def set_composition_mode(self, mode: str):
+    def set_composition_mode(self, mode: CompositionModeStr):
         """Set the current composition mode.
 
-        Possible values: "source_over", "destination_over", "clear", "source",
-                         "destination", "source_in", "destination_in", "source_out",
-                         "destination_out", "source_atop", "destination_atop",
-
         Raises:
             InvalidParamError: composition mode does not exist
         """
-        if mode not in COMP_MODES:
-            raise InvalidParamError(mode, COMP_MODES)
-        self.setCompositionMode(COMP_MODES[mode])
+        if mode not in COMPOSITION_MODE:
+            raise InvalidParamError(mode, COMPOSITION_MODE)
+        self.setCompositionMode(COMPOSITION_MODE[mode])
 
-    def get_composition_mode(self) -> str:
+    def get_composition_mode(self) -> CompositionModeStr:
         """Get the current composition mode.
 
-        Possible values: "source_over", "destination_over", "clear", "source",
-                         "destination", "source_in", "destination_in", "source_out",
-                         "destination_out", "source_atop", "destination_atop",
-
         Returns:
             composition mode
         """
-        return COMP_MODES.inv[self.compositionMode()]
+        return COMPOSITION_MODE.inverse[self.compositionMode()]
 
-    def set_clip_path(self, path: QtGui.QPainterPath, operation: str = "replace"):
-        if operation not in CLIP_OPERATIONS:
-            raise InvalidParamError(operation, CLIP_OPERATIONS)
-        self.setClipPath(path, CLIP_OPERATIONS[operation])
+    def set_clip_path(
+        self, path: QtGui.QPainterPath, operation: constants.ClipOperationStr = "replace"
+    ):
+        if operation not in constants.CLIP_OPERATION:
+            raise InvalidParamError(operation, constants.CLIP_OPERATION)
+        self.setClipPath(path, constants.CLIP_OPERATION[operation])
+
+    def get_text_rect(self, text: str) -> core.Rect:
+        return self.drawText(core.Rect(), QtCore.Qt.TextDontPrint, text)  # type: ignore
 
     @contextlib.contextmanager
-    def clip_path(self, operation: str = "replace"):
+    def clip_path(self, operation: constants.ClipOperationStr = "replace"):
         path = gui.PainterPath()
         yield path
         self.set_clip_path(path, operation)
+
+
+if __name__ == "__main__":
+    painter = Painter()
