@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+from typing import Iterator, Optional, Pattern, Tuple
 
-from qtpy import QtGui
+from qtpy import QtCore, QtGui
 
-from prettyqt import core
+from prettyqt import core, gui
 
 
 QtGui.QSyntaxHighlighter.__bases__ = (core.Object,)
@@ -12,11 +12,11 @@ class SyntaxHighlighter(QtGui.QSyntaxHighlighter):
 
     RULES: list = []
 
-    def __init__(self, parent=None):
-        super().__init__(parent)
+    def __init__(self, parent: Optional[QtCore.QObject] = None):
+        super().__init__(parent)  # type: ignore
 
     @classmethod
-    def yield_rules(cls):
+    def yield_rules(cls) -> Iterator[Tuple[Pattern, int, gui.TextCharFormat]]:
         for Rule in cls.RULES:
             if isinstance(Rule.compiled, list):
                 for i in Rule.compiled:
