@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtGui
 
 
@@ -13,5 +11,5 @@ class TextBlockUserData(QtGui.QTextBlockUserData):
 
     def __repr__(self):
         attrs = [i for i in dir(self) if not i.startswith("__")]
-        kwds = ", ".join("%s=%r" % (attr, getattr(self, attr)) for attr in attrs)
-        return f"{self.__class__.__name__}({kwds})"
+        kwds = ", ".join(f"{attr}={getattr(self, attr)!r}" for attr in attrs)
+        return f"{type(self).__name__}({kwds})"
