@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+from __future__ import annotations
 
 from qtpy import QtGui
 
@@ -10,13 +10,12 @@ QtGui.QValidator.__bases__ = (core.Object,)
 
 class Validator(QtGui.QValidator):
     def __repr__(self):
-        return f"{self.__class__.__name__}()"
+        return f"{type(self).__name__}()"
 
-    def __add__(self, other):
-        if isinstance(other, Validator):
-            from prettyqt import custom_validators
+    def __add__(self, other: Validator):
+        from prettyqt import custom_validators
 
-            return custom_validators.CompositeValidator([self, other])
+        return custom_validators.CompositeValidator([self, other])
 
     def __radd__(self, other: QtGui.QValidator):
         """Needed for sum()."""
@@ -24,7 +23,7 @@ class Validator(QtGui.QValidator):
 
     def is_valid_value(self, value: str, pos: int = 0) -> bool:
         val = self.validate(value, pos)
-        return val[0] == self.Acceptable
+        return val[0] == self.Acceptable  # type: ignore
 
 
 if __name__ == "__main__":
