@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+from typing import Literal
 
 from qtpy import QtMultimedia
 
@@ -12,15 +12,21 @@ STATES = bidict(
     paused=QtMultimedia.QMediaPlayer.PausedState,
 )
 
-ERRORS = bidict(
+StateStr = Literal["stopped", "playing", "paused"]
+
+ERROR = bidict(
     none=QtMultimedia.QMediaPlayer.NoError,
     resource=QtMultimedia.QMediaPlayer.ResourceError,
     format=QtMultimedia.QMediaPlayer.FormatError,
     network=QtMultimedia.QMediaPlayer.NetworkError,
-    access_denies=QtMultimedia.QMediaPlayer.AccessDeniedError,
+    access_denied=QtMultimedia.QMediaPlayer.AccessDeniedError,
     service_missing=QtMultimedia.QMediaPlayer.ServiceMissingError,
 )
 
+ErrorStr = Literal[
+    "none", "resource", "format", "network", "access_denied", "service_missing"
+]
+
 MEDIA_STATUS = bidict(
     unknown=QtMultimedia.QMediaPlayer.UnknownMediaStatus,
     no_media=QtMultimedia.QMediaPlayer.NoMedia,
@@ -33,27 +39,42 @@ MEDIA_STATUS = bidict(
     invalid=QtMultimedia.QMediaPlayer.InvalidMedia,
 )
 
+MediaStatusStr = Literal[
+    "unknown",
+    "no_media",
+    "loading",
+    "loaded",
+    "stalled",
+    "buffering",
+    "buffered",
+    "end",
+    "invalid",
+]
+
 QtMultimedia.QMediaPlayer.__bases__ = (multimedia.MediaObject,)
 
 
 class MediaPlayer(QtMultimedia.QMediaPlayer):
-    def get_state(self) -> str:
+    def get_state(self) -> StateStr:
         """Return current state.
 
-        Possible values: "stopped", "playing", "paused"
-
         Returns:
             state
         """
-        return STATES.inv[self.state()]
+        return STATES.inverse[self.state()]
 
-    def get_media_status(self) -> str:
+    def get_media_status(self) -> MediaStatusStr:
         """Return current media status.
 
-        Possible values: "unknown", "no_media", "loading", "loaded", "stalled",
-                         "buffering", "buffered", "end", "invalid"
-
         Returns:
             media status
         """
-        return MEDIA_STATUS.inv[self.mediaStatus()]
+        return MEDIA_STATUS.inverse[self.mediaStatus()]
+
+    def get_error(self) -> ErrorStr:
+        """Return error type.
+
+        Returns:
+            error type
+        """
+        return ERROR.inverse[self.error()]
