@@ -1,15 +1,13 @@
-# -*- coding: utf-8 -*-
-
 import pathlib
-from typing import Union, Optional
+from typing import Iterator, Literal, Optional, Union
 
 from qtpy import QtMultimedia
 
 from prettyqt import core, multimedia
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt.utils import InvalidParamError, bidict
 
 
-PLAYBACK_MODES = bidict(
+PLAYBACK_MODE = bidict(
     item_once=QtMultimedia.QMediaPlaylist.CurrentItemOnce,
     item_in_loop=QtMultimedia.QMediaPlaylist.CurrentItemInLoop,
     sequential=QtMultimedia.QMediaPlaylist.Sequential,
@@ -17,6 +15,8 @@ PLAYBACK_MODES = bidict(
     random=QtMultimedia.QMediaPlaylist.Random,
 )
 
+PlaybackModeStr = Literal["item_once", "item_in_loop", "sequential", "loop", "random"]
+
 QtMultimedia.QMediaPlaylist.__bases__ = (core.Object, multimedia.MediaBindableInterface)
 
 
@@ -26,13 +26,13 @@ class MediaPlaylist(QtMultimedia.QMediaPlaylist):
     def __len__(self) -> int:
         return self.mediaCount()
 
-    def __getitem__(self, item):
+    def __getitem__(self, item: int) -> multimedia.MediaContent:
         return multimedia.MediaContent(self.media(item))
 
-    def __delitem__(self, item):
+    def __delitem__(self, item: int):
         self.removeMedia(item)
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[multimedia.MediaContent]:
         return iter(self[i] for i in range(self.mediaCount()))
 
     # def serialize(self):
@@ -50,10 +50,12 @@ class MediaPlaylist(QtMultimedia.QMediaPlaylist):
         else:
             return self.insertMedia(pos, mediacontent)
 
-    def set_playback_mode(self, mode: str):
-        """Set playback mode for given item view.
+    def get_media_url(self, index: int) -> core.Url:
+        url = self.media(index).request().url()
+        return core.Url(url)
 
-        Allowed values are "item_once", "item_in_loop", "sequential", "loop", "random"
+    def set_playback_mode(self, mode: PlaybackModeStr):
+        """Set playback mode for given item view.
 
         Args:
             mode: playback mode to use
@@ -61,19 +63,17 @@ class MediaPlaylist(QtMultimedia.QMediaPlaylist):
         Raises:
             InvalidParamError: mode does not exist
         """
-        if mode not in PLAYBACK_MODES:
-            raise InvalidParamError(mode, PLAYBACK_MODES)
-        self.setPlaybackMode(PLAYBACK_MODES[mode])
+        if mode not in PLAYBACK_MODE:
+            raise InvalidParamError(mode, PLAYBACK_MODE)
+        self.setPlaybackMode(PLAYBACK_MODE[mode])
 
-    def get_playback_mode(self) -> str:
+    def get_playback_mode(self) -> PlaybackModeStr:
         """Return current playback mode.
 
-        Possible values: "item_once", "item_in_loop", "sequential", "loop", "random"
-
         Returns:
             playback mode
         """
-        return PLAYBACK_MODES.inv[self.playbackMode()]
+        return PLAYBACK_MODE.inverse[self.playbackMode()]
 
     # def on_playback_mode_changed(self, mode: int):
-    #     self.playback_mode_changed.emit(PLAYBACK_MODES.inv[mode])
+    #     self.playback_mode_changed.emit(PLAYBACK_MODE.inverse[mode])
