@@ -1,12 +1,14 @@
-# -*- coding: utf-8 -*-
-from dataclasses import dataclass, asdict
-from typing import Tuple, Dict, Any
+from __future__ import annotations
+
+from dataclasses import asdict, dataclass
+from typing import Any, Dict, Iterator, Literal, Tuple
 
 from qtpy import QtMultimedia
 
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt.utils import InvalidParamError, bidict
 
-QUALITIES = bidict(
+
+QUALITY = bidict(
     very_low=QtMultimedia.QMultimedia.VeryLowQuality,
     low=QtMultimedia.QMultimedia.LowQuality,
     normal=QtMultimedia.QMultimedia.NormalQuality,
@@ -14,21 +16,25 @@ QUALITIES = bidict(
     very_high=QtMultimedia.QMultimedia.VeryHighQuality,
 )
 
-ENCODING_MODES = bidict(
+QualityStr = Literal["very_low", "low", "normal", "high", "very_high"]
+
+ENCODING_MODE = bidict(
     constant_quality=QtMultimedia.QMultimedia.ConstantQualityEncoding,
     constant_bit_rate=QtMultimedia.QMultimedia.ConstantBitRateEncoding,
     average_bit_rate=QtMultimedia.QMultimedia.AverageBitRateEncoding,
     two_pass_encoding=QtMultimedia.QMultimedia.TwoPassEncoding,
 )
 
+EncodingModeStr = Literal["constant_quality", "constant_bit_rate", "average_bit_rate"]
+
 
 @dataclass
-class Settings(object):
+class Settings:
     bitrate: int
     codec: str
-    encoding_mode: str
+    encoding_mode: EncodingModeStr
     encoding_options: Dict[str, Any]
-    quality: str
+    quality: QualityStr
     frame_rate: float
     resolution: Tuple[int, int]
 
@@ -53,27 +59,27 @@ class VideoEncoderSettings(QtMultimedia.QVideoEncoderSettings):
         elif index == "quality":
             self.set_quality(value)
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[str]:
         return iter(self.to_dict().keys())
 
     def __len__(self):
         return len(self.to_dict())
 
-    def set_encoding_mode(self, mode: str):
-        if mode not in ENCODING_MODES:
-            raise InvalidParamError(mode, ENCODING_MODES)
-        self.setEncodingMode(ENCODING_MODES[mode])
+    def set_encoding_mode(self, mode: EncodingModeStr):
+        if mode not in ENCODING_MODE:
+            raise InvalidParamError(mode, ENCODING_MODE)
+        self.setEncodingMode(ENCODING_MODE[mode])
 
-    def get_encoding_mode(self) -> str:
-        return ENCODING_MODES.inv[self.encodingMode()]
+    def get_encoding_mode(self) -> EncodingModeStr:
+        return ENCODING_MODE.inverse[self.encodingMode()]
 
-    def set_quality(self, quality: str):
-        if quality not in QUALITIES:
-            raise InvalidParamError(quality, QUALITIES)
-        self.setQuality(QUALITIES[quality])
+    def set_quality(self, quality: QualityStr):
+        if quality not in QUALITY:
+            raise InvalidParamError(quality, QUALITY)
+        self.setQuality(QUALITY[quality])
 
-    def get_quality(self) -> str:
-        return QUALITIES.inv[self.quality()]
+    def get_quality(self) -> QualityStr:
+        return QUALITY.inverse[self.quality()]
 
     def to_dataclass(self) -> Settings:
         size = self.resolution()
@@ -91,7 +97,7 @@ class VideoEncoderSettings(QtMultimedia.QVideoEncoderSettings):
         return asdict(self.to_dataclass())
 
     @classmethod
-    def from_dataclass(cls, data: Settings) -> "VideoEncoderSettings":
+    def from_dataclass(cls, data: Settings) -> VideoEncoderSettings:
         instance = cls()
         instance.setBitRate(data.bitrate)
         instance.setCodec(data.codec)
@@ -103,6 +109,6 @@ class VideoEncoderSettings(QtMultimedia.QVideoEncoderSettings):
         return instance
 
     @classmethod
-    def from_dict(cls, data: Dict[str, Any]) -> "VideoEncoderSettings":
+    def from_dict(cls, data: Dict[str, Any]) -> VideoEncoderSettings:
         settings = Settings(**data)
         return cls.from_dataclass(settings)
