@@ -1,19 +1,21 @@
-# -*- coding: utf-8 -*-
-
-import pathlib
 import logging
+import pathlib
+from typing import Union
 
 from pygments.formatters.html import HtmlFormatter
 from pygments.lexer import Error, RegexLexer, Text, _TokenType
 from pygments.lexers import get_lexer_by_name, load_lexer_from_file
+from pygments.style import Style
 from pygments.styles import get_style_by_name
+from qtpy import QtGui
 
 from prettyqt import gui
 
+
 logger = logging.getLogger(__name__)
 
 
-def qstring_length(text):
+def qstring_length(text: str) -> int:
     """Tries to compute what the length of an utf16-encoded QString would be."""
     utf16_text = text.encode("utf16")
     length = len(utf16_text) // 2
@@ -24,7 +26,7 @@ def qstring_length(text):
     return length
 
 
-def get_tokens_unprocessed(self, text, stack=("root",)):
+def get_tokens_unprocessed(self, text: str, stack=("root",)):
     """Split ``text`` into (tokentype, text) pairs.
 
     Monkeypatched to store the final stack on the object itself.
@@ -99,7 +101,7 @@ class PygmentsHighlighter(gui.SyntaxHighlighter):
     #  "QSyntaxHighlighter" interface
     # ---------------------------------------------------------------------------
 
-    def __init__(self, parent, lexer=None):
+    def __init__(self, parent: QtGui.QTextDocument, lexer: str):
         super().__init__(parent)
         self._document = self.document()
         self._formatter = HtmlFormatter(nowrap=True)
@@ -136,14 +138,14 @@ class PygmentsHighlighter(gui.SyntaxHighlighter):
     # "PygmentsHighlighter" interface
     # ---------------------------------------------------------------------------
 
-    def set_style(self, style):
+    def set_style(self, style: Union[str, Style]):
         """Sets the style to the specified Pygments style."""
         if isinstance(style, str):
             style = get_style_by_name(style)
         self._style = style
         self._clear_caches()
 
-    def set_style_sheet(self, stylesheet):
+    def set_style_sheet(self, stylesheet: str):
         """Sets a CSS stylesheet.
 
         The classes in the stylesheet should correspond to those generated by:
@@ -166,7 +168,7 @@ class PygmentsHighlighter(gui.SyntaxHighlighter):
         self._brushes = {}
         self._formats = {}
 
-    def _get_format(self, token):
+    def _get_format(self, token: str) -> QtGui.QTextCharFormat:
         """Returns a QTextCharFormat for token or None."""
         if token in self._formats:
             return self._formats[token]
@@ -179,19 +181,20 @@ class PygmentsHighlighter(gui.SyntaxHighlighter):
         self._formats[token] = result
         return result
 
-    def _get_format_from_document(self, token, document):
+    def _get_format_from_document(
+        self, token: str, document: QtGui.QTextDocument
+    ) -> QtGui.QTextCharFormat:
         """Return a QTextCharFormat for token from document."""
         code, html = next(self._formatter._format_lines([(token, "dummy")]))
         self._document.setHtml(html)
         return gui.TextCursor(self._document).charFormat()
 
-    def _get_format_from_style(self, token, style):
+    def _get_format_from_style(self, token: str, style: Style) -> gui.TextCharFormat:
         """Return a QTextCharFormat for token by reading a Pygments style."""
         result = gui.TextCharFormat()
         try:
             token_style = style.style_for_token(token)
-        except KeyError as e:
-            logger.exception(e)
+        except KeyError:
             return result
         for key, value in token_style.items():
             if value:
@@ -213,7 +216,7 @@ class PygmentsHighlighter(gui.SyntaxHighlighter):
                     result.set_font_style_hint("typewriter")
         return result
 
-    def _get_brush(self, color):
+    def _get_brush(self, color: str) -> gui.Brush:
         """Return a brush for the color."""
         result = self._brushes.get(color)
         if result is None:
@@ -230,4 +233,4 @@ if __name__ == "__main__":
     editor = widgets.PlainTextEdit()
     highlighter = PygmentsHighlighter(editor.document(), lexer="regex")
     editor.show()
-    app.exec_()
+    app.main_loop()
