@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Based on http://www.yasinuludag.com/blog/?p=49 ."""
 
 from prettyqt import core, gui, syntaxhighlighters
@@ -41,8 +40,8 @@ class Keyword(Rule):
 
 VALUE_FORMAT = gui.TextCharFormat()
 VALUE_FORMAT.set_foreground_color("orange")
-VALUE_START_EXPRESSION = core.RegExp(r"\"")
-VALUE_END_EXPRESSION = core.RegExp(r"\"(?=[\s></])")
+VALUE_START_EXPRESSION = core.RegularExpression(r"\"")
+VALUE_END_EXPRESSION = core.RegularExpression(r"\"(?=[\s></])")
 
 
 class XmlHighlighter(gui.SyntaxHighlighter):
@@ -57,17 +56,19 @@ class XmlHighlighter(gui.SyntaxHighlighter):
         self.setCurrentBlockState(0)
         start_index = 0
         if self.previousBlockState() != 1:
-            start_index = VALUE_START_EXPRESSION.indexIn(text)
+            start_index = VALUE_START_EXPRESSION.match(text).capturedStart()
         while start_index >= 0:
-            end_index = VALUE_END_EXPRESSION.indexIn(text, start_index)
+            match = VALUE_END_EXPRESSION.match(text, start_index)
+            end_index = match.capturedStart()
             if end_index == -1:
                 self.setCurrentBlockState(1)
                 comment_len = len(text) - start_index
             else:
-                matched_len = VALUE_END_EXPRESSION.matchedLength()
-                comment_len = end_index - start_index + matched_len
+                comment_len = end_index - start_index + match.capturedLength()
             self.setFormat(start_index, comment_len, VALUE_FORMAT)
-            start_index = VALUE_START_EXPRESSION.indexIn(text, start_index + comment_len)
+            start_index = VALUE_START_EXPRESSION.match(
+                text, start_index + comment_len
+            ).capturedStart()
 
 
 if __name__ == "__main__":
@@ -77,4 +78,4 @@ if __name__ == "__main__":
     editor = widgets.PlainTextEdit()
     highlighter = XmlHighlighter(editor.document())
     editor.show()
-    app.exec_()
+    app.main_loop()
