@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from typing import Union
 
 from qtpy import QtCore, QtGui
@@ -7,9 +5,8 @@ from qtpy import QtCore, QtGui
 from prettyqt import gui
 
 
-ColorType = Union[
-    str, int, QtGui.QRgba64, QtCore.Qt.GlobalColor, QtGui.QColor, tuple, None
-]
+ColorType = Union[str, int, QtCore.Qt.GlobalColor, QtGui.QColor, tuple, None]
+ColorAndBrushType = Union[ColorType, QtGui.QBrush]
 
 WINDOW_ICON_COLOR = "darkcyan"
 
