@@ -1,11 +1,25 @@
-# -*- coding: utf-8 -*-
-
 """widgets module.
 
 contains QtWidgets-based classes
 """
 
+from prettyqt import core
+from qtpy.QtWidgets import (
+    QGraphicsSceneHoverEvent as GraphicsSceneHoverEvent,
+    QGraphicsSceneMouseEvent as GraphicsSceneMouseEvent,
+    QGraphicsSceneWheelEvent as GraphicsSceneWheelEvent,
+    QGraphicsSceneContextMenuEvent as GraphicsSceneContextMenuEvent,
+    QGraphicsSceneDragDropEvent as GraphicsSceneDragDropEvent,
+    QGraphicsSceneHelpEvent as GraphicsSceneHelpEvent,
+    QGraphicsSceneMoveEvent as GraphicsSceneMoveEvent,
+    QGraphicsSceneResizeEvent as GraphicsSceneResizeEvent,
+    QGraphicsSceneEvent as GraphicsSceneEvent,
+    QGestureEvent as GestureEvent,
+)
+
 from .style import Style
+from .commonstyle import CommonStyle
+from .proxystyle import ProxyStyle
 from .application import Application
 from .sizepolicy import SizePolicy
 from .widget import Widget
@@ -17,7 +31,10 @@ from .abstractspinbox import AbstractSpinBox
 from .abstractitemview import AbstractItemView
 from .scrollbar import ScrollBar
 from .scrollarea import ScrollArea
-from .desktopwidget import DesktopWidget
+from .rubberband import RubberBand
+from .graphicstransform import GraphicsTransform
+from .graphicsrotation import GraphicsRotation
+from .graphicsscale import GraphicsScale
 from .graphicsitem import GraphicsItem
 from .graphicsitemgroup import GraphicsItemGroup
 from .abstractgraphicsshapeitem import AbstractGraphicsShapeItem
@@ -45,7 +62,31 @@ from .graphicsopacityeffect import GraphicsOpacityEffect
 from .graphicsscene import GraphicsScene
 from .graphicsview import GraphicsView
 from .styleoption import StyleOption
+from .styleoptionbutton import StyleOptionButton
 from .styleoptioncomplex import StyleOptionComplex
+from .styleoptiondockwidget import StyleOptionDockWidget
+from .styleoptionfocusrect import StyleOptionFocusRect
+from .styleoptionframe import StyleOptionFrame
+from .styleoptiongraphicsitem import StyleOptionGraphicsItem
+from .styleoptionheader import StyleOptionHeader
+from .styleoptionmenuitem import StyleOptionMenuItem
+from .styleoptionprogressbar import StyleOptionProgressBar
+from .styleoptionrubberband import StyleOptionRubberBand
+from .styleoptiontab import StyleOptionTab
+from .styleoptiontabbarbase import StyleOptionTabBarBase
+from .styleoptiontabwidgetframe import StyleOptionTabWidgetFrame
+from .styleoptiontoolbar import StyleOptionToolBar
+from .styleoptiontoolbox import StyleOptionToolBox
+from .styleoptionviewitem import StyleOptionViewItem
+
+from .styleoptioncombobox import StyleOptionComboBox
+from .styleoptiongroupbox import StyleOptionGroupBox
+from .styleoptionsizegrip import StyleOptionSizeGrip
+from .styleoptionslider import StyleOptionSlider
+from .styleoptionspinbox import StyleOptionSpinBox
+from .styleoptiontitlebar import StyleOptionTitleBar
+from .styleoptiontoolbutton import StyleOptionToolButton
+
 from .stylepainter import StylePainter
 from .stylefactory import StyleFactory
 from .pushbutton import PushButton
@@ -57,16 +98,23 @@ from .errormessage import ErrorMessage
 from .filesystemmodel import FileSystemModel
 
 from .slider import Slider
-from .styleoptionslider import StyleOptionSlider
-from .styleoptionframe import StyleOptionFrame
+from .dial import Dial
 
 from .dockwidget import DockWidget
-from .action import Action
-from .actiongroup import ActionGroup
+
+if core.VersionNumber.get_qt_version() < (6, 0, 0):
+    from .action import Action
+    from .actiongroup import ActionGroup
+    from .shortcut import Shortcut
+    from .undocommand import UndoCommand
+    from .undostack import UndoStack
+    from .undogroup import UndoGroup
+    from .keyeventtransition import KeyEventTransition
+    from .mouseeventtransition import MouseEventTransition
 from .widgetaction import WidgetAction
 from .menu import Menu
 from .mainwindow import MainWindow
-
+from .whatsthis import WhatsThis
 from .listwidgetitem import ListWidgetItem
 from .treewidgetitem import TreeWidgetItem
 from .toolbutton import ToolButton
@@ -98,14 +146,19 @@ from .plaintextedit import PlainTextEdit
 from .textbrowser import TextBrowser
 from .completer import Completer
 from .progressbar import ProgressBar
+from .lcdnumber import LCDNumber
 from .columnview import ColumnView
 from .listview import ListView
 from .listwidget import ListWidget
 from .treeview import TreeView
+from .tablewidgetselectionrange import TableWidgetSelectionRange
 from .treewidget import TreeWidget
+from .treewidgetitemiterator import TreeWidgetItemIterator
 from .tableview import TableView
 from .tablewidgetitem import TableWidgetItem
 from .tablewidget import TableWidget
+from .scrollerproperties import ScrollerProperties
+from .scroller import Scroller
 from .abstractitemdelegate import AbstractItemDelegate
 from .itemdelegate import ItemDelegate
 from .styleditemdelegate import StyledItemDelegate
@@ -131,15 +184,22 @@ from .groupbox import GroupBox
 from .splitter import Splitter
 from .wizard import Wizard
 from .wizardpage import WizardPage
+from .stackedwidget import StackedWidget
 
-from .undocommand import UndoCommand
-from .undostack import UndoStack
-from .undogroup import UndoGroup
 from .undoview import UndoView
 
 from .datawidgetmapper import DataWidgetMapper
 from .sizegrip import SizeGrip
 
+from .plaintextdocumentlayout import PlainTextDocumentLayout
+
+from .gesture import Gesture
+from .tapgesture import TapGesture
+from .tapandholdgesture import TapAndHoldGesture
+from .pangesture import PanGesture
+from .pinchgesture import PinchGesture
+from .swipegesture import SwipeGesture
+
 
 def app():
     if Application.instance() is not None:
@@ -161,7 +221,10 @@ __all__ = [
     "ScrollBar",
     "ScrollArea",
     "Widget",
-    "DesktopWidget",
+    "RubberBand",
+    "GraphicsTransform",
+    "GraphicsRotation",
+    "GraphicsScale",
     "GraphicsItem",
     "GraphicsItemGroup",
     "AbstractGraphicsShapeItem",
@@ -190,6 +253,8 @@ __all__ = [
     "GraphicsScene",
     "GraphicsView",
     "Style",
+    "CommonStyle",
+    "ProxyStyle",
     "StyleOption",
     "StyleOptionComplex",
     "SpacerItem",
@@ -209,11 +274,33 @@ __all__ = [
     "GridLayout",
     "ToolBox",
     "Slider",
+    "Dial",
+    "StyleOptionButton",
+    "StyleOptionDockWidget",
+    "StyleOptionFocusRect",
+    "StyleOptionGraphicsItem",
+    "StyleOptionHeader",
+    "StyleOptionMenuItem",
+    "StyleOptionProgressBar",
+    "StyleOptionRubberBand",
+    "StyleOptionTab",
+    "StyleOptionTabBarBase",
+    "StyleOptionTabWidgetFrame",
+    "StyleOptionToolBar",
+    "StyleOptionToolBox",
+    "StyleOptionViewItem",
+    "StyleOptionComboBox",
+    "StyleOptionGroupBox",
+    "StyleOptionSizeGrip",
     "StyleOptionSlider",
+    "StyleOptionSpinBox",
+    "StyleOptionTitleBar",
+    "StyleOptionToolButton",
     "StyleOptionFrame",
     "Frame",
     "ListWidgetItem",
     "TreeWidgetItem",
+    "TreeWidgetItemIterator",
     "Action",
     "ActionGroup",
     "WidgetAction",
@@ -247,11 +334,15 @@ __all__ = [
     "TextBrowser",
     "Completer",
     "ProgressBar",
+    "LCDNumber",
     "ColumnView",
     "ListView",
     "ListWidget",
     "TreeView",
     "TreeWidget",
+    "TableWidgetSelectionRange",
+    "ScrollerProperties",
+    "Scroller",
     "TableView",
     "TableWidgetItem",
     "TableWidget",
@@ -267,7 +358,10 @@ __all__ = [
     "Splitter",
     "Wizard",
     "WizardPage",
+    "StackedWidget",
     "MainWindow",
+    "Shortcut",
+    "WhatsThis",
     "AbstractItemDelegate",
     "ItemDelegate",
     "StyledItemDelegate",
@@ -278,4 +372,23 @@ __all__ = [
     "UndoView",
     "DataWidgetMapper",
     "SizeGrip",
+    "KeyEventTransition",
+    "MouseEventTransition",
+    "GraphicsSceneHoverEvent",
+    "GraphicsSceneMouseEvent",
+    "GraphicsSceneWheelEvent",
+    "GraphicsSceneContextMenuEvent",
+    "GraphicsSceneDragDropEvent",
+    "GraphicsSceneHelpEvent",
+    "GraphicsSceneMoveEvent",
+    "GraphicsSceneResizeEvent",
+    "GraphicsSceneEvent",
+    "GestureEvent",
+    "PlainTextDocumentLayout",
+    "Gesture",
+    "TapGesture",
+    "TapAndHoldGesture",
+    "PanGesture",
+    "PinchGesture",
+    "SwipeGesture",
 ]
