@@ -1,6 +1,6 @@
 from qtpy import QtWidgets
 
-from prettyqt import widgets, gui
+from prettyqt import gui, widgets
 
 
 QtWidgets.QAbstractGraphicsShapeItem.__bases__ = (widgets.GraphicsItem,)
@@ -8,4 +8,4 @@ QtWidgets.QAbstractGraphicsShapeItem.__bases__ = (widgets.GraphicsItem,)
 
 class AbstractGraphicsShapeItem(QtWidgets.QAbstractGraphicsShapeItem):
     def serialize_fields(self):
-        return dict(brush=gui.Brush(self.brush()), pen=gui.pen(self.pen()))
+        return dict(brush=gui.Brush(self.brush()), pen=gui.Pen(self.pen()))
