@@ -1,46 +1,67 @@
-# -*- coding: utf-8 -*-
-
 import logging
-from typing import Any, Generator, List, Optional
+from typing import Any, Generator, List, Literal, Optional, Tuple, Union
 
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import constants, gui, widgets
-from prettyqt.utils import bidict, InvalidParamError, helpers
+from prettyqt.utils import InvalidParamError, bidict, helpers
+
 
 logger = logging.getLogger(__name__)
 
-TRIGGERS = bidict(
+EDIT_TRIGGERS = bidict(
     none=QtWidgets.QAbstractItemView.NoEditTriggers,
     double_click=QtWidgets.QAbstractItemView.DoubleClicked,
     edit_key=QtWidgets.QAbstractItemView.EditKeyPressed,
 )
 
-SELECTION_BEHAVIOURS = bidict(
+EditTriggerStr = Literal["none", "double_click", "edit_key"]
+
+SELECTION_BEHAVIOUR = bidict(
     rows=QtWidgets.QAbstractItemView.SelectRows,
     columns=QtWidgets.QAbstractItemView.SelectColumns,
     items=QtWidgets.QAbstractItemView.SelectItems,
 )
 
-SELECTION_MODES = bidict(
+SelectionBehaviourStr = Literal["rows", "columns", "items"]
+
+SELECTION_MODE = bidict(
     single=QtWidgets.QAbstractItemView.SingleSelection,
     extended=QtWidgets.QAbstractItemView.ExtendedSelection,
     multi=QtWidgets.QAbstractItemView.MultiSelection,
     none=QtWidgets.QAbstractItemView.NoSelection,
 )
 
-SCROLL_MODES = bidict(
+SelectionModeStr = Literal["single", "extended", "multi", "none"]
+
+SCROLL_MODE = bidict(
     item=QtWidgets.QAbstractItemView.ScrollPerItem,
     pixel=QtWidgets.QAbstractItemView.ScrollPerPixel,
 )
 
-SCROLL_HINTS = bidict(
+ScrollModeStr = Literal["item", "pixel"]
+
+SCROLL_HINT = bidict(
     ensure_visible=QtWidgets.QAbstractItemView.EnsureVisible,
     position_at_top=QtWidgets.QAbstractItemView.PositionAtTop,
     position_at_bottom=QtWidgets.QAbstractItemView.PositionAtBottom,
     position_at_center=QtWidgets.QAbstractItemView.PositionAtCenter,
 )
 
+ScrollHintStr = Literal[
+    "ensure_visible", "position_at_top", "position_at_bottom", "position_at_center"
+]
+
+DRAG_DROP_MODE = bidict(
+    none=QtWidgets.QAbstractItemView.NoDragDrop,
+    drag=QtWidgets.QAbstractItemView.DragOnly,
+    drop=QtWidgets.QAbstractItemView.DropOnly,
+    drag_drop=QtWidgets.QAbstractItemView.DragDrop,
+    internal_move=QtWidgets.QAbstractItemView.InternalMove,
+)
+
+DragDropModeStr = Literal["none", "drag", "drop", "drag_drop", "internal"]
+
 QtWidgets.QAbstractItemView.__bases__ = (widgets.AbstractScrollArea,)
 
 
@@ -53,10 +74,10 @@ class AbstractItemView(QtWidgets.QAbstractItemView):
     def selectAll(self):
         """Override, we dont want to selectAll for too many items bc of performance."""
         if self.model() is None:
-            return None
+            return
         if self.model().rowCount() * self.model().columnCount() > 1_000_000:
             logger.warning("Too many cells to select.")
-            return None
+            return
         super().selectAll()
 
     def set_model(self, model: Optional[QtCore.QAbstractItemModel]):
@@ -64,7 +85,7 @@ class AbstractItemView(QtWidgets.QAbstractItemView):
         old_model = self.model()
         old_sel_model = self.selectionModel()
         if old_model is not None or model is not None:
-            self.setModel(model)
+            self.setModel(model)  # type: ignore
         # if old_model:
         #     old_model.deleteLater()
         #     del old_model
@@ -97,7 +118,7 @@ class AbstractItemView(QtWidgets.QAbstractItemView):
     def toggle_select_all(self):
         """Select all items from list (deselect when all selected)."""
         if self.selectionModel() is None:
-            return None
+            return
         if self.selectionModel().hasSelection():
             self.clearSelection()
         else:
@@ -152,47 +173,62 @@ class AbstractItemView(QtWidgets.QAbstractItemView):
         self.setDefaultDropAction(QtCore.Qt.MoveAction)
         self.setDropIndicatorShown(True)
 
-    def set_edit_triggers(self, *triggers: Optional[str]):
+    def set_edit_triggers(self, *triggers: Optional[EditTriggerStr]):
         items = ["none" if t is None else t for t in triggers]
         for item in items:
-            if item not in TRIGGERS:
-                raise InvalidParamError(item, TRIGGERS)
-        flags = helpers.merge_flags(items, TRIGGERS)
+            if item not in EDIT_TRIGGERS:
+                raise InvalidParamError(item, EDIT_TRIGGERS)
+        flags = helpers.merge_flags(items, EDIT_TRIGGERS)
         self.setEditTriggers(flags)
 
-    def get_edit_triggers(self) -> List[str]:
-        return [k for k, v in TRIGGERS.items() if v & self.editTriggers()]
+    def get_edit_triggers(self) -> List[EditTriggerStr]:
+        return [k for k, v in EDIT_TRIGGERS.items() if v & self.editTriggers()]
 
-    def set_selection_behaviour(self, behaviour: str):
+    def set_selection_behaviour(self, behaviour: SelectionBehaviourStr):
         """Set selection behaviour for given item view.
 
-        Allowed values are "rows", "columns", "items"
-
         Args:
             behaviour: selection behaviour to use
 
         Raises:
             InvalidParamError: behaviour does not exist
         """
-        if behaviour not in SELECTION_BEHAVIOURS:
-            raise InvalidParamError(behaviour, SELECTION_BEHAVIOURS)
-        self.setSelectionBehavior(SELECTION_BEHAVIOURS[behaviour])
+        if behaviour not in SELECTION_BEHAVIOUR:
+            raise InvalidParamError(behaviour, SELECTION_BEHAVIOUR)
+        self.setSelectionBehavior(SELECTION_BEHAVIOUR[behaviour])
 
-    def get_selection_behaviour(self) -> str:
+    def get_selection_behaviour(self) -> SelectionBehaviourStr:
         """Return current selection behaviour.
 
-        Possible values: "rows", "columns", "items"
-
         Returns:
             selection behaviour
         """
-        return SELECTION_BEHAVIOURS.inv[self.selectionBehavior()]
+        return SELECTION_BEHAVIOUR.inverse[self.selectionBehavior()]
 
-    def set_selection_mode(self, mode: Optional[str]):
+    def set_drag_drop_mode(self, mode: DragDropModeStr):
+        """Set drag-drop mode for given item view.
+
+        Args:
+            mode: drag-drop mode to use
+
+        Raises:
+            InvalidParamError: mode does not exist
+        """
+        if mode not in DRAG_DROP_MODE:
+            raise InvalidParamError(mode, DRAG_DROP_MODE)
+        self.setDragDropMode(DRAG_DROP_MODE[mode])
+
+    def get_drag_drop_mode(self) -> DragDropModeStr:
+        """Return current drag-drop mode.
+
+        Returns:
+            drag-drop mode
+        """
+        return DRAG_DROP_MODE.inverse[self.dragDropMode()]
+
+    def set_selection_mode(self, mode: Optional[SelectionModeStr]):
         """Set selection mode for given item view.
 
-        Allowed values are "single", "extended", "multi" or "none"
-
         Args:
             mode: selection mode to use
 
@@ -201,65 +237,57 @@ class AbstractItemView(QtWidgets.QAbstractItemView):
         """
         if mode is None:
             mode = "none"
-        if mode not in SELECTION_MODES:
-            raise InvalidParamError(mode, SELECTION_MODES)
-        self.setSelectionMode(SELECTION_MODES[mode])
+        if mode not in SELECTION_MODE:
+            raise InvalidParamError(mode, SELECTION_MODE)
+        self.setSelectionMode(SELECTION_MODE[mode])
 
-    def get_selection_mode(self) -> str:
+    def get_selection_mode(self) -> SelectionModeStr:
         """Return current selection mode.
 
-        Possible values: "single", "extended", "multi" or "none"
-
         Returns:
             selection mode
         """
-        return SELECTION_MODES.inv[self.selectionMode()]
+        return SELECTION_MODE.inverse[self.selectionMode()]
 
-    def set_scroll_mode(self, mode: str):
+    def set_scroll_mode(self, mode: ScrollModeStr):
         """Set the scroll mode for both directions.
 
-        possible values are "item", "pixel"
-
         Args:
             mode: mode to set
 
         Raises:
             InvalidParamError: invalid scroll mode
         """
-        if mode not in SCROLL_MODES:
-            raise InvalidParamError(mode, SCROLL_MODES)
-        self.setHorizontalScrollMode(SCROLL_MODES[mode])
-        self.setVerticalScrollMode(SCROLL_MODES[mode])
+        if mode not in SCROLL_MODE:
+            raise InvalidParamError(mode, SCROLL_MODE)
+        self.setHorizontalScrollMode(SCROLL_MODE[mode])
+        self.setVerticalScrollMode(SCROLL_MODE[mode])
 
-    def set_horizontal_scroll_mode(self, mode: str):
+    def set_horizontal_scroll_mode(self, mode: ScrollModeStr):
         """Set the horizontal scroll mode.
 
-        possible values are "item", "pixel"
-
         Args:
             mode: mode to set
 
         Raises:
             InvalidParamError: invalid scroll mode
         """
-        if mode not in SCROLL_MODES:
-            raise InvalidParamError(mode, SCROLL_MODES)
-        self.setHorizontalScrollMode(SCROLL_MODES[mode])
+        if mode not in SCROLL_MODE:
+            raise InvalidParamError(mode, SCROLL_MODE)
+        self.setHorizontalScrollMode(SCROLL_MODE[mode])
 
-    def set_vertical_scroll_mode(self, mode: str):
+    def set_vertical_scroll_mode(self, mode: ScrollModeStr):
         """Set the vertical scroll mode.
 
-        possible values are "item", "pixel"
-
         Args:
             mode: mode to set
 
         Raises:
             InvalidParamError: invalid scroll mode
         """
-        if mode not in SCROLL_MODES:
-            raise InvalidParamError(mode, SCROLL_MODES)
-        self.setVerticalScrollMode(SCROLL_MODES[mode])
+        if mode not in SCROLL_MODE:
+            raise InvalidParamError(mode, SCROLL_MODE)
+        self.setVerticalScrollMode(SCROLL_MODE[mode])
 
     def num_selected(self) -> int:
         """Return amount of selected rows.
@@ -280,7 +308,7 @@ class AbstractItemView(QtWidgets.QAbstractItemView):
             col_num: column to scroll to
         """
         if self.model() is None:
-            return None
+            return
         idx = self.model().index(0, col_num)
         self.scrollTo(idx)
 
@@ -296,13 +324,20 @@ class AbstractItemView(QtWidgets.QAbstractItemView):
         idx = self.model().createIndex(self.model().rowCount() - 1, 0)
         self.setCurrentIndex(idx)
 
-    def scroll_to(self, index, mode: str = "ensure_visible"):
-        if mode not in SCROLL_HINTS:
-            raise InvalidParamError(mode, SCROLL_HINTS)
-        self.scrollTo(index, SCROLL_HINTS[mode])
+    def scroll_to(self, index, mode: ScrollHintStr = "ensure_visible"):
+        if mode not in SCROLL_HINT:
+            raise InvalidParamError(mode, SCROLL_HINT)
+        self.scrollTo(index, SCROLL_HINT[mode])
 
     def highlight_when_inactive(self):
         """Highlight items when widget does not have focus."""
         p = gui.Palette()
         p.highlight_inactive()
         self.setPalette(p)
+
+    def set_icon_size(self, size: Union[int, QtCore.QSize, Tuple[int, int]]):
+        if isinstance(size, tuple):
+            size = QtCore.QSize(*size)
+        elif isinstance(size, int):
+            size = QtCore.QSize(size, size)
+        self.setIconSize(size)
