@@ -1,11 +1,12 @@
-# -*- coding: utf-8 -*-
+from typing import Literal
 
 from qtpy import QtCore, QtWidgets
 
-from prettyqt import core, widgets
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt import constants, core, widgets
+from prettyqt.utils import InvalidParamError, bidict
 
-SLIDER_ACTIONS = bidict(
+
+SLIDER_ACTION = bidict(
     none=QtWidgets.QAbstractSlider.SliderNoAction,
     single_step_add=QtWidgets.QAbstractSlider.SliderSingleStepAdd,
     single_step_sub=QtWidgets.QAbstractSlider.SliderSingleStepSub,
@@ -16,6 +17,17 @@ SLIDER_ACTIONS = bidict(
     move=QtWidgets.QAbstractSlider.SliderMove,
 )
 
+SliderActionStr = Literal[
+    "none",
+    "single_step_add",
+    "single_step_sub",
+    "page_step_add",
+    "page_step_sub",
+    "to_minimum",
+    "to_maximum",
+    "move",
+]
+
 QtWidgets.QAbstractSlider.__bases__ = (widgets.Widget,)
 
 
@@ -38,7 +50,7 @@ class AbstractSlider(QtWidgets.QAbstractSlider):
         )
 
     def __setstate__(self, state):
-        self.__init__()
+        super().__setstate__(state)
         self.set_range(*state["range"])
         self.set_value(state["value"])
         self.setSingleStep(state["single_step"])
@@ -47,6 +59,9 @@ class AbstractSlider(QtWidgets.QAbstractSlider):
         self.setInvertedControls(state["inverted_controls"])
         self.setInvertedAppearance(state["inverted_appearance"])
 
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
     def is_horizontal(self) -> bool:
         """Check if silder is horizontal.
 
@@ -71,6 +86,27 @@ class AbstractSlider(QtWidgets.QAbstractSlider):
         """Set slider orientation to vertical."""
         self.setOrientation(QtCore.Qt.Vertical)
 
+    def set_orientation(self, orientation: constants.OrientationStr):
+        """Set the orientation of the slider.
+
+        Args:
+            orientation: orientation for the slider
+
+        Raises:
+            InvalidParamError: orientation does not exist
+        """
+        if orientation not in constants.ORIENTATION:
+            raise InvalidParamError(orientation, constants.ORIENTATION)
+        self.setOrientation(constants.ORIENTATION[orientation])
+
+    def get_orientation(self) -> constants.OrientationStr:
+        """Return current orientation.
+
+        Returns:
+            orientation
+        """
+        return constants.ORIENTATION.inverse[self.orientation()]
+
     def scroll_to_min(self):
         """Scroll to the minimum value of the slider."""
         self.setValue(self.minimum())
@@ -85,43 +121,34 @@ class AbstractSlider(QtWidgets.QAbstractSlider):
     def set_step_size(self, step_size: int):
         self.setSingleStep(step_size)
 
-    def set_repeat_action(self, action: str, threshold: int = 500, repeat_time: int = 50):
+    def set_repeat_action(
+        self, action: SliderActionStr, threshold: int = 500, repeat_time: int = 50
+    ):
         """Set the repeat action.
 
-        Valid values are "none", "single_step_add", "single_step_sub", "page_step_add",
-        "page_step_sub", "to_minimum", "to_maximum", "move"
-
         Args:
             action: repeat action
 
         Raises:
             InvalidParamError: invalid repeat action
         """
-        if action not in SLIDER_ACTIONS:
-            raise InvalidParamError(action, SLIDER_ACTIONS)
-        self.setRepeatAction(SLIDER_ACTIONS[action], threshold, repeat_time)
+        if action not in SLIDER_ACTION:
+            raise InvalidParamError(action, SLIDER_ACTION)
+        self.setRepeatAction(SLIDER_ACTION[action], threshold, repeat_time)
 
-    def get_repeat_action(self) -> str:
+    def get_repeat_action(self) -> SliderActionStr:
         """Get current repeat action.
 
-        Possible values are "none", "single_step_add", "single_step_sub", "page_step_add",
-        "page_step_sub", "to_minimum", "to_maximum", "move"
-
         Returns:
             current repeat action
         """
-        return SLIDER_ACTIONS.inv[self.repeatAction()]
+        return SLIDER_ACTION.inverse[self.repeatAction()]
 
-    def trigger_action(self, action: str):
-        """Trigger slider action.
-
-        Possible values are "none", "single_step_add", "single_step_sub", "page_step_add",
-        "page_step_sub", "to_minimum", "to_maximum", "move"
-
-        """
-        if action not in SLIDER_ACTIONS:
-            raise InvalidParamError(action, SLIDER_ACTIONS)
-        self.triggerAction(SLIDER_ACTIONS[action])
+    def trigger_action(self, action: SliderActionStr):
+        """Trigger slider action."""
+        if action not in SLIDER_ACTION:
+            raise InvalidParamError(action, SLIDER_ACTION)
+        self.triggerAction(SLIDER_ACTION[action])
 
     def get_value(self):
         return self.value()
@@ -136,4 +163,4 @@ if __name__ == "__main__":
     slider.setRange(0, 100)
     slider.value_changed.connect(print)
     slider.show()
-    app.exec_()
+    app.main_loop()
