@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
-
-from typing import Optional
+from typing import Callable, Literal, Optional
 
 from qtpy import QtCore, QtWidgets
 
-from prettyqt import core, gui
-from prettyqt.utils import bidict, InvalidParamError, helpers, prettyprinter
+from prettyqt import constants, core, gui, iconprovider
+from prettyqt.utils import InvalidParamError, bidict, helpers, prettyprinter
 
 
 PRIORITIES = bidict(
@@ -14,12 +12,7 @@ PRIORITIES = bidict(
     high=QtWidgets.QAction.HighPriority,
 )
 
-CONTEXTS = bidict(
-    widget=QtCore.Qt.WidgetShortcut,
-    widget_with_children=QtCore.Qt.WidgetWithChildrenShortcut,
-    window=QtCore.Qt.WindowShortcut,
-    application=QtCore.Qt.ApplicationShortcut,
-)
+PriorityStr = Literal["low", "normal", "high"]
 
 ROLES = bidict(
     none=QtWidgets.QAction.NoRole,
@@ -31,21 +24,32 @@ ROLES = bidict(
     quit=QtWidgets.QAction.QuitRole,
 )
 
+RoleStr = Literal[
+    "none",
+    "text_heuristic",
+    "application_specific",
+    "about_qt",
+    "about",
+    "preferences",
+    "quit",
+]
+
 QtWidgets.QAction.__bases__ = (core.Object,)
 
 
 class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
     def __init__(
         self,
-        parent=None,
+        parent: Optional[QtCore.QObject] = None,
         text: str = "",
-        icon: gui.icon.IconType = None,
+        icon: iconprovider.IconType = None,
         shortcut: Optional[str] = None,
         tooltip: str = "",
         checkable: bool = False,
         checked: bool = False,
         statustip: str = "",
         enabled: bool = True,
+        callback: Optional[Callable] = None,
     ):
         super().__init__(parent)
         self.set_text(text)
@@ -56,9 +60,11 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
         self.set_checked(checked)
         self.set_statustip(statustip)
         self.set_enabled(enabled)
+        if callback is not None:
+            self.triggered.connect(callback)
 
     def __repr__(self) -> str:
-        cls_name = self.__class__.__name__
+        cls_name = type(self).__name__
         return f"{cls_name}({helpers.format_kwargs(self.serialize_fields())})"
 
     def serialize_fields(self):
@@ -85,7 +91,7 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
         )
 
     def __setstate__(self, state):
-        self.__init__()
+        super().__setstate__(state)
         self.set_text(state.get("text", ""))
         self.set_enabled(state.get("enabled", True))
         self.set_shortcut(state["shortcut"])
@@ -96,6 +102,9 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
         self.set_shortcut_context(state["shortcut_context"])
         self.set_checkable(state["checkable"])
 
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
     def set_text(self, text: str):
         self.setText(text)
 
@@ -117,13 +126,13 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
     def set_checkable(self, value: bool):
         self.setCheckable(value)
 
-    def set_icon(self, icon: gui.icon.IconType):
+    def set_icon(self, icon: iconprovider.IconType):
         """Set the icon for the action.
 
         Args:
             icon: icon to use
         """
-        icon = gui.icon.get_icon(icon)
+        icon = iconprovider.get_icon(icon)
         self.setIcon(icon)
 
     def set_shortcut(self, shortcut):
@@ -131,19 +140,17 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
             self.setShortcut(shortcut)
 
     def get_shortcut(self) -> Optional[gui.KeySequence]:
-        shortcut = gui.KeySequence(self.shortcut())
+        shortcut = self.shortcut()
         if not shortcut:
             return None
-        return shortcut
+        return gui.KeySequence(shortcut)
 
     def set_menu(self, menu):
         self.setMenu(menu)
 
-    def set_priority(self, priority: str):
+    def set_priority(self, priority: PriorityStr):
         """Set priority of the action.
 
-        Allowed values are "low", "normal", "high"
-
         Args:
             priority: priority for the action
 
@@ -154,47 +161,38 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
             raise InvalidParamError(priority, PRIORITIES)
         self.setPriority(PRIORITIES[priority])
 
-    def get_priority(self) -> str:
+    def get_priority(self) -> PriorityStr:
         """Return current priority.
 
-        Possible values: "low", "normal", "high"
-
         Returns:
             priority
         """
-        return PRIORITIES.inv[self.priority()]
+        return PRIORITIES.inverse[self.priority()]
 
-    def set_shortcut_context(self, context: str):
+    def set_shortcut_context(self, context: constants.ContextStr):
         """Set shortcut context.
 
-        Allowed values are "widget", "widget_with_children", "window", "application"
-
         Args:
             context: shortcut context
 
         Raises:
             InvalidParamError: shortcut context does not exist
         """
-        if context not in CONTEXTS:
-            raise InvalidParamError(context, CONTEXTS)
-        self.setShortcutContext(CONTEXTS[context])
+        if context not in constants.CONTEXT:
+            raise InvalidParamError(context, constants.CONTEXT)
+        self.setShortcutContext(constants.CONTEXT[context])
 
-    def get_shortcut_context(self) -> str:
+    def get_shortcut_context(self) -> constants.ContextStr:
         """Return shortcut context.
 
-        Possible values: "widget", "widget_with_children", "window", "application"
-
         Returns:
             shortcut context
         """
-        return CONTEXTS.inv[self.shortcutContext()]
+        return constants.CONTEXT.inverse[self.shortcutContext()]
 
-    def set_menu_role(self, role: str):
+    def set_menu_role(self, role: RoleStr):
         """Set menu role.
 
-        Allowed values are "none", "text_heuristic", "application_specific", "about_qt",
-        "about", "preferences", "quit"
-
         Args:
             role: menu role
 
@@ -205,16 +203,13 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
             raise InvalidParamError(role, ROLES)
         self.setMenuRole(ROLES[role])
 
-    def get_menu_role(self) -> str:
+    def get_menu_role(self) -> RoleStr:
         """Return menu role.
 
-        Possible values: "none", "text_heuristic", "application_specific", "about_qt",
-        "about", "preferences", "quit"
-
         Returns:
             menu role
         """
-        return ROLES.inv[self.menuRole()]
+        return ROLES.inverse[self.menuRole()]
 
     def show_shortcut_in_contextmenu(self, state: bool = True):
         self.setShortcutVisibleInContextMenu(state)
@@ -224,5 +219,5 @@ if __name__ == "__main__":
     from prettyqt import widgets
 
     app = widgets.app()
-    action = Action("This is a test")
-    app.exec_()
+    action = Action(text="This is a test")
+    app.main_loop()
