@@ -1,41 +1,40 @@
-# -*- coding: utf-8 -*-
+from typing import Literal, Optional
 
-from typing import Optional
-
-from qtpy import QtWidgets
+from qtpy import QtCore, QtWidgets
 
 from prettyqt import core
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt.utils import InvalidParamError, bidict
+
 
 if core.VersionNumber.get_qt_version() >= (5, 14, 0):
     POLICIES = bidict(
-        none=QtWidgets.QActionGroup.ExclusionPolicy(0),
+        none=QtWidgets.QActionGroup.ExclusionPolicy.None_,
         exclusive=QtWidgets.QActionGroup.ExclusionPolicy.Exclusive,
         exclusive_optional=QtWidgets.QActionGroup.ExclusionPolicy.ExclusiveOptional,
     )
 
+ExclusionPolicyStr = Literal["none", "exclusive", "exclusive_optional"]
+
 
 QtWidgets.QActionGroup.__bases__ = (core.Object,)
 
 
 class ActionGroup(QtWidgets.QActionGroup):
-    def __init__(self, parent: Optional[QtWidgets.QWidget] = None):
-        super().__init__(parent)
+    def __init__(self, parent: Optional[QtCore.QObject] = None):
+        super().__init__(parent)  # type: ignore
 
     def __len__(self) -> int:
         return len(self.actions())
 
-    def __getitem__(self, item: int):
+    def __getitem__(self, item: int) -> QtWidgets.QAction:
         return self.actions()[item]
 
     def serialize_fields(self):
         return dict(exclusion_policy=self.get_exclusion_policy())
 
-    def set_exclusion_policy(self, policy: Optional[str]):
+    def set_exclusion_policy(self, policy: Optional[ExclusionPolicyStr]):
         """Set exclusion policy to use.
 
-        Allowed values are "none", "exclusive", "exclusive_optional"
-
         Args:
             policy: exclusion policy to use
 
@@ -48,15 +47,13 @@ class ActionGroup(QtWidgets.QActionGroup):
             raise InvalidParamError(policy, POLICIES)
         self.setExclusionPolicy(POLICIES[policy])
 
-    def get_exclusion_policy(self) -> str:
+    def get_exclusion_policy(self) -> ExclusionPolicyStr:
         """Return current exclusion policy.
 
-        Possible values: "none", "exclusive", "exclusive_optional"
-
         Returns:
             exclusion policy
         """
-        return POLICIES.inv[self.exclusionPolicy()]
+        return POLICIES.inverse[self.exclusionPolicy()]
 
 
 if __name__ == "__main__":
@@ -67,4 +64,4 @@ if __name__ == "__main__":
     act = widgets.Action()
     action.addAction(act)
     print(act in action)
-    app.exec_()
+    app.main_loop()
