@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
 
 class ButtonGroup(QtWidgets.QButtonGroup):
-    def __getitem__(self, index):
+    def __getitem__(self, index: int) -> QtWidgets.QAbstractButton:
         return self.button(index)
