@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-
-from typing import Optional
+from typing import Literal, Optional
 
 from qtpy import QtWidgets
 
@@ -14,6 +12,7 @@ OPTIONS = dict(
     no_native=QtWidgets.QColorDialog.DontUseNativeDialog,
 )
 
+OptionStr = Literal["show_alpha", "no_buttons", "no_native"]
 
 QtWidgets.QColorDialog.__bases__ = (widgets.BaseDialog,)
 
@@ -23,10 +22,13 @@ class ColorDialog(QtWidgets.QColorDialog):
         return dict(color=self.current_color())
 
     def __setstate__(self, state):
-        self.__init__()
+        super().__setstate__(state)
         if state["color"]:
             self.setCurrentColor(state["color"])
 
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
     @classmethod
     def get_color(
         cls,
@@ -35,8 +37,9 @@ class ColorDialog(QtWidgets.QColorDialog):
         parent: Optional[QtWidgets.QWidget] = None,
     ) -> gui.Color:
         preset = colors.get_color(preset)
-        kwargs = dict(options=cls.ShowAlphaChannel) if allow_alpha else dict()
-        return gui.Color(cls.getColor(preset, parent, **kwargs))
+        kwargs = dict(options=cls.ShowAlphaChannel) if allow_alpha else {}
+        color = cls.getColor(preset, parent, **kwargs)
+        return gui.Color(color)
 
     def current_color(self) -> gui.Color:
         return gui.Color(self.currentColor())
@@ -45,4 +48,4 @@ class ColorDialog(QtWidgets.QColorDialog):
 if __name__ == "__main__":
     app = widgets.app()
     ColorDialog.get_color()
-    app.exec_()
+    app.main_loop()
