@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
 from prettyqt import widgets
@@ -17,4 +15,4 @@ if __name__ == "__main__":
     dlg = QtWidgets.QMainWindow()
     status_bar = ColumnView()
     dlg.show()
-    app.exec_()
+    app.main_loop()
