@@ -1,14 +1,12 @@
-# -*- coding: utf-8 -*-
-
-from typing import Iterable, Union, Mapping, Any
+from typing import Any, Iterable, Literal, Mapping, Tuple, Union
 
 from qtpy import QtCore, QtWidgets
 
-from prettyqt import core, gui, widgets
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt import core, gui, iconprovider, widgets
+from prettyqt.utils import InvalidParamError, bidict
 
 
-INSERT_POLICIES = bidict(
+INSERT_POLICY = bidict(
     no_insert=QtWidgets.QComboBox.NoInsert,
     top=QtWidgets.QComboBox.InsertAtTop,
     current=QtWidgets.QComboBox.InsertAtCurrent,
@@ -18,15 +16,29 @@ INSERT_POLICIES = bidict(
     alphabetically=QtWidgets.QComboBox.InsertAlphabetically,
 )
 
-SIZE_POLICIES = bidict(
+InsertPolicyStr = Literal[
+    "no_insert",
+    "top",
+    "current",
+    "bottom",
+    "after_current",
+    "before_current",
+    "alphabetically",
+]
+
+SIZE_ADJUST_POLICY = bidict(
     content=QtWidgets.QComboBox.AdjustToContents,
     first_show=QtWidgets.QComboBox.AdjustToContentsOnFirstShow,
     min_length=QtWidgets.QComboBox.AdjustToMinimumContentsLength,
     min_length_with_icon=QtWidgets.QComboBox.AdjustToMinimumContentsLengthWithIcon,
 )
 
+SizeAdjustPolicyStr = Literal[
+    "content", "first_show", "min_length", "min_length_with_icon"
+]
 
-class NoData(object):
+
+class NoData:
     pass
 
 
@@ -65,14 +77,10 @@ class ComboBox(QtWidgets.QComboBox):
         return dct
 
     def __setstate__(self, state):
-        self.__init__()
+        super().__setstate__(state)
         for label, data, icon in state["items"]:
             self.add(label, data, icon=icon)
-        self.set_id(state.get("object_name", ""))
         self.setCurrentIndex(state["index"])
-        self.setEnabled(state.get("enabled", True))
-        self.setToolTip(state.get("tool_tip", ""))
-        self.setStatusTip(state.get("status_tip", ""))
         self.setEditable(state["editable"])
         self.setMaxCount(state["max_count"])
         self.setMaxVisibleItems(state["max_visible_items"])
@@ -80,6 +88,9 @@ class ComboBox(QtWidgets.QComboBox):
         self.setDuplicatesEnabled(state["duplicates_enabled"])
         self.setFrame(state["has_frame"])
 
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
     def __len__(self) -> int:
         return self.count()
 
@@ -87,7 +98,7 @@ class ComboBox(QtWidgets.QComboBox):
         data = self.itemData(index)
         self.value_changed.emit(data)
 
-    def add_items(self, items: Union[Iterable, Mapping]):
+    def add_items(self, items: Union[Iterable, Mapping], default=NoData):
         if isinstance(items, Mapping):
             for k, v in items.items():
                 self.addItem(v, userData=k)
@@ -97,12 +108,14 @@ class ComboBox(QtWidgets.QComboBox):
                     self.add(*i)
                 else:
                     self.addItem(i, i)
+        if default is not NoData:
+            self.set_value(default)
 
-    def add(self, label: str, data=NoData, icon: gui.icon.IconType = None):
+    def add(self, label: str, data=NoData, icon: iconprovider.IconType = None):
         if data is NoData:
             data = label
         if icon is not None:
-            icon = gui.icon.get_icon(icon)
+            icon = iconprovider.get_icon(icon)
             self.addItem(gui.Icon(icon), label, userData=data)
         else:
             self.addItem(label, userData=data)
@@ -110,62 +123,58 @@ class ComboBox(QtWidgets.QComboBox):
     def item_icon(self, index: int) -> gui.Icon:
         return gui.Icon(self.itemIcon(index))
 
-    def set_insert_policy(self, policy: str):
+    def set_insert_policy(self, policy: InsertPolicyStr):
         """Set insert policy.
 
-        valid values are "no_insert", "top", "current", "bottom", "after_current",
-        "before_current", "alphabetically"
-
         Args:
             policy: insert policy to use
 
         Raises:
             InvalidParamError: invalid insert policy
         """
-        if policy not in INSERT_POLICIES:
-            raise InvalidParamError(policy, INSERT_POLICIES)
-        policy = INSERT_POLICIES.get(policy)
-        self.setInsertPolicy(policy)
+        if policy not in INSERT_POLICY:
+            raise InvalidParamError(policy, INSERT_POLICY)
+        self.setInsertPolicy(INSERT_POLICY[policy])
 
-    def get_insert_policy(self) -> str:
+    def get_insert_policy(self) -> InsertPolicyStr:
         """Return insert policy.
 
-        possible values are "no_insert", "top", "current", "bottom", "after_current",
-        "before_current", "alphabetically"
-
         Returns:
             insert policy
         """
-        return INSERT_POLICIES.inv[self.insertPolicy()]
+        return INSERT_POLICY.inverse[self.insertPolicy()]
 
-    def set_size_adjust_policy(self, policy: str):
+    def set_size_adjust_policy(self, policy: SizeAdjustPolicyStr):
         """Set size adjust policy.
 
-        possible values are "content", "first_show", "min_length", "min_length_with_icon"
-
         Args:
             policy: size adjust policy to use
 
         Raises:
             InvalidParamError: invalid size adjust policy
         """
-        if policy not in SIZE_POLICIES:
-            raise InvalidParamError(policy, SIZE_POLICIES)
-        policy = SIZE_POLICIES.get(policy)
-        self.setSizeAdjustPolicy(policy)
+        if policy not in SIZE_ADJUST_POLICY:
+            raise InvalidParamError(policy, SIZE_ADJUST_POLICY)
+        self.setSizeAdjustPolicy(SIZE_ADJUST_POLICY[policy])
 
-    def get_size_adjust_policy(self) -> str:
+    def get_size_adjust_policy(self) -> SizeAdjustPolicyStr:
         """Return size adjust policy.
 
-        possible values are "content", "first_show", "min_length", "min_length_with_icon"
-
         Returns:
             size adjust policy
         """
-        return SIZE_POLICIES.inv[self.sizeAdjustPolicy()]
+        return SIZE_ADJUST_POLICY.inverse[self.sizeAdjustPolicy()]
 
-    def set_icon_size(self, size: int):
-        self.setIconSize(QtCore.QSize(size, size))
+    def set_icon_size(self, size: Union[int, Tuple[int, int], QtCore.QSize]):
+        """Set size of the icons."""
+        if isinstance(size, int):
+            size = core.Size(size, size)
+        elif isinstance(size, tuple):
+            size = core.Size(*size)
+        self.setIconSize(size)
+
+    def get_icon_size(self) -> core.Size:
+        return core.Size(self.iconSize())
 
     def set_min_char_length(self, chars: int):
         self.setMinimumContentsLength(chars)
@@ -201,4 +210,4 @@ if __name__ == "__main__":
     widget.add("test", data="aa", icon="mdi.timer")
     widget.add("test2", data="aa2", icon="mdi.timer")
     widget.show()
-    app.exec_()
+    app.main_loop()
