@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
 from prettyqt import core, widgets
@@ -17,4 +15,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = CommandLinkButton("This is a test")
     widget.show()
-    app.exec_()
+    app.main_loop()
