@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
-
 import datetime
+from typing import Union
 
-from qtpy import QtWidgets
+from qtpy import QtCore, QtWidgets
 
 from prettyqt import core, widgets
 
@@ -14,28 +13,30 @@ class DateEdit(QtWidgets.QDateEdit):
 
     value_changed = core.Signal(datetime.datetime)
 
+    def __setstate__(self, state):
+        super().__setstate__(state)
+        self.setDate(state["date"])
+        self.set_range(*state["range"])
+
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
     def serialize_fields(self):
         return dict(
-            calendar_popup=self.calendarPopup(),
             date=self.get_date(),
-            display_format=self.displayFormat(),
             range=(self.min_date(), self.max_date()),
         )
 
-    def __setstate__(self, state):
-        self.__init__(state["date"])
-        self.setEnabled(state.get("enabled", True))
-        self.setDisplayFormat(state["display_format"])
-        self.set_range(*state["range"])
-        self.setToolTip(state.get("tool_tip", ""))
-        self.setStatusTip(state.get("status_tip", ""))
-
-    def set_value(self, value):
+    def set_value(self, value: Union[QtCore.QDate, datetime.date]):
         return self.setDate(value)
 
-    def set_range(self, lower: datetime.date, upper: datetime.date):
+    def set_range(
+        self,
+        lower: Union[QtCore.QDate, datetime.date],
+        upper: Union[QtCore.QDate, datetime.date],
+    ):
         self.setToolTip(f"{lower} <= x <= {upper}")
-        self.setDateRange(lower, upper)
+        self.setDateRange(lower, upper)  # type: ignore
 
     def get_value(self) -> datetime.date:
         return self.get_date()
@@ -47,4 +48,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = DateEdit()
     widget.show()
-    app.exec_()
+    app.main_loop()
