@@ -1,13 +1,13 @@
-# -*- coding: utf-8 -*-
-
 import datetime
+from typing import List, Literal, Union
 
-from qtpy import QtWidgets
+from qtpy import QtCore, QtWidgets
 
 from prettyqt import core, widgets
+from prettyqt.utils import InvalidParamError, bidict, to_date, to_datetime, to_time
 
 
-SECTIONS = dict(
+SECTIONS = bidict(
     none=QtWidgets.QDateTimeEdit.NoSection,
     am_pm=QtWidgets.QDateTimeEdit.AmPmSection,
     msec=QtWidgets.QDateTimeEdit.MSecSection,
@@ -19,6 +19,19 @@ SECTIONS = dict(
     year=QtWidgets.QDateTimeEdit.YearSection,
 )
 
+SectionsStr = Literal[
+    "none",
+    "am_pm",
+    "msec",
+    "second",
+    "minute",
+    "hour",
+    "day",
+    "month",
+    "year",
+]
+
+
 QtWidgets.QDateTimeEdit.__bases__ = (widgets.AbstractSpinBox,)
 
 
@@ -31,6 +44,16 @@ class DateTimeEdit(QtWidgets.QDateTimeEdit):
         self.setCalendarPopup(True)
         self.dateTimeChanged.connect(self.datetime_changed)
 
+    def __setstate__(self, state):
+        super().__setstate__(state)
+        self.setDateTime(state["datetime"])
+        self.set_range(*state["range"])
+        self.setCalendarPopup(state["calendar_popup"])
+        self.setDisplayFormat(state["display_format"])
+
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
     def datetime_changed(self, date):
         dt = self.get_datetime()
         self.value_changed.emit(dt)
@@ -43,18 +66,29 @@ class DateTimeEdit(QtWidgets.QDateTimeEdit):
             display_format=self.displayFormat(),
         )
 
-    def __setstate__(self, state):
-        self.__init__(state["datetime"])
-        self.setDateTime(state["datetime"])
-        self.setEnabled(state.get("enabled", True))
-        self.set_range(*state["range"])
-        self.setDisplayFormat(state["display_format"])
-        self.setToolTip(state.get("tool_tip", ""))
-        self.setStatusTip(state.get("status_tip", ""))
+    def get_section_text(self, section: SectionsStr) -> str:
+        if section not in SECTIONS:
+            raise InvalidParamError(section, SECTIONS)
+        return self.sectionText(SECTIONS[section])
 
-    def set_range(self, lower: datetime.datetime, upper: datetime.datetime):
+    def get_current_section(self) -> SectionsStr:
+        return SECTIONS.inverse[self.currentSection()]
+
+    def set_current_section(self, section: SectionsStr):
+        if section not in SECTIONS:
+            raise InvalidParamError(section, SECTIONS)
+        self.setCurrentSection(SECTIONS[section])
+
+    def get_displayed_sections(self) -> List[SectionsStr]:
+        return [k for k, v in SECTIONS.items() if v & self.displayedSections()]
+
+    def set_range(
+        self,
+        lower: Union[QtCore.QDateTime, datetime.datetime],
+        upper: Union[QtCore.QDateTime, datetime.datetime],
+    ):
         self.setToolTip(f"{lower} <= x <= {upper}")
-        self.setDateTimeRange(lower, upper)
+        self.setDateTimeRange(lower, upper)  # type: ignore
 
     def set_format(self, fmt: str):
         self.setDisplayFormat(fmt)
@@ -63,65 +97,38 @@ class DateTimeEdit(QtWidgets.QDateTimeEdit):
         return self.get_datetime()
 
     def set_value(self, value: datetime.datetime):
-        self.setDateTime(value)
+        self.setDateTime(value)  # type: ignore
 
     def get_datetime(self) -> datetime.datetime:
-        try:
-            return self.dateTime().toPython()
-        except TypeError:
-            return self.dateTime().toPyDateTime()
+        return to_datetime(self.dateTime())
 
     def min_datetime(self) -> datetime.datetime:
-        try:
-            return self.minimumDateTime().toPython()
-        except (TypeError, AttributeError):
-            return self.minimumDateTime().toPyDateTime()
+        return to_datetime(self.minimumDateTime())
 
     def max_datetime(self) -> datetime.datetime:
-        try:
-            return self.maximumDateTime().toPython()
-        except (TypeError, AttributeError):
-            return self.maximumDateTime().toPyDateTime()
+        return to_datetime(self.maximumDateTime())
 
     def min_date(self) -> datetime.date:
-        try:
-            return self.minimumDate().toPython()
-        except (TypeError, AttributeError):
-            return self.minimumDate().toPyDate()
+        return to_date(self.minimumDate())
 
     def max_date(self) -> datetime.date:
-        try:
-            return self.maximumDate().toPython()
-        except (TypeError, AttributeError):
-            return self.maximumDate().toPyDate()
+        return to_date(self.maximumDate())
 
     def get_date(self) -> datetime.date:
-        try:
-            return self.date().toPython()
-        except (TypeError, AttributeError):
-            return self.date().toPyDate()
+        return to_date(self.date())
 
     def min_time(self) -> datetime.time:
-        try:
-            return self.minimumTime().toPython()
-        except (TypeError, AttributeError):
-            return self.minimumTime().toPyTime()
+        return to_time(self.minimumTime())
 
     def max_time(self) -> datetime.time:
-        try:
-            return self.maximumTime().toPython()
-        except (TypeError, AttributeError):
-            return self.maximumTime().toPyTime()
+        return to_time(self.maximumTime())
 
     def get_time(self) -> datetime.time:
-        try:
-            return self.time().toPython()
-        except (TypeError, AttributeError):
-            return self.time().toPyTime()
+        return to_time(self.time())
 
 
 if __name__ == "__main__":
     app = widgets.app()
     widget = DateTimeEdit()
     widget.show()
-    app.exec_()
+    app.main_loop()
