@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-
-from typing import Union, Optional
+from typing import Optional, Union
 
 from qtpy import QtCore, QtWidgets
 
@@ -11,30 +9,33 @@ QtWidgets.QDialog.__bases__ = (widgets.Widget,)
 
 
 class BaseDialog(QtWidgets.QDialog):
-    def __getitem__(self, index):
-        return self.findChild(QtWidgets.QWidget, index)
+    def __getitem__(self, index: str) -> QtWidgets.QWidget:
+        result = self.find_child(QtWidgets.QWidget, index)
+        if result is None:
+            raise KeyError("Widget not found")
+        return result
 
     def serialize_fields(self):
         return dict(
             layout=self.layout(),
             is_maximized=self.isMaximized(),
-            has_sizegrip=self.isSizeGripEnabled(),
+            size_grip_enabled=self.isSizeGripEnabled(),
             size=(self.size().width(), self.size().height()),
         )
 
     def __setstate__(self, state):
-        self.__init__()
-        self.set_title(state["window_title"])
-        self.set_icon(state["icon"])
+        super().__setstate__(state)
         if state["layout"]:
             self.set_layout(state["layout"])
-        self.resize(state["size"])
-        self.setSizeGripEnabled(state["has_sizegrip"])
+        self.resize(*state["size"])
+        self.setSizeGripEnabled(state["size_grip_enabled"])
         if state["is_maximized"]:
             self.showMaximized()
-        self.resize(*state["size"])
         self.box = self.layout()
 
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
     def keyPressEvent(self, e):
         if e.key() == QtCore.Qt.Key_Escape:
             self.close()
