@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
 from prettyqt import widgets
@@ -17,4 +15,4 @@ if __name__ == "__main__":
     widget = ErrorMessage()
     widget.set_icon("mdi.timer")
     widget.show()
-    app.exec_()
+    app.main_loop()
