@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
 from prettyqt import gui, widgets
@@ -16,4 +14,4 @@ class FontDialog(QtWidgets.QFontDialog):
 if __name__ == "__main__":
     app = widgets.app()
     widget = FontDialog.getFont()
-    app.exec_()
+    app.main_loop()
