@@ -1,9 +1,9 @@
-from typing import List
+from typing import List, Literal
 
 from qtpy import QtWidgets
 
 from prettyqt import widgets
-from prettyqt.utils import bidict, helpers, InvalidParamError
+from prettyqt.utils import InvalidParamError, bidict, helpers
 
 
 BLUR_HINTS = bidict(
@@ -12,6 +12,8 @@ BLUR_HINTS = bidict(
     animation=QtWidgets.QGraphicsBlurEffect.AnimationHint,
 )
 
+BlurHintStr = Literal["performance", "quality", "animation"]
+
 
 QtWidgets.QGraphicsBlurEffect.__bases__ = (widgets.GraphicsEffect,)
 
@@ -20,12 +22,20 @@ class GraphicsBlurEffect(QtWidgets.QGraphicsBlurEffect):
     def serialize_fields(self):
         return dict(blur_radius=self.blurRadius(), blur_hints=self.get_blur_hints())
 
-    def set_blur_hints(self, *hints: str):
+    def __setstate__(self, state):
+        super().__setstate__(state)
+        self.setBlurRadius(state["blur_radius"])
+        self.set_blur_hints(*state["blur_hints"])
+
+    def set_blur_hints(self, *hints: BlurHintStr):
         for item in hints:
             if item not in BLUR_HINTS:
                 raise InvalidParamError(item, BLUR_HINTS)
-        flags = helpers.merge_flags(hints, BLUR_HINTS)
+        if hints:
+            flags = helpers.merge_flags(hints, BLUR_HINTS)
+        else:
+            flags = QtWidgets.QGraphicsBlurEffect.BlurHint()
         self.setBlurHints(flags)
 
-    def get_blur_hints(self) -> List[str]:
+    def get_blur_hints(self) -> List[BlurHintStr]:
         return [k for k, v in BLUR_HINTS.items() if v & self.blurHints()]
