@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
-from prettyqt import widgets, gui
+from prettyqt import gui, widgets
 
 
 QtWidgets.QGraphicsDropShadowEffect.__bases__ = (widgets.GraphicsEffect,)
