@@ -1,7 +1,10 @@
+from typing import Iterator, List
+
 from qtpy import QtWidgets
 
 from prettyqt import widgets
 
+
 QtWidgets.QGraphicsLayout.__bases__ = (widgets.GraphicsLayoutItem,)
 
 
@@ -17,15 +20,22 @@ class GraphicsLayout(QtWidgets.QGraphicsLayout):
     def __delitem__(self, index: int):
         self.removeAt(index)
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[QtWidgets.QGraphicsItem]:
         return iter(self[i] for i in range(self.count()))
 
     def __contains__(self, item):
         return item in self.get_children()
 
-    def get_children(self) -> list:
+    def __len__(self):
+        # for PySide2
+        return self.count()
+
+    def get_children(self) -> List[QtWidgets.QGraphicsItem]:
         return list(self)
 
+    def set_margin(self, margin: int):
+        self.setContentsMargins(margin, margin, margin, margin)
+
 
 if __name__ == "__main__":
     layout = GraphicsLayout()
