@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
 
 class GraphicsLayoutItem(QtWidgets.QGraphicsLayoutItem):
     def __repr__(self):
-        return f"{self.__class__.__name__}()"
+        return f"{type(self).__name__}()"
