@@ -1,6 +1,6 @@
 from qtpy import QtWidgets
 
-from prettyqt import widgets, core
+from prettyqt import core, widgets
 
 
 QtWidgets.QGraphicsLineItem.__bases__ = (widgets.GraphicsItem,)
@@ -8,9 +8,16 @@ QtWidgets.QGraphicsLineItem.__bases__ = (widgets.GraphicsItem,)
 
 class GraphicsLineItem(QtWidgets.QGraphicsLineItem):
     def __repr__(self):
-        return f"{self.__class__.__name__}({repr(self.get_line())})"
+        return f"{type(self).__name__}({repr(self.get_line())})"
 
-    def get_line(self):
+    def serialize_fields(self):
+        return dict(line=self.get_line())
+
+    def __setstate__(self, state):
+        super().__setstate__(state)
+        self.setLine(state["line"])
+
+    def get_line(self) -> core.Line:
         return core.LineF(self.line())
 
 
