@@ -1,6 +1,6 @@
 from qtpy import QtWidgets
 
-from prettyqt import widgets, core
+from prettyqt import core, widgets
 
 
 QtWidgets.QGraphicsRectItem.__bases__ = (widgets.AbstractGraphicsShapeItem,)
@@ -8,10 +8,14 @@ QtWidgets.QGraphicsRectItem.__bases__ = (widgets.AbstractGraphicsShapeItem,)
 
 class GraphicsRectItem(QtWidgets.QGraphicsRectItem):
     def __repr__(self):
-        return f"{self.__class__.__name__}({repr(self.get_rect())})"
+        return f"{type(self).__name__}({repr(self.get_rect())})"
 
     def get_rect(self):
         return core.RectF(self.rect())
 
     def serialize_fields(self):
         return dict(rect=self.get_rect())
+
+    def __setstate__(self, state):
+        super().__setstate__(state)
+        self.setRect(state["rect"])
