@@ -8,4 +8,4 @@ QtWidgets.QGraphicsSimpleTextItem.__bases__ = (widgets.AbstractGraphicsShapeItem
 
 class GraphicsSimpleTextItem(QtWidgets.QGraphicsSimpleTextItem):
     def __repr__(self):
-        return f"{self.__class__.__name__}({repr(self.text())})"
+        return f"{type(self).__name__}({self.text()!r})"
