@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
+from typing import Iterator, Optional, Tuple, Union
 
-from typing import Union, Optional
+from qtpy import QtCore, QtWidgets
 
-from qtpy import QtWidgets, QtCore
-from prettyqt import widgets
+from prettyqt import constants, widgets
+from prettyqt.utils import InvalidParamError
 
 
 QtWidgets.QGridLayout.__bases__ = (widgets.Layout,)
@@ -11,7 +11,7 @@ QtWidgets.QGridLayout.__bases__ = (widgets.Layout,)
 
 class GridLayout(QtWidgets.QGridLayout):
     def __getitem__(
-        self, idx: Union[tuple, int, str]
+        self, idx: Union[Tuple[int, int], int, str]
     ) -> Optional[Union[QtWidgets.QWidget, QtWidgets.QLayout]]:
         if isinstance(idx, tuple):
             item = self.itemAtPosition(*idx)
@@ -21,10 +21,14 @@ class GridLayout(QtWidgets.QGridLayout):
             return self.find_child(QtCore.QObject, idx)
         widget = item.widget()
         if widget is None:
-            widget = item.layout()
+            return item.layout()
         return widget
 
-    def __setitem__(self, idx, value):
+    def __setitem__(
+        self,
+        idx: Tuple[Union[int, slice], Union[int, slice]],
+        value: Union[QtWidgets.QWidget, QtWidgets.QLayout, QtWidgets.QLayoutItem],
+    ):
         row, col = idx
         rowspan = row.stop - row.start + 1 if isinstance(row, slice) else 1
         colspan = col.stop - col.start + 1 if isinstance(col, slice) else 1
@@ -41,15 +45,22 @@ class GridLayout(QtWidgets.QGridLayout):
         return dict(widgets=widgets, positions=positions)
 
     def __setstate__(self, state):
-        self.__init__()
         for i, (item, pos) in enumerate(zip(state["widgets"], state["positions"])):
             x, y, w, h = pos
             self[x : x + w - 1, y : y + h - 1] = item
 
-    def __iter__(self):
-        return iter(self[i] for i in range(self.count()) if self[i] is not None)
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
 
-    def __add__(self, other):
+    def __iter__(self) -> Iterator[Union[QtWidgets.QWidget, QtWidgets.QLayout]]:
+        return iter(item for i in range(self.count()) if (item := self[i]) is not None)
+
+    def __add__(
+        self,
+        other: Union[
+            tuple, list, QtWidgets.QWidget, QtWidgets.QLayout, QtWidgets.QLayoutItem
+        ],
+    ):
         if isinstance(other, (tuple, list)):
             for i, control in enumerate(other):
                 self[self.rowCount(), i] = other
@@ -57,7 +68,14 @@ class GridLayout(QtWidgets.QGridLayout):
             self[self.rowCount(), 0 : self.columnCount() - 1] = other
         return self
 
-    def add(self, item, rowstart, colstart, rowspan=1, colspan=1):
+    def add(
+        self,
+        item: Union[QtWidgets.QWidget, QtWidgets.QLayout, QtWidgets.QLayoutItem],
+        rowstart: int,
+        colstart: int,
+        rowspan: int = 1,
+        colspan: int = 1,
+    ):
         if isinstance(item, QtWidgets.QWidget):
             self.addWidget(item, rowstart, colstart, rowspan, colspan)
         elif isinstance(item, QtWidgets.QLayout):
@@ -65,9 +83,32 @@ class GridLayout(QtWidgets.QGridLayout):
         else:
             self.addItem(item, rowstart, colstart, rowspan, colspan)
 
-    def append(self, item):
+    def append(
+        self, item: Union[QtWidgets.QWidget, QtWidgets.QLayout, QtWidgets.QLayoutItem]
+    ):
         self[self.rowCount(), 0 : self.columnCount() - 1] = item
 
+    def set_origin_corner(self, corner: constants.CornerStr):
+        """Set the origin corner.
+
+        Args:
+            corner: origin corner
+
+        Raises:
+            InvalidParamError: corner does not exist
+        """
+        if corner not in constants.CORNER:
+            raise InvalidParamError(corner, constants.CORNER)
+        self.setOriginCorner(constants.CORNER[corner])
+
+    def get_origin_corner(self) -> constants.CornerStr:
+        """Return current origin corner.
+
+        Returns:
+            origin corner
+        """
+        return constants.CORNER.inverse[self.originCorner()]
+
 
 if __name__ == "__main__":
     app = widgets.app()
@@ -81,4 +122,4 @@ if __name__ == "__main__":
     widget.set_layout(layout)
     print(layout)
     widget.show()
-    app.exec_()
+    app.main_loop()
