@@ -1,17 +1,14 @@
-# -*- coding: utf-8 -*-
-
 import functools
-from typing import Iterable, Optional, Union, List
+import hashlib
+from typing import Iterable, List, Literal, Optional, Union
 
 from deprecated import deprecated
 from qtpy import QtCore, QtWidgets
 
-from prettyqt import core, widgets
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt import constants, core, widgets
+from prettyqt.utils import InvalidParamError, bidict
 
 
-ORIENTATIONS = bidict(horizontal=QtCore.Qt.Horizontal, vertical=QtCore.Qt.Vertical)
-
 MODES = bidict(
     interactive=QtWidgets.QHeaderView.Interactive,
     fixed=QtWidgets.QHeaderView.Fixed,
@@ -19,6 +16,7 @@ MODES = bidict(
     resize_to_contents=QtWidgets.QHeaderView.ResizeToContents,
 )
 
+ModeStr = Literal["interactive", "fixed", "stretch", "resize_to_contents"]
 
 QtWidgets.QHeaderView.__bases__ = (widgets.AbstractItemView,)
 
@@ -28,41 +26,51 @@ class HeaderView(QtWidgets.QHeaderView):
     section_vis_changed = QtCore.Signal(int, bool)
 
     def __init__(
-        self, orientation: Union[str, int], parent: Optional[QtWidgets.QWidget] = None
+        self,
+        orientation: Union[constants.OrientationStr, QtCore.Qt.Orientation],
+        parent: Optional[QtWidgets.QWidget] = None,
     ):
-        if orientation in ORIENTATIONS:
-            orientation = ORIENTATIONS[orientation]
-        super().__init__(orientation, parent=parent)
+        if isinstance(orientation, QtCore.Qt.Orientation):
+            ori = orientation
+        else:
+            ori = constants.ORIENTATION[orientation]
+        super().__init__(ori, parent=parent)
         self.setSectionsMovable(True)
         self.setSectionsClickable(True)
-        self._widget_name = parent.id if parent is not None else ""
+        self._widget_name = parent.get_id() if parent is not None else ""
+
+    def generate_header_id(self):
+        # return f"{self._widget_name}.state"
+        column_names = ",".join(self.get_section_labels())
+        columns_hash = hashlib.md5(column_names.encode("utf-8")).hexdigest()
+        return f"{type(self).__name__}_{columns_hash}.state"
 
     def save_state(
         self, settings: Optional[core.Settings] = None, key: Optional[str] = None
     ):
         settings = core.Settings() if settings is None else settings
-        key = f"{self._widget_name}.state" if key is None else key
+        key = self.generate_header_id() if key is None else key
         settings.set_value(key, self.saveState())
 
     def load_state(
         self, settings: Optional[core.Settings] = None, key: Optional[str] = None
     ) -> bool:
         settings = core.Settings() if settings is None else settings
-        key = f"{self._widget_name}.state" if key is None else key
+        key = self.generate_header_id() if key is None else key
         state = settings.get(key, None)
         if state is not None:
             self.restoreState(state)
             return True
         return False
 
-    def resize_sections(self, mode: str):
+    def resize_sections(self, mode: ModeStr):
         self.resizeSections(MODES[mode])
 
     @deprecated(reason="This method is deprecated, use set_resize_mode instead.")
-    def resize_mode(self, mode: str, col: Optional[int] = None):
+    def resize_mode(self, mode: ModeStr, col: Optional[int] = None):
         self.set_resize_mode(mode, col)
 
-    def set_resize_mode(self, mode: str, col: Optional[int] = None):
+    def set_resize_mode(self, mode: ModeStr, col: Optional[int] = None):
         if mode not in MODES:
             raise InvalidParamError(mode, MODES)
         if col is None:
@@ -118,4 +126,4 @@ if __name__ == "__main__":
     app = widgets.app()
     header = HeaderView("horizontal")
     header.show()
-    app.exec_()
+    app.main_loop()
