@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtGui, QtWidgets
 
 from prettyqt import core, gui, widgets
@@ -17,7 +15,7 @@ class KeySequenceEdit(QtWidgets.QKeySequenceEdit):
         self.keySequenceChanged.connect(self.value_changed)
 
     def __repr__(self):
-        return f"KeySequenceEdit({self.get_value()})"
+        return f"{type(self).__name__}({self.get_value()!r})"
 
     def set_value(self, value: str):
         seq = gui.KeySequence.fromString(value)
@@ -34,4 +32,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = KeySequenceEdit()
     widget.show()
-    app.exec_()
+    app.main_loop()
