@@ -1,29 +1,14 @@
-# -*- coding: utf-8 -*-
+from __future__ import annotations
 
 import pathlib
-
-from typing import List, Optional, Union
+from typing import List, Literal, Optional, Union
 
 from qtpy import QtCore, QtWidgets
 
-from prettyqt import core, gui, widgets
-from prettyqt.utils import bidict, colors, InvalidParamError, helpers
+from prettyqt import constants, core, gui, widgets
+from prettyqt.utils import InvalidParamError, bidict, colors, helpers
 
 
-H_ALIGNMENTS = bidict(
-    left=QtCore.Qt.AlignLeft,
-    right=QtCore.Qt.AlignRight,
-    center=QtCore.Qt.AlignHCenter,
-    justify=QtCore.Qt.AlignJustify,
-)
-
-V_ALIGNMENTS = bidict(
-    top=QtCore.Qt.AlignTop,
-    bottom=QtCore.Qt.AlignBottom,
-    center=QtCore.Qt.AlignVCenter,
-    baseline=QtCore.Qt.AlignBaseline,
-)
-
 TEXT_INTERACTION = bidict(
     none=QtCore.Qt.NoTextInteraction,
     by_mouse=QtCore.Qt.TextSelectableByMouse,
@@ -35,14 +20,25 @@ TEXT_INTERACTION = bidict(
     like_text_browser=QtCore.Qt.TextBrowserInteraction,
 )
 
-TEXT_FORMATS = bidict(
+TextInteractionStr = Literal[
+    "none",
+    "by_mouse",
+    "by_keyboard",
+    "accessible_by_mouse",
+    "accessible_by_keyboard",
+    "text_editable",
+    "like_text_editor",
+    "like_text_browser",
+]
+
+TEXT_FORMAT = bidict(
     rich=QtCore.Qt.RichText, plain=QtCore.Qt.PlainText, auto=QtCore.Qt.AutoText
 )
 
 if core.VersionNumber.get_qt_version() >= (5, 14, 0):
-    TEXT_FORMATS["markdown"] = QtCore.Qt.MarkdownText
+    TEXT_FORMAT["markdown"] = QtCore.Qt.MarkdownText
 
-WEIGHTS = gui.font.WEIGHTS  # type: ignore
+TextFormatStr = Literal["rich", "plain", "auto", "markdown"]
 
 
 QtWidgets.QLabel.__bases__ = (widgets.Frame,)
@@ -54,7 +50,7 @@ class Label(QtWidgets.QLabel):
         self.openExternalLinks()
 
     def __repr__(self):
-        return f"Label({self.text()!r})"
+        return f"{type(self).__name__}({self.text()!r})"
 
     def serialize_fields(self):
         pixmap = gui.Pixmap(self.pixmap())
@@ -68,13 +64,12 @@ class Label(QtWidgets.QLabel):
             open_external_links=self.openExternalLinks(),
             has_selected_text=self.hasSelectedText(),
             selected_text=self.selectedText(),
-            alignment=int(self.alignment()),
+            alignment=(self.get_horizontal_alignment(), self.get_vertical_alignment()),
             word_wrap=self.wordWrap(),
             text_interaction_flags=self.get_text_interaction(),
         )
 
     def __setstate__(self, state):
-        self.__init__()
         self.setText(state.get("text", ""))
         self.setIndent(state.get("indent", -1))
         self.setMargin(state.get("margin", 0))
@@ -82,11 +77,14 @@ class Label(QtWidgets.QLabel):
         self.set_text_format(state.get("text_format", 0))
         # self.setPixmap(state.get("pixmap"))
         self.setOpenExternalLinks(state.get("open_external_links", False))
-        self.setAlignment(QtCore.Qt.Alignment(state.get("alignment")))
+        self.set_alignment(*state.get("alignment"))
         self.setScaledContents(state["scaled_contents"])
         self.setWordWrap(state["word_wrap"])
 
-    def allow_links(self) -> "Label":
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
+    def allow_links(self) -> Label:
         # self.setText("<a href=\"http://example.com/\">Click Here!</a>")
         self.setTextFormat(QtCore.Qt.RichText)
         self.setTextInteractionFlags(QtCore.Qt.TextBrowserInteraction)
@@ -94,56 +92,74 @@ class Label(QtWidgets.QLabel):
         return self
 
     def set_alignment(
-        self, horizontal: Optional[str] = None, vertical: Optional[str] = None
+        self,
+        horizontal: Optional[constants.HorizontalAlignmentStr] = None,
+        vertical: Optional[constants.VerticalAlignmentStr] = None,
     ):
         """Set the alignment of the label's contents."""
         if horizontal is None and vertical is not None:
-            flag = V_ALIGNMENTS[vertical]
+            flag = constants.V_ALIGNMENT[vertical]
         elif vertical is None and horizontal is not None:
-            flag = H_ALIGNMENTS[horizontal]
+            flag = constants.H_ALIGNMENT[horizontal]
         elif vertical is not None and horizontal is not None:
-            flag = V_ALIGNMENTS[vertical] | H_ALIGNMENTS[horizontal]
+            flag = constants.V_ALIGNMENT[vertical] | constants.H_ALIGNMENT[horizontal]
         else:
             return
         self.setAlignment(flag)
         return self
 
-    def set_indent(self, indent: int) -> "Label":
+    def get_horizontal_alignment(self) -> constants.HorizontalAlignmentStr:
+        align = self.alignment()
+        if align & QtCore.Qt.AlignRight:
+            return "right"
+        elif align & QtCore.Qt.AlignHCenter:
+            return "center"
+        elif align & QtCore.Qt.AlignJustify:
+            return "justify"
+        else:
+            return "left"
+
+    def get_vertical_alignment(self) -> constants.VerticalAlignmentStr:
+        align = self.alignment()
+        if align & QtCore.Qt.AlignTop:
+            return "top"
+        elif align & QtCore.Qt.AlignBottom:
+            return "bottom"
+        elif align & QtCore.Qt.AlignBaseline:
+            return "baseline"
+        else:
+            return "center"
+
+    def set_indent(self, indent: int) -> Label:
         """Set the label's text indent in pixels."""
         self.setIndent(indent)
         return self
 
-    def set_text_format(self, text_format: str) -> "Label":
+    def set_text_format(self, text_format: TextFormatStr) -> Label:
         """Set the text format.
 
-        Allowed values are "rich", "plain", "auto", "markdown"
-
         Args:
             text_format: text format to use
 
         Raises:
             InvalidParamError: text format does not exist
         """
-        if text_format not in TEXT_FORMATS:
-            raise InvalidParamError(text_format, TEXT_FORMATS)
-        self.setTextFormat(TEXT_FORMATS[text_format])
+        if text_format not in TEXT_FORMAT:
+            raise InvalidParamError(text_format, TEXT_FORMAT)
+        self.setTextFormat(TEXT_FORMAT[text_format])
         return self
 
-    def get_text_format(self) -> str:
+    def get_text_format(self) -> TextFormatStr:
         """Return current text format.
 
-        Possible values: "rich", "plain", "auto", "markdown"
-
         Returns:
             text format
         """
-        return TEXT_FORMATS.inv[self.textFormat()]
+        return TEXT_FORMAT.inverse[self.textFormat()]
 
-    def set_text_interaction(self, *types: str) -> "Label":
+    def set_text_interaction(self, *types: TextInteractionStr) -> Label:
         """Set the text interaction mode.
 
-        Allowed values are "none", "by_mouse", "by_keyboard", "text_editable"
-
         Args:
             types: text interaction mode to use
 
@@ -157,59 +173,54 @@ class Label(QtWidgets.QLabel):
         self.setTextInteractionFlags(flags)
         return self
 
-    def get_text_interaction(self) -> List[str]:
+    def get_text_interaction(self) -> List[TextInteractionStr]:
         """Return current text interaction mode.
 
-        Possible values: "none", "by_mouse", "by_keyboard", "text_editable"
-
         Returns:
             list of text interaction modes
         """
         return [k for k, v in TEXT_INTERACTION.items() if v & self.textInteractionFlags()]
 
-    def set_text(self, text: str) -> "Label":
+    def set_text(self, text: str) -> Label:
         """Set the label's text."""
         self.setText(text)
         return self
 
-    def set_bold(self, bold: bool = True) -> "Label":
+    def set_bold(self, bold: bool = True) -> Label:
         font = self.font()
         font.setBold(bold)
         self.setFont(font)
         return self
 
-    def set_italic(self, italic: bool = True) -> "Label":
+    def set_italic(self, italic: bool = True) -> Label:
         font = self.font()
         font.setItalic(italic)
         self.setFont(font)
         return self
 
-    def set_point_size(self, size: int) -> "Label":
+    def set_point_size(self, size: int) -> Label:
         font = self.font()
         font.setPointSize(size)
         self.setFont(font)
         return self
 
-    def set_weight(self, weight: str) -> "Label":
+    def set_weight(self, weight: gui.font.WeightStr) -> Label:
         """Set the font weight.
 
-        Valid values are "thin", "extra_light", light", "medium", "demi_bold", "bold",
-                         "extra_bold", normal", "black"
-
         Args:
             weight: font weight
 
         Raises:
             InvalidParamError: invalid font weight
         """
-        if weight not in WEIGHTS:
-            raise InvalidParamError(weight, WEIGHTS)
+        if weight not in gui.font.WEIGHT:
+            raise InvalidParamError(weight, gui.font.WEIGHT)
         font = self.font()
-        font.setWeight(WEIGHTS[weight])
+        font.setWeight(gui.font.WEIGHT[weight])
         self.setFont(font)
         return self
 
-    def set_color(self, color: colors.ColorType) -> "Label":
+    def set_color(self, color: colors.ColorType) -> Label:
         with self.edit_stylesheet() as ss:
             if color is None:
                 ss.color.setValue("")
@@ -218,7 +229,7 @@ class Label(QtWidgets.QLabel):
                 ss.color.setValue(color.name())
         return self
 
-    def set_image(self, path: Union[pathlib.Path, str], width: int = 300) -> "Label":
+    def set_image(self, path: Union[pathlib.Path, str], width: int = 300) -> Label:
         self.setScaledContents(True)
         self.set_alignment(horizontal="center")
         self.setText(
@@ -231,7 +242,7 @@ class Label(QtWidgets.QLabel):
     @classmethod
     def image_from_path(
         cls, path: Union[pathlib.Path, str], parent: Optional[QtWidgets.QWidget] = None
-    ) -> "Label":
+    ) -> Label:
         pixmap = gui.Pixmap.from_file(path)
         label = cls(parent=parent)
         label.setPixmap(pixmap)
@@ -243,4 +254,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = Label("http://www.test.de")
     widget.show()
-    app.exec_()
+    app.main_loop()
