@@ -1,41 +1,41 @@
-# -*- coding: utf-8 -*-
-
-from typing import Union
+from typing import Literal, Union
 
 from qtpy import QtGui, QtWidgets
 
-from prettyqt import gui, widgets
-from prettyqt.utils import bidict, colors, InvalidParamError
+from prettyqt import constants, gui, widgets
+from prettyqt.utils import InvalidParamError, bidict, colors
 
 
-VIEW_MODES = bidict(
+VIEW_MODE = bidict(
     default=QtWidgets.QMdiArea.SubWindowView, tabbed=QtWidgets.QMdiArea.TabbedView
 )
 
+ViewModeStr = Literal["default", "tabbed"]
 
-WINDOW_ORDERS = bidict(
+WINDOW_ORDER = bidict(
     creation=QtWidgets.QMdiArea.CreationOrder,
     stacking=QtWidgets.QMdiArea.StackingOrder,
     activation_history=QtWidgets.QMdiArea.ActivationHistoryOrder,
 )
 
-TAB_POSITIONS = bidict(
+WindowOrderStr = Literal["creation", "stacking", "activation_history"]
+
+TAB_POSITION = bidict(
     north=QtWidgets.QTabWidget.North,
     south=QtWidgets.QTabWidget.South,
     west=QtWidgets.QTabWidget.West,
     east=QtWidgets.QTabWidget.East,
 )
 
-PATTERNS = gui.painter.PATTERNS  # type: ignore
+TabPositionStr = Literal["north", "south", "west", "east"]
 
 QtWidgets.QMdiArea.__bases__ = (widgets.AbstractScrollArea,)
 
 
 class MdiArea(QtWidgets.QMdiArea):
-    def __add__(self, other):
-        if isinstance(other, QtWidgets.QWidget):
-            self.add(other)
-            return self
+    def __add__(self, other: QtWidgets.QWidget):
+        self.add(other)
+        return self
 
     def serialize_fields(self):
         return dict(
@@ -46,10 +46,16 @@ class MdiArea(QtWidgets.QMdiArea):
             document_mode=self.documentMode(),
         )
 
-    def set_view_mode(self, mode: str):
-        """Set view mode for the MDI area.
+    def __setstate__(self, state):
+        super().__setstate__(state)
+        self.set_view_mode(state["view_mode"])
+        self.set_window_order(state["window_order"])
+        self.set_tab_position(state["tab_position"])
+        self.set_background(state["background"])
+        self.setDocumentMode(state["document_mode"])
 
-        Valid values are "default", "tabbed"
+    def set_view_mode(self, mode: ViewModeStr):
+        """Set view mode for the MDI area.
 
         Args:
             mode: view mode to use
@@ -57,82 +63,71 @@ class MdiArea(QtWidgets.QMdiArea):
         Raises:
             InvalidParamError: view mode does not exist
         """
-        if mode not in VIEW_MODES:
-            raise InvalidParamError(mode, VIEW_MODES)
-        self.setViewMode(VIEW_MODES[mode])
+        if mode not in VIEW_MODE:
+            raise InvalidParamError(mode, VIEW_MODE)
+        self.setViewMode(VIEW_MODE[mode])
 
-    def get_view_mode(self) -> str:
+    def get_view_mode(self) -> ViewModeStr:
         """Return current view mode.
 
-        Possible values: "default", "tabbed"
-
         Returns:
             view mode
         """
-        return VIEW_MODES.inv[self.viewMode()]
+        return VIEW_MODE.inverse[self.viewMode()]
 
-    def set_window_order(self, mode: str):
+    def set_window_order(self, mode: WindowOrderStr):
         """Set the window order behaviour for the MDI area.
 
-        Valid values are "creation", "stacking", "activation_history"
-
         Args:
             mode: window order behaviour to use
 
         Raises:
             InvalidParamError: window order mode not existing.
         """
-        if mode not in WINDOW_ORDERS:
-            raise InvalidParamError(mode, WINDOW_ORDERS)
-        self.setActivationOrder(WINDOW_ORDERS[mode])
+        if mode not in WINDOW_ORDER:
+            raise InvalidParamError(mode, WINDOW_ORDER)
+        self.setActivationOrder(WINDOW_ORDER[mode])
 
-    def get_window_order(self) -> str:
+    def get_window_order(self) -> WindowOrderStr:
         """Return current window order.
 
-        Possible values: "creation", "stacking", "activation_history"
-
         Returns:
             view mode
         """
-        return WINDOW_ORDERS.inv[self.activationOrder()]
+        return WINDOW_ORDER.inverse[self.activationOrder()]
 
-    def set_tab_position(self, position: str):
+    def set_tab_position(self, position: TabPositionStr):
         """Set tab position for the MDI area.
 
-        Valid values are "north", "south", "west", "east"
-
         Args:
             position: tabs position to use
 
         Raises:
             InvalidParamError: tab position does not exist
         """
-        if position not in TAB_POSITIONS:
-            raise InvalidParamError(position, TAB_POSITIONS)
-        self.setTabPosition(TAB_POSITIONS[position])
+        if position not in TAB_POSITION:
+            raise InvalidParamError(position, TAB_POSITION)
+        self.setTabPosition(TAB_POSITION[position])
 
-    def get_tab_position(self) -> str:
+    def get_tab_position(self) -> TabPositionStr:
         """Return current tab position.
 
-        Possible values: "north", "south", "west", "east"
-
         Returns:
             tab position
         """
-        return TAB_POSITIONS.inv[self.tabPosition()]
+        return TAB_POSITION.inverse[self.tabPosition()]
 
     def set_background(
         self,
         brush_or_color: Union[QtGui.QBrush, colors.ColorType],
-        pattern: str = "solid",
+        pattern: constants.PatternStr = "solid",
     ):
         if isinstance(brush_or_color, QtGui.QBrush):
-            self.setBackground(brush_or_color)
+            brush = brush_or_color
         else:
-            pattern = PATTERNS[pattern]
             color = colors.get_color(brush_or_color)
-            brush = gui.Brush(color, pattern)
-            self.setBackground(brush)
+            brush = gui.Brush(color, constants.PATTERN[pattern])
+        self.setBackground(brush)
 
     def get_background(self) -> gui.Brush:
         return gui.Brush(self.background())
@@ -156,4 +151,4 @@ if __name__ == "__main__":
     widget.add(le)
     widget.add(le2)
     widget.show()
-    app.exec_()
+    app.main_loop()
