@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
 from prettyqt import widgets
@@ -16,4 +14,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = MdiSubWindow()
     widget.show()
-    app.exec_()
+    app.main_loop()
