@@ -1,13 +1,11 @@
-# -*- coding: utf-8 -*-
-
 import sys
 import traceback
-from typing import Optional, List
+from typing import List, Literal, Optional, Union
 
 from qtpy import QtCore, QtWidgets
 
-from prettyqt import gui, widgets, core
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt import core, iconprovider, widgets
+from prettyqt.utils import InvalidParamError, bidict
 
 
 ICONS = bidict(
@@ -18,6 +16,8 @@ ICONS = bidict(
     question=QtWidgets.QMessageBox.Question,
 )
 
+IconStr = Literal["none", "information", "warning", "critical", "question"]
+
 BUTTONS = bidict(
     none=QtWidgets.QMessageBox.NoButton,
     cancel=QtWidgets.QMessageBox.Cancel,
@@ -40,11 +40,35 @@ BUTTONS = bidict(
     ignore=QtWidgets.QMessageBox.Ignore,
 )
 
-TEXT_FORMATS = bidict(
+ButtonStr = Literal[
+    "none",
+    "cancel",
+    "ok",
+    "save",
+    "open",
+    "close",
+    "discard",
+    "apply",
+    "reset",
+    "restore_defaults",
+    "help",
+    "save_all",
+    "yes",
+    "yes_to_all",
+    "no",
+    "no_to_all",
+    "abort",
+    "retry",
+    "ignore",
+]
+
+TEXT_FORMAT = bidict(
     rich=QtCore.Qt.RichText, plain=QtCore.Qt.PlainText, auto=QtCore.Qt.AutoText
 )
 if core.VersionNumber.get_qt_version() >= (5, 14, 0):
-    TEXT_FORMATS["markdown"] = QtCore.Qt.MarkdownText
+    TEXT_FORMAT["markdown"] = QtCore.Qt.MarkdownText
+
+TextFormatStr = Literal["rich", "plain", "auto"]
 
 QtWidgets.QMessageBox.__bases__ = (widgets.BaseDialog,)
 
@@ -52,8 +76,8 @@ QtWidgets.QMessageBox.__bases__ = (widgets.BaseDialog,)
 class MessageBox(QtWidgets.QMessageBox):
     def __init__(
         self,
-        icon: gui.icon.IconType = None,
-        title: Optional[str] = None,
+        icon: iconprovider.IconType = None,
+        title: str = "",
         text: str = "",
         informative_text: str = "",
         details: str = "",
@@ -77,8 +101,8 @@ class MessageBox(QtWidgets.QMessageBox):
     def message(
         cls,
         text: str,
-        title: str = None,
-        icon: gui.icon.IconType = None,
+        title: str = "",
+        icon: iconprovider.IconType = None,
         detail_text: Optional[str] = None,
     ) -> str:
         m = cls("none", title, text)
@@ -94,27 +118,22 @@ class MessageBox(QtWidgets.QMessageBox):
         dlg = cls(text=str(value), title=str(exctype), icon="critical", details=tb)
         dlg.show_blocking()
 
-    def set_icon(self, icon: gui.icon.IconType):
+    def set_icon(self, icon: Union[iconprovider.IconType, IconStr]):
         if icon in ICONS:
             self.setIcon(ICONS[icon])
-            return None
-        icon = gui.icon.get_icon(icon)
-        self.setIconPixmap(icon.get_pixmap(size=64))
+        else:
+            ico = iconprovider.get_icon(icon)
+            self.setIconPixmap(ico.get_pixmap(size=64))
 
-    def show_blocking(self) -> str:
-        return BUTTONS.inv[self.exec_()]
+    def show_blocking(self) -> ButtonStr:
+        return BUTTONS.inverse[self.exec_()]
 
-    def get_standard_buttons(self) -> List[str]:
+    def get_standard_buttons(self) -> List[ButtonStr]:
         return [k for k, v in BUTTONS.items() if v & self.standardButtons()]
 
-    def add_button(self, button: str) -> QtWidgets.QPushButton:
+    def add_button(self, button: ButtonStr) -> QtWidgets.QPushButton:
         """Add a default button.
 
-        Valid arguments: "none", "cancel", "ok", "save", "open", "close",
-                         "discard", "apply", "reset", "restore_defaults",
-                         "help", "save_all", "yes", "yes_to_all", "no",
-                         "no_to_all", "abort", "retry", "ignore"
-
         Args:
             button: button to add
 
@@ -134,30 +153,26 @@ class MessageBox(QtWidgets.QMessageBox):
     #     error_text = str(exception[1])
     #     widgets.MessageBox.message(error_text, header, "mdi.exclamation")
 
-    def set_text_format(self, text_format: str):
+    def set_text_format(self, text_format: TextFormatStr):
         """Set the text format.
 
-        Allowed values are "rich", "plain", "auto"
-
         Args:
             text_format: text format to use
 
         Raises:
             InvalidParamError: text format does not exist
         """
-        if text_format not in TEXT_FORMATS:
-            raise InvalidParamError(text_format, TEXT_FORMATS)
-        self.setTextFormat(TEXT_FORMATS[text_format])
+        if text_format not in TEXT_FORMAT:
+            raise InvalidParamError(text_format, TEXT_FORMAT)
+        self.setTextFormat(TEXT_FORMAT[text_format])
 
-    def get_text_format(self) -> str:
+    def get_text_format(self) -> TextFormatStr:
         """Return current text format.
 
-        Possible values: "rich", "plain", "auto"
-
         Returns:
             text format
         """
-        return TEXT_FORMATS.inv[self.textFormat()]
+        return TEXT_FORMAT.inverse[self.textFormat()]
 
 
 if __name__ == "__main__":
@@ -166,4 +181,4 @@ if __name__ == "__main__":
     ret.set_icon("mdi.folder")
     ret.show()
     print(ret)
-    app.exec_()
+    app.main_loop()
