@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-
-from typing import Optional, Callable
+from typing import Callable, Optional
 
 from qtpy import QtWidgets
 
@@ -20,28 +18,16 @@ class PushButton(QtWidgets.QPushButton):
         parent: Optional[QtWidgets.QWidget] = None,
         callback: Optional[Callable] = None,
     ):
+        if label is None:
+            label = ""
         super().__init__(label, parent)
         if callback:
             self.clicked.connect(callback)
         self.toggled.connect(self.value_changed)
 
-    def get_value(self) -> bool:
-        return self.isChecked()
-
-    def set_value(self, value: bool):
-        self.setChecked(value)
-
-    @property
-    def is_on(self) -> bool:
-        return self.isChecked()
-
-    @is_on.setter
-    def is_on(self, state: bool):
-        self.setChecked(state)
-
 
 if __name__ == "__main__":
     app = widgets.app()
     widget = PushButton("This is a test")
     widget.show()
-    app.exec_()
+    app.main_loop()
