@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
 from prettyqt import widgets
@@ -13,9 +11,12 @@ class ScrollArea(QtWidgets.QScrollArea):
         return dict(widget=self.widget(), resizable=self.widgetResizable())
 
     def __setstate__(self, state):
-        self.__init__()
+        super().__setstate__(state)
         self.set_widget(state["widget"])
         self.setWidgetResizable(state["resizable"])
 
-    def set_widget(self, widget):
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
+    def set_widget(self, widget: QtWidgets.QWidget):
         self.setWidget(widget)
