@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
 from prettyqt import widgets
 
+
 QtWidgets.QSizeGrip.__bases__ = (widgets.Widget,)
 
 
@@ -13,6 +12,7 @@ class SizeGrip(QtWidgets.QSizeGrip):
 
 if __name__ == "__main__":
     app = widgets.app()
-    widget = SizeGrip()
+    w = widgets.Widget()
+    widget = SizeGrip(w)
     widget.show()
-    app.exec_()
+    app.main_loop()
