@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from typing import Optional
 
 from qtpy import QtWidgets
@@ -39,20 +37,18 @@ class SpinBox(QtWidgets.QSpinBox):
         )
 
     def __setstate__(self, state):
-        self.__init__()
+        super().__setstate__(state)
         self.set_range(*state["range"])
         self.setValue(state["value"])
-        self.setEnabled(state.get("enabled", True))
-        self.setToolTip(state.get("tool_tip", ""))
-        self.setStatusTip(state.get("status_tip", ""))
         self.setSingleStep(state["single_step"])
         self.setPrefix(state["prefix"])
         self.setSuffix(state["suffix"])
-        self.set_button_symbols(state["button_symbols"])
-        self.set_correction_mode(state["correction_mode"])
         self.setDisplayIntegerBase(state["int_base"])
         self.set_step_type(state["step_type"])
 
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
     def set_range(self, start: Optional[int], end: Optional[int]):
         if start is None:
             start = -2147483647
@@ -68,4 +64,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = SpinBox()
     widget.show()
-    app.exec_()
+    app.main_loop()
