@@ -1,14 +1,9 @@
-# -*- coding: utf-8 -*-
-
-from typing import Union, Optional, List
+from typing import Iterator, List, Optional, Union
 
 from qtpy import QtCore, QtWidgets
 
-from prettyqt import widgets
-from prettyqt.utils import bidict, InvalidParamError
-
-
-ORIENTATIONS = bidict(horizontal=QtCore.Qt.Horizontal, vertical=QtCore.Qt.Vertical)
+from prettyqt import constants, widgets
+from prettyqt.utils import InvalidParamError
 
 
 QtWidgets.QSplitter.__bases__ = (widgets.Frame,)
@@ -17,18 +12,25 @@ QtWidgets.QSplitter.__bases__ = (widgets.Frame,)
 class Splitter(QtWidgets.QSplitter):
     def __init__(
         self,
-        orientation: Union[str, int] = "horizontal",
+        orientation: Union[
+            constants.OrientationStr, QtCore.Qt.Orientation
+        ] = "horizontal",
         parent: Optional[QtWidgets.QWidget] = None,
     ):
-        if orientation in ORIENTATIONS:
-            orientation = ORIENTATIONS[orientation]
-        super().__init__(orientation, parent)
+        if isinstance(orientation, QtCore.Qt.Orientation):
+            ori = orientation
+        else:
+            ori = constants.ORIENTATION[orientation]
+        super().__init__(ori, parent)
 
-    def __getitem__(self, index: Union[int, str]):
+    def __getitem__(self, index: Union[int, str]) -> QtWidgets.QWidget:
         if isinstance(index, int):
             return self.widget(index)
         else:
-            return self.findChild(QtWidgets.QWidget, index)
+            result = self.find_child(QtWidgets.QWidget, index)
+            if result is None:
+                raise KeyError("Widget not found")
+            return result
 
     def __setitem__(self, index: int, value: QtWidgets.QWidget):
         self.replaceWidget(index, value)
@@ -43,24 +45,24 @@ class Splitter(QtWidgets.QSplitter):
         )
 
     def __setstate__(self, state):
-        self.__init__(state["orientation"])
         for item in state["items"]:
             self.addWidget(item)
         self.setHandleWidth(state["handle_width"])
         self.setChildrenCollapsible(state["children_collapsible"])
         self.setOpaqueResize(state["opaque_resize"])
 
-    def __iter__(self):
+    def __reduce__(self):
+        return type(self), (self.orientation(),), self.__getstate__()
+
+    def __iter__(self) -> Iterator[QtWidgets.QWidget]:
         return iter(self.get_children())
 
     def __len__(self) -> int:
         return self.count()
 
     def __add__(self, other: Union[QtWidgets.QWidget, QtWidgets.QLayout]):
-        if isinstance(other, (QtWidgets.QLayout, QtWidgets.QWidget)):
-            self.add(other)
-            return self
-        raise TypeError(f"Invalid type: {type(other)}")
+        self.add(other)
+        return self
 
     def get_children(self) -> List[QtWidgets.QWidget]:
         return [self[i] for i in range(self.count())]
@@ -68,10 +70,11 @@ class Splitter(QtWidgets.QSplitter):
     def add_widget(self, widget: QtWidgets.QWidget):
         self.addWidget(widget)
 
-    def add_layout(self, layout: QtWidgets.QLayout):
+    def add_layout(self, layout: QtWidgets.QLayout) -> widgets.Widget:
         widget = widgets.Widget()
         widget.set_layout(layout)
         self.addWidget(widget)
+        return widget
 
     def add(self, *item: Union[QtWidgets.QWidget, QtWidgets.QLayout]):
         for i in item:
@@ -87,40 +90,35 @@ class Splitter(QtWidgets.QSplitter):
         horizontal: bool = False,
         parent: Optional[QtWidgets.QWidget] = None,
     ):
-        orientation = "horizontal" if horizontal else "vertical"
-        splitter = cls(orientation, parent=parent)
+        splitter = cls("horizontal" if horizontal else "vertical", parent=parent)
         for widget in widgets:
             splitter += widget
         return splitter
 
-    def set_orientation(self, orientation: str):
+    def set_orientation(self, orientation: constants.OrientationStr):
         """Set the orientation of the splitter.
 
-        Allowed values are "horizontal", "vertical"
-
         Args:
             orientation: orientation for the splitter
 
         Raises:
             InvalidParamError: orientation does not exist
         """
-        if orientation not in ORIENTATIONS:
-            raise InvalidParamError(orientation, ORIENTATIONS)
-        self.setOrientation(ORIENTATIONS[orientation])
+        if orientation not in constants.ORIENTATION:
+            raise InvalidParamError(orientation, constants.ORIENTATION)
+        self.setOrientation(constants.ORIENTATION[orientation])
 
-    def get_orientation(self) -> str:
+    def get_orientation(self) -> constants.OrientationStr:
         """Return current orientation.
 
-        Possible values: "horizontal", "vertical"
-
         Returns:
             orientation
         """
-        return ORIENTATIONS.inv[self.orientation()]
+        return constants.ORIENTATION.inverse[self.orientation()]
 
 
 if __name__ == "__main__":
     app = QtWidgets.QApplication([])
     widget = Splitter()
     widget.show()
-    app.exec_()
+    app.main_loop()
