@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+from typing import Union
 
 from qtpy import QtWidgets
 
@@ -13,16 +13,17 @@ class StackedLayout(QtWidgets.QStackedLayout):
         return dict(items=self.get_children())
 
     def __setstate__(self, state):
-        self.__init__()
         for item in state["items"]:
             self.add(item)
 
-    def __add__(self, other):
-        if isinstance(other, (QtWidgets.QWidget, QtWidgets.QLayout)):
-            self.add(other)
-            return self
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
 
-    def set_current_widget(self, widget):
+    def __add__(self, other: Union[QtWidgets.QWidget, QtWidgets.QLayout]):
+        self.add(other)
+        return self
+
+    def set_current_widget(self, widget: QtWidgets.QWidget):
         self.setCurrentWidget(widget)
 
 
@@ -38,4 +39,4 @@ if __name__ == "__main__":
     layout += widget3
     widget.set_layout(layout)
     widget.show()
-    app.exec_()
+    app.main_loop()
