@@ -1,6 +1,7 @@
-# -*- coding: utf-8 -*-
+from __future__ import annotations
 
 from typing import Union
+
 from qtpy import QtWidgets
 
 from prettyqt import widgets
@@ -14,9 +15,9 @@ class StatusBar(QtWidgets.QStatusBar):
         super().__init__(*args, **kwargs)
         self.progress_bar = widgets.ProgressBar()
 
-    def __add__(self, other: Union[QtWidgets.QAction, QtWidgets.QWidget]) -> "StatusBar":
+    def __add__(self, other: Union[QtWidgets.QAction, QtWidgets.QWidget]) -> StatusBar:
         if isinstance(other, QtWidgets.QAction):
-            self.add_action(other)
+            self.addAction(other)
             return self
         elif isinstance(other, QtWidgets.QWidget):
             self.addWidget(other)
@@ -55,4 +56,4 @@ if __name__ == "__main__":
     status_bar.setup_default_bar()
     dlg.setStatusBar(status_bar)
     dlg.show()
-    app.exec_()
+    app.main_loop()
