@@ -1,8 +1,10 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
+from prettyqt import widgets
+
+
+QtWidgets.QStyledItemDelegate.__bases__ = (widgets.AbstractItemDelegate,)
+
 
 class StyledItemDelegate(QtWidgets.QStyledItemDelegate):
-
     pass
