@@ -1,5 +1,12 @@
+from typing import Literal
+
 from qtpy import QtCore, QtWidgets
 
+from prettyqt import widgets
+
+
+QtWidgets.QStyleOptionSlider.__bases__ = (widgets.StyleOptionComplex,)
+
 
 class StyleOptionSlider(QtWidgets.QStyleOptionSlider):
     def is_horizontal(self) -> bool:
@@ -26,5 +33,5 @@ class StyleOptionSlider(QtWidgets.QStyleOptionSlider):
         """Set slider orientation to vertical."""
         self.orientation = QtCore.Qt.Vertical
 
-    def get_orientation(self) -> str:
+    def get_orientation(self) -> Literal["horizontal", "vertical"]:
         return "horizontal" if self.is_horizontal() else "vertical"
