@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtWidgets
 
-from prettyqt import gui
+from prettyqt import gui, iconprovider
 from prettyqt.utils import bidict
 
+
 ACTIVATION_REASONS = bidict(
     unknown=QtWidgets.QSystemTrayIcon.Unknown,
     context=QtWidgets.QSystemTrayIcon.Context,
@@ -22,29 +21,29 @@ MESSAGE_ICONS = bidict(
 
 
 class SystemTrayIcon(QtWidgets.QSystemTrayIcon):
-    def set_icon(self, icon: gui.icon.IconType):
+    def set_icon(self, icon: iconprovider.IconType):
         """Set the system tray icon.
 
         Args:
             icon: icon to use
         """
-        icon = gui.icon.get_icon(icon)
+        icon = iconprovider.get_icon(icon)
         self.setIcon(icon)
 
     def show_message(
         self,
         title: str,
         message: str = "",
-        icon: gui.icon.IconType = None,
+        icon: iconprovider.IconType = None,
         timeout: int = 10,
     ):
         if icon is None:
-            icon = "none"
+            ico = gui.Icon()
         if icon in MESSAGE_ICONS:
-            icon = MESSAGE_ICONS[icon]
+            ico = MESSAGE_ICONS[icon]
         else:
-            icon = gui.icon.get_icon(icon)
-        self.showMessage(title, message, icon, timeout * 1000)
+            ico = iconprovider.get_icon(icon)
+        self.showMessage(title, message, ico, timeout * 1000)
 
 
 if __name__ == "__main__":
@@ -55,4 +54,4 @@ if __name__ == "__main__":
     icon.set_icon("mdi.folder")
     print(icon.isSystemTrayAvailable())
     icon.show_message("a", "b", "information")
-    app.exec_()
+    app.main_loop()
