@@ -1,27 +1,21 @@
-# -*- coding: utf-8 -*-
-
-from typing import Optional
+from typing import Literal, Optional, Tuple, Union
 
+from deprecated import deprecated
 from qtpy import QtCore, QtGui, QtWidgets
 
-from prettyqt import core, widgets
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt import constants, core, widgets
+from prettyqt.utils import InvalidParamError, bidict
 
 
-ELIDE_MODES = bidict(
-    left=QtCore.Qt.ElideLeft,
-    right=QtCore.Qt.ElideRight,
-    middle=QtCore.Qt.ElideMiddle,
-    none=QtCore.Qt.ElideNone,
-)
-
-REMOVE_BEHAVIOURS = bidict(
+REMOVE_BEHAVIOUR = bidict(
     left_tab=QtWidgets.QTabBar.SelectLeftTab,
     right_tab=QtWidgets.QTabBar.SelectRightTab,
     previous_tab=QtWidgets.QTabBar.SelectPreviousTab,
 )
 
-SHAPES = bidict(
+RemoveBehaviourStr = Literal["left_tab", "right_tab", "previous_tab"]
+
+SHAPE = bidict(
     rounded_north=QtWidgets.QTabBar.RoundedNorth,
     rounded_south=QtWidgets.QTabBar.RoundedSouth,
     rounded_west=QtWidgets.QTabBar.RoundedWest,
@@ -32,8 +26,20 @@ SHAPES = bidict(
     triangular_east=QtWidgets.QTabBar.TriangularEast,
 )
 
+ShapeStr = Literal[
+    "rounded_north",
+    "rounded_south",
+    "rounded_west",
+    "rounded_east",
+    "triangular_north",
+    "triangular_south",
+    "triangular_west",
+    "triangular_east",
+]
+
 POSITIONS = bidict(left=QtWidgets.QTabBar.LeftSide, right=QtWidgets.QTabBar.RightSide)
 
+PositionStr = Literal["left", "right"]
 
 QtWidgets.QTabBar.__bases__ = (widgets.Widget,)
 
@@ -46,13 +52,14 @@ class TabBar(QtWidgets.QTabBar):
 
         self.setAcceptDrops(True)
         self.set_elide_mode("right")
-        self.set_remove_behaviour("left_tab")
-        self.mouse_cursor = QtGui.QCursor()
+        self.set_selection_behavior_on_remove("left_tab")
 
-    def __getitem__(self, index):
+    def __getitem__(self, index: Tuple[int, str]):
         return self.tabButton(index[0], POSITIONS[index[1]])
 
-    def __setitem__(self, index, value):
+    def __setitem__(
+        self, index: Tuple[int, PositionStr], value: Optional[QtWidgets.QWidget]
+    ):
         self.set_tab(index[0], index[1], value)
 
     def serialize_fields(self):
@@ -67,7 +74,6 @@ class TabBar(QtWidgets.QTabBar):
         )
 
     def __setstate__(self, state):
-        self.__init__()
         self.setDocumentMode(state.get("document_mode", False))
         self.setMovable(state.get("movable", False))
         # self.setShape(state.get("shape", "rounded"))
@@ -76,68 +82,76 @@ class TabBar(QtWidgets.QTabBar):
         self.set_elide_mode(state.get("elide_mode"))
         self.setCurrentIndex(state.get("index", 0))
 
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
     #  Send the on_detach when a tab is double clicked
     def mouseDoubleClickEvent(self, event):
         event.accept()
-        self.on_detach.emit(self.tabAt(event.pos()), self.mouse_cursor.pos())
+        tab = self.tabAt(event.pos())
+        pos = QtGui.QCursor.pos()
+        self.on_detach.emit(tab, pos)
 
-    def set_icon_size(self, size: int) -> None:
-        """Set the icon size for the tabs.
+    def set_icon_size(self, size: Union[int, Tuple[int, int], QtCore.QSize]):
+        """Set size of the icons."""
+        if isinstance(size, int):
+            size = core.Size(size, size)
+        elif isinstance(size, tuple):
+            size = core.Size(*size)
+        self.setIconSize(size)
 
-        Args:
-            size: height/width of the icons
-        """
-        self.setIconSize(QtCore.QSize(size, size))
+    def get_icon_size(self) -> core.Size:
+        return core.Size(self.iconSize())
 
     def set_tab(
-        self, index: int, position: str, widget: Optional[QtWidgets.QWidget]
+        self, index: int, position: PositionStr, widget: Optional[QtWidgets.QWidget]
     ) -> None:
-        self.setTabButton(index, POSITIONS[position], widget)
+        self.setTabButton(index, POSITIONS[position], widget)  # type: ignore
 
-    def set_remove_behaviour(self, mode: str) -> None:
+    @deprecated(
+        reason="This method is deprecated, use set_selection_behavior_on_remove instead."
+    )
+    def set_remove_behaviour(self, mode: RemoveBehaviourStr) -> None:
+        self.set_selection_behavior_on_remove(mode)
+
+    def set_selection_behavior_on_remove(self, mode: RemoveBehaviourStr) -> None:
         """Set the remove hehaviour.
 
         What tab should be set as current when removeTab is called
         if the removed tab is also the current tab.
-        Possible values: left, right, previous
+
         Args:
             mode: new remove behaviour
         """
-        if mode not in REMOVE_BEHAVIOURS:
-            raise InvalidParamError(mode, REMOVE_BEHAVIOURS)
-        self.setSelectionBehaviorOnRemove(REMOVE_BEHAVIOURS[mode])
+        if mode not in REMOVE_BEHAVIOUR:
+            raise InvalidParamError(mode, REMOVE_BEHAVIOUR)
+        self.setSelectionBehaviorOnRemove(REMOVE_BEHAVIOUR[mode])
 
-    def get_remove_behaviour(self) -> str:
+    def get_remove_behaviour(self) -> RemoveBehaviourStr:
         """Return remove behaviour.
 
-        possible values are "left_tab", "right_tab", "previous_tab"
-
         Returns:
             remove behaviour
         """
-        return REMOVE_BEHAVIOURS.inv[self.selectionBehaviorOnRemove()]
+        return REMOVE_BEHAVIOUR.inverse[self.selectionBehaviorOnRemove()]
 
-    def set_elide_mode(self, mode: str) -> None:
+    def set_elide_mode(self, mode: constants.ElideModeStr) -> None:
         """Set elide mode.
 
-        Valid values are "left", "right", "middle", "none"
-
         Args:
             mode: elide mode to use
 
         Raises:
             InvalidParamError: invalid elide mode
         """
-        if mode not in ELIDE_MODES:
-            raise InvalidParamError(mode, ELIDE_MODES)
-        self.setElideMode(ELIDE_MODES[mode])
+        if mode not in constants.ELIDE_MODE:
+            raise InvalidParamError(mode, constants.ELIDE_MODE)
+        self.setElideMode(constants.ELIDE_MODE[mode])
 
-    def get_elide_mode(self) -> str:
+    def get_elide_mode(self) -> constants.ElideModeStr:
         """Return elide mode.
 
-        possible values are "left", "right", "middle", "none"
-
         Returns:
             elide mode
         """
-        return ELIDE_MODES.inv[self.elideMode()]
+        return constants.ELIDE_MODE.inverse[self.elideMode()]
