@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+from typing import Tuple
 
 from qtpy import QtCore, QtWidgets
 
@@ -9,17 +9,19 @@ QtWidgets.QTableWidget.__bases__ = (widgets.TableView,)
 
 
 class TableWidget(QtWidgets.QTableWidget):
-    def sort(self, column=0, reverse=False):
-        order = QtCore.Qt.DescendingOrder if reverse else QtCore.Qt.AscendingOrder
-        self.sortItems(column, order)
-
-    def __getitem__(self, index):
+    def __getitem__(self, index: Tuple[int, int]) -> QtWidgets.QTableWidgetItem:
         return self.item(*index)
 
-    def __setitem__(self, index, value):
-        print(index, value)
+    def __setitem__(self, index: Tuple[int, int], value: QtWidgets.QTableWidgetItem):
         self.setItem(index[0], index[1], value)
 
+    def __delitem__(self, index: Tuple[int, int]):
+        self.takeItem(*index)
+
+    def sort(self, column: int = 0, reverse: bool = False):
+        order = QtCore.Qt.DescendingOrder if reverse else QtCore.Qt.AscendingOrder
+        self.sortItems(column, order)
+
 
 if __name__ == "__main__":
     app = QtWidgets.QApplication([])
@@ -29,4 +31,4 @@ if __name__ == "__main__":
     widget.insertRow(0)
     widget[0, 0] = widgets.TableWidgetItem("test")
     widget.show()
-    app.exec_()
+    app.main_loop()
