@@ -1,24 +1,26 @@
-# -*- coding: utf-8 -*-
-
-from typing import Union, Optional, Dict
+from typing import Dict, List, Literal, Optional, Tuple, Union
 
 from qtpy import QtCore, QtGui, QtWidgets
 
-from prettyqt import core, gui, widgets
-from prettyqt.utils import bidict, InvalidParamError, autoslot
+from prettyqt import core, gui, iconprovider, widgets
+from prettyqt.utils import InvalidParamError, bidict
 
 
 TAB_SHAPES = bidict(
     rounded=QtWidgets.QTabWidget.Rounded, triangular=QtWidgets.QTabWidget.Triangular
 )
 
-TAB_POSITIONS = bidict(
+TabShapeStr = Literal["rounded", "triangular"]
+
+TAB_POSITION = bidict(
     north=QtWidgets.QTabWidget.North,
     south=QtWidgets.QTabWidget.South,
     west=QtWidgets.QTabWidget.West,
     east=QtWidgets.QTabWidget.East,
 )
 
+TabPositionStr = Literal["north", "south", "west", "east"]
+
 QtWidgets.QTabWidget.__bases__ = (widgets.Widget,)
 
 
@@ -41,7 +43,7 @@ class TabWidget(QtWidgets.QTabWidget):
 
         # Used to keep a reference to detached tabs since their QMainWindow
         # does not have a parent
-        self.detached_tabs: Dict[str, DetachedTab] = dict()
+        self.detached_tabs: Dict[str, DetachedTab] = {}
         if detachable:
             self.set_detachable()
         self.set_closable(closable)
@@ -53,7 +55,10 @@ class TabWidget(QtWidgets.QTabWidget):
         if isinstance(index, int):
             return self.widget(index)
         else:
-            return self.findChild(QtWidgets.QWidget, index)
+            result = self.findChild(QtWidgets.QWidget, index)
+            if result is None:
+                raise KeyError("Widget not found")
+            return result
 
     def serialize_fields(self):
         return dict(
@@ -69,7 +74,7 @@ class TabWidget(QtWidgets.QTabWidget):
         )
 
     def __setstate__(self, state):
-        self.__init__()
+        super().__setstate__(state)
         self.setTabBar(state["tabbar"])
         self.setDocumentMode(state.get("document_mode", False))
         self.setMovable(state.get("movable", False))
@@ -81,14 +86,23 @@ class TabWidget(QtWidgets.QTabWidget):
             self.setTabWhatsThis(i, whatsthis)
         self.setCurrentIndex(state.get("index", 0))
 
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
+    def set_icon_size(self, size: Union[int, Tuple[int, int], QtCore.QSize]):
+        """Set size of the icons."""
+        if isinstance(size, int):
+            size = core.Size(size, size)
+        elif isinstance(size, tuple):
+            size = core.Size(*size)
+        self.setIconSize(size)
+
     def set_document_mode(self, state: bool = True) -> None:
         self.setDocumentMode(state)
 
-    def set_tab_shape(self, shape: str) -> None:
+    def set_tab_shape(self, shape: TabShapeStr):
         """Set tab shape for the tabwidget.
 
-        Valid values are "rounded" and "triangular"
-
         Args:
             shape: tab shape to use
 
@@ -99,42 +113,36 @@ class TabWidget(QtWidgets.QTabWidget):
             raise InvalidParamError(shape, TAB_SHAPES)
         self.setTabShape(TAB_SHAPES[shape])
 
-    def get_tab_shape(self) -> str:
+    def get_tab_shape(self) -> TabShapeStr:
         """Return tab shape.
 
-        possible values are "rounded", "triangular"
-
         Returns:
             tab shape
         """
-        return TAB_SHAPES.inv[self.tabShape()]
+        return TAB_SHAPES.inverse[self.tabShape()]
 
-    def set_tab_position(self, position: str) -> None:
+    def set_tab_position(self, position: TabPositionStr):
         """Set tab position for the tabwidget.
 
-        Valid values are "north", "south", "east", "west"
-
         Args:
             position: tab position to use
 
         Raises:
             InvalidParamError: tab position does not exist
         """
-        if position not in TAB_POSITIONS:
-            raise InvalidParamError(position, TAB_POSITIONS)
-        self.setTabPosition(TAB_POSITIONS[position])
+        if position not in TAB_POSITION:
+            raise InvalidParamError(position, TAB_POSITION)
+        self.setTabPosition(TAB_POSITION[position])
 
-    def get_tab_position(self) -> str:
+    def get_tab_position(self) -> TabPositionStr:
         """Return tab position.
 
-        possible values are "north", "south", "east", "west"
-
         Returns:
             tab position
         """
-        return TAB_POSITIONS.inv[self.tabPosition()]
+        return TAB_POSITION.inverse[self.tabPosition()]
 
-    def get_children(self) -> list:
+    def get_children(self) -> List[tuple]:
         return [
             (
                 self.widget(i),
@@ -149,16 +157,16 @@ class TabWidget(QtWidgets.QTabWidget):
     def tab_icon(self, i: int) -> gui.Icon:
         return gui.Icon(self.tabIcon(i))
 
-    def set_detachable(self) -> None:
+    def set_detachable(self):
         self.tab_bar.on_detach.connect(self.detach_tab)
         widgets.Application.call_on_exit(self.close_detached_tabs)
         self.setMovable(True)
 
-    def set_closable(self, closable: bool = True) -> None:
+    def set_closable(self, closable: bool = True):
         self.setTabsClosable(closable)
 
-    @autoslot.AutoSlot
-    def detach_tab(self, index: int, point: QtCore.QPoint) -> None:
+    @core.Slot(int, QtCore.QPoint)
+    def detach_tab(self, index: int, point: Union[QtCore.QPoint, Tuple[int, int]]):
         """Detach tab by removing its contents and placing them in a DetachedTab window.
 
         Args:
@@ -169,6 +177,8 @@ class TabWidget(QtWidgets.QTabWidget):
             None: Description
         """
         # Get the tab content
+        if isinstance(point, tuple):
+            point = QtCore.QPoint(*point)
         name = self.tabText(index)
         icon = self.tabIcon(index)
         if icon.isNull():
@@ -196,7 +206,7 @@ class TabWidget(QtWidgets.QTabWidget):
         self,
         item: Union[QtWidgets.QWidget, QtWidgets.QLayout],
         label: str,
-        icon: gui.icon.IconType = None,
+        icon: iconprovider.IconType = None,
         position: Optional[int] = None,
         show: bool = False,
     ) -> int:
@@ -210,7 +220,7 @@ class TabWidget(QtWidgets.QTabWidget):
         if not icon:
             index = self.insertTab(position, widget, label)
         else:
-            icon = gui.icon.get_icon(icon)
+            icon = iconprovider.get_icon(icon)
             index = self.insertTab(position, widget, icon, label)
         if show:
             self.setCurrentIndex(index)
@@ -220,7 +230,7 @@ class TabWidget(QtWidgets.QTabWidget):
         self,
         widget: Union[QtWidgets.QWidget, QtWidgets.QLayout],
         name: str,
-        icon: gui.icon.IconType = None,
+        icon: iconprovider.IconType = None,
         insert_at: Optional[int] = None,
     ):
         """Re-attach tab.
@@ -232,7 +242,7 @@ class TabWidget(QtWidgets.QTabWidget):
             widget (Union[QtWidgets.QWidget, QtWidgets.QLayout]): the content widget
                 from the DetachedTab window
             name (str): the name of the detached tab
-            icon (gui.icon.IconType, optional): the window icon for the detached tab
+            icon (iconprovider.IconType, optional): the window icon for the detached tab
             insert_at (Optional[int], optional): insert the re-attached tab at the
                 given index
         """
@@ -245,27 +255,27 @@ class TabWidget(QtWidgets.QTabWidget):
         # If they are, then do not add the icon to the tab
         self.add_tab(widget, name, icon=icon, position=insert_at, show=True)
 
-    def close_detached_tabs(self) -> None:
+    def close_detached_tabs(self):
         """Close all tabs that are currently detached."""
         tabs = list(self.detached_tabs.values())
         for tab in tabs:
             tab.close()
 
-    @autoslot.AutoSlot
-    def remove_tab(self, index: int) -> None:
+    @core.Slot(int)
+    def remove_tab(self, index: int):
         widget = self.widget(index)
         self.removeTab(index)
         if widget is not None:
             widget.deleteLater()
 
-    @autoslot.AutoSlot
+    @core.Slot(QtWidgets.QWidget, str)
     def open_widget(self, widget: QtWidgets.QWidget, title: str = "Unnamed"):
         """Create a tab containing delivered widget."""
         self.add_tab(widget, title, icon="mdi.widgets", show=True)
 
     def set_tab(
         self, index: int, position: str, widget: Optional[QtWidgets.QWidget] = None
-    ) -> None:
+    ):
         self.tabBar().set_tab(index, position, widget)
 
 
@@ -281,7 +291,7 @@ class DetachedTab(widgets.MainWindow):
 
     on_close = core.Signal(QtWidgets.QWidget, str, QtGui.QIcon)
 
-    def __init__(self, name, widget):
+    def __init__(self, name: str, widget: QtWidgets.QWidget):
         super().__init__(None)
 
         self.set_id(name)
@@ -294,7 +304,7 @@ class DetachedTab(widgets.MainWindow):
     #  If the window is closed, emit the on_close and give the
     #  content widget back to the DetachableTabWidget
     def closeEvent(self, event):
-        self.on_close.emit(self.widget, self.id, self.windowIcon())
+        self.on_close.emit(self.widget, self.get_id(), self.windowIcon())
 
 
 if __name__ == "__main__":
@@ -305,4 +315,4 @@ if __name__ == "__main__":
     widget_2 = widgets.Widget()
     tab_widget.add_tab(widget_2, "Test 2")
     tab_widget.show()
-    app.exec_()
+    app.main_loop()
