@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
-
 import datetime
+from typing import Union
 
-from qtpy import QtWidgets
+from qtpy import QtCore, QtWidgets
 
 from prettyqt import core, widgets
 
@@ -16,29 +15,31 @@ class TimeEdit(QtWidgets.QTimeEdit):
 
     def serialize_fields(self):
         return dict(
-            calendar_popup=self.calendarPopup(),
             time=self.get_time(),
-            display_format=self.displayFormat(),
             range=(self.min_time(), self.max_time()),
         )
 
     def __setstate__(self, state):
-        self.__init__(state["time"])
-        self.setEnabled(state.get("enabled", True))
-        self.setDisplayFormat(state["display_format"])
+        super().__setstate__(state)
+        self.setTime(state["time"])
         self.set_range(*state["range"])
-        self.setToolTip(state.get("tool_tip", ""))
-        self.setStatusTip(state.get("status_tip", ""))
 
-    def set_range(self, lower: datetime.time, upper: datetime.time):
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
+    def set_range(
+        self,
+        lower: Union[QtCore.QTime, datetime.time],
+        upper: Union[QtCore.QTime, datetime.time],
+    ):
         self.setToolTip(f"{lower} <= x <= {upper}")
-        self.setTimeRange(lower, upper)
+        self.setTimeRange(lower, upper)  # type: ignore
 
     def get_value(self) -> datetime.time:
         return self.get_time()
 
-    def set_value(self, value: datetime.time):
-        return self.setTime(value)
+    def set_value(self, value: Union[datetime.time, QtCore.QTime]):
+        return self.setTime(value)  # type: ignore
 
 
 if __name__ == "__main__":
@@ -47,4 +48,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = TimeEdit()
     widget.show()
-    app.exec_()
+    app.main_loop()
