@@ -1,28 +1,9 @@
-# -*- coding: utf-8 -*-
-
-from typing import Callable, Optional, Dict, Any
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 from qtpy import QtCore, QtWidgets
 
-from prettyqt import core, gui, widgets
-from prettyqt.utils import bidict, InvalidParamError, helpers
-
-
-STYLES = bidict(
-    icon=QtCore.Qt.ToolButtonIconOnly,
-    text=QtCore.Qt.ToolButtonTextOnly,
-    text_beside_icon=QtCore.Qt.ToolButtonTextBesideIcon,
-    text_below_icon=QtCore.Qt.ToolButtonTextUnderIcon,
-)
-
-TOOLBAR_AREAS = bidict(
-    left=QtCore.Qt.LeftToolBarArea,
-    right=QtCore.Qt.RightToolBarArea,
-    top=QtCore.Qt.TopToolBarArea,
-    bottom=QtCore.Qt.BottomToolBarArea,
-    all=QtCore.Qt.AllToolBarAreas,
-    none=QtCore.Qt.NoToolBarArea,
-)
+from prettyqt import constants, core, iconprovider, widgets
+from prettyqt.utils import InvalidParamError, helpers
 
 
 QtWidgets.QToolBar.__bases__ = (widgets.Widget,)
@@ -35,11 +16,26 @@ class ToolBar(QtWidgets.QToolBar):
         self.menu_buttons = list()
 
     def __setstate__(self, state: Dict[str, Any]) -> None:
-        super().__init__()
+        super().__setstate__(state)
         self.addActions(state["actions"])
 
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
+
+    def serialize_fields(self):
+        return dict(actions=self.actions(), allowed_areas=self.get_allowed_areas())
+
+    def __repr__(self):
+        return f"{type(self).__name__}({self.windowTitle()!r})"
+
+    def add(self, item: Union[QtWidgets.QAction, QtWidgets.QWidget]):
+        if isinstance(item, QtWidgets.QAction):
+            self.addAction(item)
+        else:
+            self.addWidget(item)
+
     def add_menu_button(
-        self, label: str, icon: gui.icon.IconType, menu: QtWidgets.QMenu
+        self, label: str, icon: iconprovider.IconType, menu: QtWidgets.QMenu
     ) -> widgets.ToolButton:
         btn = widgets.ToolButton.for_menu(menu)
         btn.setText(label)
@@ -77,31 +73,27 @@ class ToolBar(QtWidgets.QToolBar):
             else:
                 return self.addWidget(label)
 
-    def set_style(self, style: str):
-        if style is None:
-            return None
-        self.setToolButtonStyle(STYLES[style])
+    def set_style(self, style: constants.ToolButtonStyleStr):
+        self.setToolButtonStyle(constants.TOOLBUTTON_STYLE[style])
         for btn in self.menu_buttons:
             btn.set_style(style)
 
-    def get_style(self) -> str:
+    def get_style(self) -> constants.ToolButtonStyleStr:
         """Return current style.
 
-        Possible values: "icon", "text", "text_below_icon", "text_beside_icon"
-
         Returns:
             style
         """
-        return STYLES.inv[self.toolButtonStyle()]
+        return constants.TOOLBUTTON_STYLE.inverse[self.toolButtonStyle()]
 
     def add_action(
         self,
         label: str,
-        icon: gui.icon.IconType = None,
+        icon: iconprovider.IconType = None,
         callback: Optional[Callable] = None,
         checkable: bool = False,
-    ):
-        icon = gui.icon.get_icon(icon)
+    ) -> QtWidgets.QAction:
+        icon = iconprovider.get_icon(icon)
         action = self.addAction(icon, label)
         if callback is not None:
             action.triggered.connect(callback)
@@ -109,43 +101,56 @@ class ToolBar(QtWidgets.QToolBar):
             action.setCheckable(True)
         return action
 
-    def add_spacer(self):
+    def add_spacer(self) -> QtWidgets.QAction:
         spacer = widgets.Widget()
         spacer.set_size_policy("expanding", "expanding")
         return self.addWidget(spacer)
 
-    def set_icon_size(self, size: int):
-        self.setIconSize(core.Size(size, size))
+    def set_icon_size(self, size: Union[int, Tuple[int, int], QtCore.QSize]):
+        """Set size of the icons."""
+        if isinstance(size, int):
+            size = core.Size(size, size)
+        elif isinstance(size, tuple):
+            size = core.Size(*size)
+        self.setIconSize(size)
+
+    def get_icon_size(self) -> core.Size:
+        return core.Size(self.iconSize())
 
     def set_font_size(self, size: int):
-        with self.current_font() as font:
+        with self.edit_font() as font:
             font.set_size(size)
 
-    def is_area_allowed(self, area: str):
+    def is_area_allowed(self, area: constants.ToolbarAreaStr) -> bool:
         """Check if toolbar is allowed at specified area.
 
-        Valid values for area: "left", "right", "top", "bottom", "all"
-
         Args:
             area: area of the toolbar
 
         Raises:
             InvalidParamError: area does not exist
         """
-        if area not in TOOLBAR_AREAS:
-            raise InvalidParamError(area, TOOLBAR_AREAS)
-        return self.isAreaAllowed(TOOLBAR_AREAS[area])
+        if area not in constants.TOOLBAR_AREA:
+            raise InvalidParamError(area, constants.TOOLBAR_AREA)
+        return self.isAreaAllowed(constants.TOOLBAR_AREA[area])
 
-    def set_allowed_areas(self, *areas: str):
+    def set_allowed_areas(self, *areas: constants.ToolbarAreaStr):
         for area in areas:
-            if area not in TOOLBAR_AREAS:
-                raise InvalidParamError(area, TOOLBAR_AREAS)
-        flag = helpers.merge_flags(areas, TOOLBAR_AREAS)
+            if area not in constants.TOOLBAR_AREA:
+                raise InvalidParamError(area, constants.TOOLBAR_AREA)
+        flag = helpers.merge_flags(areas, constants.TOOLBAR_AREA)
         self.setAllowedAreas(flag)
 
+    def get_allowed_areas(self) -> List[constants.ToolbarAreaStr]:
+        return [
+            k
+            for k, v in constants.TOOLBAR_AREA.items()
+            if v & self.allowedAreas()  # type: ignore
+        ]
+
 
 if __name__ == "__main__":
     app = widgets.app()
-    widget = ToolBar()
+    widget = ToolBar("test")
     widget.show()
-    app.exec_()
+    app.main_loop()
