@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
-
 from typing import Optional
-from qtpy import QtWidgets, QtGui, QtCore
+
+from qtpy import QtCore, QtGui, QtWidgets
 
 
 class ToolTip(QtWidgets.QToolTip):
@@ -13,8 +12,7 @@ class ToolTip(QtWidgets.QToolTip):
         linebreak_px: int = 400,
     ):
         if position is None:
-            cursor = QtGui.QCursor()
-            position = cursor.pos()
+            position = QtGui.QCursor.pos()
         cls.showText(position, f'<div style="max-width: {linebreak_px}px">{text}</div>')
 
 
@@ -23,4 +21,4 @@ if __name__ == "__main__":
 
     app = widgets.app()
     ToolTip.show_text(text="test")
-    app.exec_()
+    app.main_loop()
