@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
-
 from typing import Optional
 
 from qtpy import QtWidgets
 
-from prettyqt import widgets, constants
+from prettyqt import constants, widgets
 
 
 QtWidgets.QTreeView.__bases__ = (widgets.AbstractItemView,)
@@ -63,4 +61,4 @@ if __name__ == "__main__":
     dlg = QtWidgets.QMainWindow()
     status_bar = TreeView()
     dlg.show()
-    app.exec_()
+    app.main_loop()
