@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import widgets
@@ -9,7 +7,7 @@ QtWidgets.QTreeWidget.__bases__ = (widgets.TreeView,)
 
 
 class TreeWidget(QtWidgets.QTreeWidget):
-    def sort(self, column=0, reverse=False):
+    def sort(self, column: int = 0, reverse: bool = False):
         order = QtCore.Qt.DescendingOrder if reverse else QtCore.Qt.AscendingOrder
         self.sortItems(column, order)
 
@@ -18,4 +16,4 @@ if __name__ == "__main__":
     app = QtWidgets.QApplication([])
     widget = TreeWidget()
     widget.show()
-    app.exec_()
+    app.main_loop()
