@@ -1,19 +1,22 @@
-# -*- coding: utf-8 -*-
+from typing import Optional
 
-from qtpy import QtWidgets
+from qtpy import QtCore, QtWidgets
 
 from prettyqt import widgets
-from typing import Optional
 
 
 QtWidgets.QWidgetAction.__bases__ = (widgets.Action,)
 
 
 class WidgetAction(QtWidgets.QWidgetAction):
-    def __init__(self, parent: Optional[QtWidgets.QWidget] = None) -> None:
-        super().__init__(parent)
+    def __init__(self, parent: Optional[QtCore.QObject] = None):
+        super().__init__(parent)  # type: ignore
 
     #     self.set_text(text)
     #     self.set_icon(icon)
     #     self.set_shortcut(shortcut)
     #     self.set_tooltip(tooltip)
+
+
+if __name__ == "__main__":
+    w = WidgetAction()
