@@ -1,8 +1,9 @@
-# -*- coding: utf-8 -*-
+from qtpy import PYQT5, PYSIDE2
 
-try:
+
+if PYQT5:
     from PyQt5 import QtWinExtras  # type: ignore
-except ImportError:
+elif PYSIDE2:
     from PySide2 import QtWinExtras
 
 from prettyqt import core, winextras
@@ -32,4 +33,4 @@ if __name__ == "__main__":
 
     app = widgets.app()
     pass
-    app.exec_()
+    app.main_loop()
