@@ -1,14 +1,15 @@
-# -*- coding: utf-8 -*-
-
-from typing import Union, Optional
 import pathlib
+from typing import Literal, Optional, Union
 
-try:
+from qtpy import PYQT5, PYSIDE2
+
+
+if PYQT5:
     from PyQt5 import QtWinExtras  # type: ignore
-except ImportError:
+elif PYSIDE2:
     from PySide2 import QtWinExtras
 
-from prettyqt import gui
+from prettyqt import iconprovider
 from prettyqt.utils import bidict
 
 
@@ -19,6 +20,8 @@ TYPES = bidict(
     tasks=QtWinExtras.QWinJumpListCategory.Tasks,
 )
 
+TypeStr = Literal["custom", "recent", "frequent", "tasks"]
+
 
 class WinJumpListCategory(QtWinExtras.QWinJumpListCategory):
     def __contains__(self, item):
@@ -30,8 +33,8 @@ class WinJumpListCategory(QtWinExtras.QWinJumpListCategory):
     def __bool__(self):
         return not self.isEmpty()
 
-    def get_type(self) -> str:
-        return TYPES.inv[self.type()]
+    def get_type(self) -> TypeStr:
+        return TYPES.inverse[self.type()]
 
     def add_destination(self, destination: Union[str, pathlib.Path]) -> None:
         self.addDestination(str(destination))
@@ -44,9 +47,9 @@ class WinJumpListCategory(QtWinExtras.QWinJumpListCategory):
         title: str,
         exe_path: Union[str, pathlib.Path],
         arguments: Optional[list] = None,
-        icon: gui.icon.IconType = None,
+        icon: iconprovider.IconType = None,
     ) -> None:
-        icon = gui.icon.get_icon(icon)
+        icon = iconprovider.get_icon(icon)
         if arguments is None:
             arguments = []
         self.addLink(icon, title, str(exe_path), arguments)
@@ -58,4 +61,4 @@ if __name__ == "__main__":
     app = widgets.app()
     cat = WinJumpListCategory()
     len(cat)
-    app.exec_()
+    app.main_loop()
