@@ -1,14 +1,15 @@
-# -*- coding: utf-8 -*-
-
-from typing import Union
 import pathlib
+from typing import Literal, Union
 
-try:
+from qtpy import PYQT5, PYSIDE2
+
+
+if PYQT5:
     from PyQt5 import QtWinExtras  # type: ignore
-except ImportError:
+elif PYSIDE2:
     from PySide2 import QtWinExtras
 
-from prettyqt import gui
+from prettyqt import iconprovider
 from prettyqt.utils import bidict
 
 
@@ -18,18 +19,22 @@ TYPES = bidict(
     separator=QtWinExtras.QWinJumpListItem.Separator,
 )
 
+TypeStr = Literal["destination", "link", "separator"]
+
 
 class WinJumpListItem(QtWinExtras.QWinJumpListItem):
-    def __init__(self, typ: str) -> None:
-        if typ in TYPES:
-            typ = TYPES[typ]
-        super().__init__(typ)
+    def __init__(self, typ: Union[QtWinExtras.QWinJumpListItem.Type, TypeStr]) -> None:
+        if isinstance(typ, QtWinExtras.QWinJumpListItem.Type):
+            param = typ
+        else:
+            param = TYPES[typ]
+        super().__init__(param)
 
     def set_title(self, title: str) -> None:
         self.setTitle(title)
 
-    def set_icon(self, icon: gui.icon.IconType) -> None:
-        icon = gui.icon.get_icon(icon)
+    def set_icon(self, icon: iconprovider.IconType) -> None:
+        icon = iconprovider.get_icon(icon)
         self.setIcon(icon)
 
     def set_file_path(self, path: Union[str, pathlib.Path]) -> None:
@@ -44,11 +49,11 @@ class WinJumpListItem(QtWinExtras.QWinJumpListItem):
     def get_working_directory(self) -> pathlib.Path:
         return pathlib.Path(self.workingDirectory())
 
-    def set_type(self, typ: str) -> None:
+    def set_type(self, typ: TypeStr) -> None:
         self.setType(TYPES[typ])
 
-    def get_type(self) -> str:
-        return TYPES.inv[self.type()]
+    def get_type(self) -> TypeStr:
+        return TYPES.inverse[self.type()]
 
 
 if __name__ == "__main__":
@@ -56,4 +61,4 @@ if __name__ == "__main__":
 
     app = widgets.app()
     pass
-    app.exec_()
+    app.main_loop()
